<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Classifieds extends MY_Controller {

	function __construct(){
		parent::__construct();

		$this->load->helper(array('html', 'text'));
		$this->load->model(array('Classifieds_model', 'Categories_model', 'Analytics_model'));

		$this->Categories_model->setModule('classifieds');
		$this->Analytics_model->saveUserInfo();// save visitors info's		
	}

	function index($offset=0){

		if($this->session->userdata('classifieds_category'))
			redirect('classifieds/category/' . $this->session->userdata('classifieds_category'));

		$this->load->library('pagination');
		$config['base_url'] = site_url('classifieds/page');
		$config['total_rows'] = $this->Classifieds_model->getClassifieds(array('published'=>FALSE,'count'=>TRUE));
		$config['per_page'] = 10;
		$config['uri_segment'] = 3;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
		
		$data = array(
			'classifieds' 	=> $this->Classifieds_model->getClassifieds(array('limit'=>$config['per_page'],'offset'=>$offset,'published'=>0)),
			'categories'	=> $this->Categories_model->getTreeRows(),
			'categories2'	=> $this->Categories_model->getCategories(),
			'pages_links' 	=> $this->pagination->create_links(),
			'current_user_id' => $this->session->userdata('user_id'),
			'search_str' => 'Enter a keyword',
			'mysearch' => TRUE,
			'view' 			=> 'classifieds_home'
		);
		
		$nav_data = array(
			'twitter' => $this->Classifieds_model->getOption('twitter_integration'),
			'answers' => $this->Classifieds_model->unapprovedAnswerCount()
		);
		

		
		$this->display('classifieds', $this->active_template, $this->pos_sidebar,  $data);
	}
	
	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	function page($offset=0){

		$this->index($offset);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){

//var_dump( $cat_id, isset($cat_id) );die();

		$cat_id = (!isset($cat_id)) ? $_POST['cat_id'] : $cat_id;
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('classifieds_category');
			redirect('classifieds');
		}
		else {
			$this->session->set_userdata('classifieds_category', $cat_id);

			$this->load->library('pagination');
			$config['base_url'] = site_url('classifieds/category/'.$cat_id);
			$config['total_rows'] = $this->Classifieds_model->getClassifieds(array('category_in'=>$cat_id,'published'=>FALSE,'count'=>TRUE));
			$config['per_page'] = 10;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);

			$data = array(
				'classifieds' => $this->Classifieds_model->getClassifieds(array('category_in'=>$cat_id,'published'=>FALSE,'limit'=>$config['per_page'],'offset'=>$offset)),
				'categories'	=> $this->Categories_model->getTreeRows(),
				'pages_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'search_str' => 'Enter a keyword',
				'mysearch' => TRUE,
				'view' => 'classifieds_home'
			);
			
		$this->display('classifieds', $this->active_template, $this->pos_sidebar,  $data);
		}
	}
	
	/**
	 * Edit a classified
	 *
	 * @param int $id
	 */
	function edit($id=0){
      
      if($id>0){		
			$data['classifieds'] = $this->Classifieds_model->getClassifieds(array('id'=>$id, 'published'=>0))->first_row('array');
		}
		//$data['classifieds'] = $this->Classifieds_model->getClassifieds(array('id'=>$id, 'published'=>0))->first_row('array');
		$data['categories'] = $this->Categories_model->getTreeRows();
		$data['tags'] = $this->Classifieds_model->getTagsOnClassified($id);
		$data['twitter_integration'] = $this->Classifieds_model->getOption('twitter_integration');
		$data['current_user_id'] = $this->session->userdata('user_id');
		$data['view'] = 'classifieds_add';

		$this->display('classifieds', $this->active_template, $this->pos_sidebar,  $data);
	}
	
	/**
	 * Add a new classified. Calls the edit() method.
	 *
	 */
	function add(){
		$this->edit();
	}
	
	/**
	 * Save existing classified, or insert new classified.
	 * Also handles image uploads for the classified.
	 *
	 * @param int $id
	 */
	function save($id=NULL){

			$this->load->library('form_validation');
			
			// field name, error message, validation rules
			$this->form_validation->set_rules('title', 'Titre', 'trim|required');
			$this->form_validation->set_rules('detail', 'Classified', 'trim|required');
			$this->form_validation->set_rules('imagecode', 'Classified', 'trim|required');
			$this->form_validation->set_rules('answer_email_notify', 'Email Address', 'trim|required|valid_email');
			$this->form_validation->set_rules('confirm_email_notify', 'Confirm Email Address' , 'required|trim|matches[answer_email_notify]');
			
			if($this->form_validation->run() == FALSE)
			{
				$this->_setMessage('Oops, Your entry is bad, verify any field of your classified.', 'error');
				$this->add();
			}
			else
			{
				$this->load->library('securimage');

				$user = $this->Classifieds_model->getUsers(array('user_id'=>$_POST['user_id']));

				if ($user)
				 {
					$user = $user->row();
					$_POST['user_id'] = $user->user_id;
					$_POST['display_name'] = $user->display_name;
					$_POST['email_address'] = $user->email_address;
				}	
						
				$inputCode = $this->input->post('imagecode');
				if($this->securimage->check($inputCode) == true){
					$data['result'] = '<h1>=v= PASS!</h1>';
					$this->_setMessage('Your input has been saved and sent in your mailbox.' . CI_VERSION, 'success');

					unset($_POST['confirm_email_notify']);
					unset($_POST['imagecode']);
					unset($_POST['button']);					
					if ( isset( $_POST ) )
						$value = $_POST['title'] ;	

					if ( get_magic_quotes_gpc() )
						$postedValue = htmlspecialchars( stripslashes( $value ) ) ;
					else
						$postedValue = htmlspecialchars( $value ) ;
						
					$_POST['title'] = $postedValue;	

					// validation has passed. Now send the email			 
					$data = $_POST;
					if (function_exists('email')) {
							$this->send_email($data);			 
						}
	
					if(isset($_FILES ['classified_image'] ['name']) && $_FILES ['classified_image'] ['name'] !=NULL){

						//load photos model
						$this->load->model('Photos_model'); 

						//get default image sizes
						$opts['large_size'] = array ('w' => 100,'h' => 75);
						$opts['upload_path'] = $this->Classifieds_model->getOption('file_upload_path').'/classifieds/';
						$opts['allowed_types'] = $this->Classifieds_model->getOption('image_allowed_types');
									
						//upload the image
						$image_data = $this->_uploadFile( $opts );

						//if successuflly uploaded, add image field to _POST array
						if($image_data[0]['raw_name'] != NULL)
							$_POST['image'] = $image_data[0]['orig_name'];
							$_POST['filename'] = $image_data[0]['raw_name'];
							$_POST['filetype'] = strtolower(substr($image_data[0]['file_ext'], 1));

					}
				
					if($this->Classifieds_model->save($id))
						$this->_setMessage('Your classifieds has been saved and sent in your mailbox.', 'success');
					else
						$this->_setMessage('Oops, there was a problem saving your classified.', 'error');

				} else {
					$data['result'] = '<h1>/_\ FAILURE</h1>';
					$this->_setMessage('Your input captcha has not been saved and retry again.' . CI_VERSION, 'error');
				}					
				redirect('classifieds');
			}

	}
	
	
	function send_email($data=NULL) 
	{	

		$title = $data['title'];
		$email = $data['comment_email_notify'];
		$detail = $data['detail'];
		$name = $data['name'];

		$this->load->library('email');
		
		$datestring = " %d  %m  %Y - %h:%i %a";
		$time = time();

		$config['charset'] = 'utf-8';
		$config['wordwrap'] = TRUE;

		$this->email->initialize($config);

		$this->email->set_newline("\r\n");

		$this->email->from('support@candlecms.com', 'CandleCMS Project');
		$this->email->to($email);		
		$this->email->subject($title);		

		$this->email->message('CandleCMS Replies'. 
		$name."\r\n".'candlecms_date_time'.": ". 
		mdate($datestring, $time) ."\r\n".'candlecms_message_sender_email'.": ". 
		$email. "\r\n".'candlecms_message'.": " . html_entity_decode(strip_tags($detail)));
		
		$file = FCPATH . 'assets/uploads/attachments/logo_candle_cms_500x250.png';

		$this->email->attach($file);

		if($this->email->send())
		{
			//echo 'Your email was sent, OK.';
			return TRUE;
		}

		else
		{
			show_error($this->email->print_debugger());
		}			

	}
	
     public function answers($id=null){

		if($this->session->userdata('logged_in')){

			 if($_POST){

				$post_answer['classified_id']=$id;
			 
				$post_answer['name']=$this->session->userdata('display_name');
				$post_answer['email']=$this->session->userdata('email_address');
				$post_answer['answer']=$_POST['answer'];
				$post_answer['ip']=$this->session->userdata('ip_address');
			 

				$this->Classifieds_model->insertAnswer($post_answer);

			 }
			 $data = array(
				'answers'=>$this->Classifieds_model->getAnswers($id),
				'classified_id'=> $id,
				'view' => 'classifieds_answer'
			);

			$this->display('classifieds', $this->active_template, $this->pos_sidebar,$data);
		}
		else{
			$data = array(
				'answers'=>$this->Classifieds_model->getAnswers(),
				'view' => 'classifieds_answer'
			);

			$this->display('classifieds', $this->active_template, $this->pos_sidebar,$data);
		}
	}
	
	function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'classifieds' => $this->Classifieds_model->searchClassifieds($search_str),
			'categories' => $this->Categories_model->getTreeRows(),
			'search_str' => $search_str,
			'mysearch' => TRUE,
			'sub_nav' => 'search',
			'view' => 'classifieds_home'
		);
		$this->display('classifieds', $this->active_template, $this->pos_sidebar, $data);
	}
	
 public function tagspage($offset=0){
	$this->tag($offset);
      
	}
	function tag($tag){
		 $this->load->library('pagination');

		$config['total_rows'] = $this->Classifieds_model->getClassifieds(array('tagged'=>$tag,'count'=>TRUE));
      $config['base_url'] = site_url('classifieds/tagspage/');
		$config['per_page'] = 10;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
		$data = array(
			'classifieds' => $this->Classifieds_model->getClassifieds(array('tagged'=>$tag)),
			'categories'	=> $this->Categories_model->getTreeRows(),
		//	'tag' => $tag,
			'pages_links'		=> $this->pagination->create_links(),
			'view' => 'classifieds_home'
		);
		
		$this->display('classifieds', $this->active_template, $this->pos_sidebar,  $data);
	}
}
/* End of file classifieds.php */
/* Location: ./application/controllers/classifieds.php */
