<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Links extends MY_Controller {

	function __construct(){
		parent::__construct();
		
		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Links_model','Categories_model'));
		//set module
		$this->Categories_model->setModule('links');
	}
	
	/**
	 * Shows a list of links
	 *
	 * @param int $offset
	 */
	function index($offset=0){

		
		$this->load->library('pagination');

		$config['base_url'] = site_url('links/page');
		$config['total_rows'] = $this->Links_model->getLinks('count=1');
		$config['per_page'] = 20;
		$config['uri_segment'] = 3;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);
		
		$data = array(
			'links' => $this->Links_model->getLinks(array('limit'=>$config['per_page'], 'offset'=>$offset)),
			'categories' => $this->Categories_model->getTreeRows(),
			'letter' => range('a', 'z'),
			'search_str' => 'Enter a keyword',
			'mysearch' => TRUE,
			'pages_links' => $this->pagination->create_links(),
			'view' => 'links_home'
		);
		$this->display('links', $this->active_template, $this->pos_sidebar,  $data);
	}
	
	/**
	 * Used for pagination
	 *
	 * @param int$offset
	 */
	function page($offset=0){
		$this->index($offset);
	}

	
	function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'links' => $this->Links_model->searchLinks($search_str),
			'categories' => $this->Categories_model->getTreeRows(),
			'letter' => range('a', 'z'),
			'mysearch' => TRUE,
			'search_str' => $search_str,
			'view' => 'links_home'
		);
		
		$this->display('links', $this->active_template, $this->pos_sidebar,  $data);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('links_category');
			redirect('links');
		}
		else {
			$this->session->set_userdata('links_category', $cat_id);
			
			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('links/category/'.$cat_id);
			$config['total_rows'] = $this->Links_model->getLinks(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page'] = 20;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'links' => $this->Links_model->getLinks(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'letter' => range('a', 'z'),
				'search_str' => 'Enter a keyword',
				'mysearch' => TRUE,
				'view' => 'links_home'
			);
			
		$this->display('links', $this->active_template, $this->pos_sidebar,  $data);
		}
	}
}
/* End of file links.php */
/* Location: ./application/controllers/links.php */
