<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Medias extends MY_Controller {

	function __construct(){
		parent::__construct();

		//load models
		$this->load->model(array('Medias_model', 'categories_model'));

		$this->load->model('Analytics_model');
		$this->Analytics_model->saveUserInfo();// save visitors info's		 
		//set module
		$this->categories_model->setModule('medias');
	}

	/**
	 * Show a list of media
	 *
	 * @param int $page_num
	 */	
	function index($page_num=0){

		if($this->session->userdata('medias_category'))
			redirect('medias/category/' . $this->session->userdata('medias_category'));

		$this->load->library('pagination');
		$config['base_url'] = site_url('medias/page');
		$config['total_rows'] = $this->Medias_model->getMedia('count=1');
		$config['per_page'] = 20;
		$config['uri_segment'] = 3;
		$this->pagination->initialize($config);

		$data = array(
			'medias' => $this->Medias_model->getMedia("offset=$page_num&limit=$config[per_page]"),
			'medias_types' => $this->Medias_model->getMediaTypes(),
			'categories' => $this->categories_model->getTreeRows(),
			'page_links' => $this->pagination->create_links(),
			'view' => 'medias_home'
		);

		$this->display('medias',$this->active_template,$this->pos_sidebar, $data);
	}

	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	function page($page_num){
		$this->index($page_num);
	}

	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){
		$_POST['cat_id'] = (!isset($_POST['cat_id'])) ? 'Uncategorized' : $_POST['cat_id'];
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;

		if($cat_id == 'ALL'){
			$this->session->unset_userdata('medias_category');
			redirect('medias');
		}
		else {
			$this->session->set_userdata('medias_category', $cat_id);

			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('medias/category/'.$cat_id);
			$config['total_rows'] = $this->Medias_model->getMedia(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page'] = 20;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);

			$data = array(
				'medias' => $this->Medias_model->getMedia(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'page_links' => $this->pagination->create_links(),
				'crumbs' => $this->categories_model->breadCrumbs($cat_id),
				'view' => 'medias_home'
			);
		
			$this->display('medias_home',$this->active_template,$this->pos_sidebar, $data);
		}
	}

	/**
	 * Download a media file increase  downloaded field
	 *
	 * @param int $media_id
	 */
	function download ($media_id){
		
		$this->load->helper('download');

		$data = $this->Medias_model->getMedia(array('id'=>$media_id))->first_row('array');
			
		$downloaded = $data['downloaded'] + 1;

		$this->db->update('medias', array('downloaded'=>$downloaded), array('id'=>$media_id));
		//entête pour le téléchargement
		
			$file = $data['filename'] . "." . $data['filetype'];
			$uploadfile = 'assets/uploads/medias/' . $file;
			

			if(file_exists($uploadfile))
			{
					/*$path=base_url().'assets/uploads/'.$data['filename'].'.'.$data['filetype'];
					$file = file_get_contents($path); // Read the file's contents
					$name = $data['filename'].'.'.$data['filetype'];

					force_download($name, $file); */
				
				if (function_exists('apache_request_headers'))
				{
			    $headers = apache_request_headers();
				}

			    // Checking if the client is validating his cache and if it is current.
			    if (isset($headers['If-Modified-Since']) && (strtotime($headers['If-Modified-Since']) == filemtime($uploadfile)))
				{
			        // Client's cache IS current, so we just respond '304 Not Modified'.
			        header('Last-Modified: '.gmdate('D, d M Y H:i:s', filemtime($uploadfile)).' GMT', true, 304);
			    }
				else
				{
					$this->load->helper('file');
			        /* Image not cached or cache outdated, we respond '200 OK' and output the image.*/ 
					 header('Content-disposition: attachment; filename="' . $uploadfile . '"');
					 header('Content-Type: application/force-download');
					 header('Content-Transfer-Encoding: binary');
					 header('Content-Length: '. filesize($uploadfile));
					 header('Pragma: no-cache');
					 header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
					 header('Expires: 0');
					 readfile( $uploadfile );
					


			    }

			}
			else
			{
				$this->output->set_header("HTTP/1.0 404 Not Found");
				$this->display('medias',$this->active_template,$this->pos_sidebar, '404');
			}
			
			redirect('medias_home');
	}

	/**
	 * Save a media file
	 *
	 * @param int $media_id
	 */
	function save($media_id){
		$this->Medias_model->save($media_id);
		redirect('medias');
	}


	public function view($id){
		
		$data = array(
		//	'row' => $this->Media_model->getMedia($id)->first_row('array'),
			'categories' => $this->categories_model->getTreeDD(),
			'view' => 'medias_info'
		);
		$data['row']=$this->Medias_model->getMedia(array('id'=>$id))->result_array();
		foreach ($data['row'] as $row){
			if ($row['id']==$id) $data['row']=$row;
			
			}
		$this->display('medias',$this->active_template,$this->pos_sidebar, $data);
	}
	

	/**
	 * Delete a media file
	 *
	 * @param int $id
	 */
	function delete($id){
		$upload_path = $this->Medias_model->getOption('file_upload_path');

		$row = $this->Medias_model->getMediaByID($id)->first_row();

		$this->_deleteFile($upload_path, $row->filename, $row->filetype);

		//delete from db
		$this->Medias_model->delete($id);

		redirect('medias');
	}

	

	/**
	 * Show all media files by type (file ext)
	 *
	 * @param int $type
	 */
	function type($type, $offset=0){
		
		$this->load->library('pagination');
			$config['base_url'] = site_url('medias/page');
			$config['total_rows'] = $this->Medias_model->getMedia(array('filetype'=>$type,'count'=>TRUE));
			$config['per_page'] = 6;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
		
		$data = array(
			'medias' => $this->Medias_model->getMedia(array('filetype'=>$type,'limit'=>$config['per_page'],'offset'=>$offset,'type'=>$type)),
			'page_links' => $this->pagination->create_links(),
			'type' => $type,
			'view' => 'medias_view'
		);
		
		$this->display('medias',$this->active_template,$this->pos_sidebar, $data);
	}
	
	
}
/* End of file medias.php */
/* Location: ./application/controllers/medias.php */
