<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Posts extends MY_Controller {

	public  $code_lang;

	function __construct(){
		parent::__construct();

		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Posts_model', 'Categories_model', 'Analytics_model'));
		//set module
		$this->Categories_model->setModule('posts');
		//get language		
		$this->code_lang = $this->getCurrentLang();

	}

	function index($offset=0){
		
		if($this->session->userdata('posts_category'))
			redirect('posts/category/' . $this->session->userdata('posts_category'));

		$this->load->library('pagination');
		$config['base_url'] = site_url('posts/page');
		$config['total_rows'] = $this->Posts_model->getPosts(array('published'=>FALSE,'count'=>TRUE));
		$config['per_page'] = 10;
		$config['uri_segment'] = 3;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
		
		$data = array(
			'posts' 		=> $this->Posts_model->getPosts(array('limit'=>$config['per_page'],'offset'=>$offset,'published'=>0,'lang'=>$this->code_lang)),
			'categories'	=> $this->Categories_model->getTreeRows(),
			'categories2'	=> $this->Categories_model->getCategories(),
			'page_links' 	=> $this->pagination->create_links(),
			'search_str' => 'Enter a keyword',
			'mysearch' => TRUE,
			'view' 			=> 'posts_home'
		);
		
		$nav_data = array(
			'twitter' => $this->Posts_model->getOption('twitter_integration'),
			'comments' => $this->Posts_model->unapprovedCommentCount()
		);
		
		$this->Analytics_model->saveUserInfo();// save visitors info's

		$this->display('posts', $this->active_template, $this->pos_sidebar,  $data);
	}
	
	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	function page($offset=0){

		$this->index($offset);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){

		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('posts_category');
			redirect('posts');
		}
		else {
			$this->session->set_userdata('posts_category', $cat_id);

			$this->load->library('pagination');
			$config['base_url'] = site_url('posts/category/'.$cat_id);
			$config['total_rows'] = $this->Posts_model->getPosts(array('category_in'=>$cat_id,'published'=>FALSE,'count'=>TRUE));
			$config['per_page'] = 10;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);

			$data = array(
				'posts' => $this->Posts_model->getPosts(array('category_in'=>$cat_id,'published'=>FALSE,'limit'=>$config['per_page'],'offset'=>$offset,'lang'=>$this->code_lang)),
				'page_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'search_str' => 'Enter a keyword',
				'mysearch' => TRUE,
				'view' => 'posts_home'
			);
			
		$this->Analytics_model->saveUserInfo();
		$this->display('posts', $this->active_template, $this->pos_sidebar,  $data);
		}
	}

	function edit($id=0){

		redirect('backoffice/posts/edit/'.$id);
	}

     public function comments($id=null){

		if($this->session->userdata('logged_in')){

			 if($_POST){

				$post_comment['post_id']=$id;
			 
				$post_comment['name']=$this->session->userdata('display_name');
				$post_comment['email']=$this->session->userdata('email_address');
				$post_comment['comment']=$_POST['comment'];
				$post_comment['ip']=$this->session->userdata('ip_address');
			 

				$message=$this->Posts_model->insertComment($post_comment);
             $this->_setMessage($message);
			 }
			 $data = array(
			 'post'=>$this->Posts_model->getPosts(array('id'=>$id)),
			'comments'=>$this->Posts_model->getComments($id),
			'view' => 'posts_comment'
		);
              
					$this->display('posts', $this->active_template, $this->pos_sidebar,$data);
		}
		else{
			$data = array(
				'post'=>$this->Posts_model->getPosts(array('id'=>$id)),
				'comments'=>$this->Posts_model->getComments(),
				'view' => 'posts_comment'
			);

		$this->display('posts', $this->active_template, $this->pos_sidebar,$data);
		}
	}
	
	public function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'posts' => $this->Posts_model->searchPosts($search_str),
			'categories' 	=> $this->Categories_model->getTreeRows(),
			'mysearch' 		=> TRUE,
			'search_str' => $search_str,
			'sub_nav'	 => 'posts',
			'view' => 'posts_home'
		);
		$this->display('posts',$this->active_template, $this->pos_sidebar, $data);
	}

   public function tag($tag){
      $this->load->library('pagination');

		$config['total_rows'] = $this->Posts_model->getPosts(array('tagged'=>$tag, 'count'=>TRUE,'lang'=>$this->code_lang));

		$config['per_page'] = 10;
		$config['uri_segment'] = 5;
		$config['num_links'] = 4;

		$this->pagination->initialize($config);

		$data = array(
			'posts'				 => $this->Posts_model->getPosts(array('tagged'=>$tag)),
			'twitter_integration'=> $this->Posts_model->getOption('twitter_integration'),
			'page_links'		=> $this->pagination->create_links(),
			'tag'				 => $tag,
			'sub_nav'			 => 'posts',
			'view'				 => 'posts_home'
		);

		$this->display('posts', $this->active_template, $this->pos_sidebar, $data);
   }
	

}
/* End of file posts.php */
/* Location: ./application/controllers/posts.php */
