<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class MY_Controller extends CI_Controller
{
	/* Array of languages supported by the candlecms app */
	private  $_languages	= array ('english', 'french');
	private  $_language;
      
	protected $canView;
	protected $canEdit;
	protected $canDelete;

	protected $is_admin;      
	protected $is_superadmin;
	protected $is_subscriber;
	protected $useraccessright; 
	    
	public $admin_level;
	public $super_admin_level;
	
	public $active_template;
	public $pos_sidebar;
	
      function __construct()
	{
		// get the CI superobject
		$CI =& get_instance();

		// call the parent constructor
		parent::__construct();

		// do we have a superobject?
		if ( $CI )
		{
			// yes, so this is an HMVC sub-controller.

			// check how we reference the module itself
			$config = $CI->config->item('module');
			$self = isset($config['self']) ? $config['self'] : false;

			// copy all objects from the parent controller to the sub-controller
			foreach (array_keys(get_object_vars($CI)) as $attribute)
			{
				if ($attribute != $self && is_object($CI->$attribute))
				{
					$this->$attribute =& $CI->$attribute;
				}
			}

			// inform the loader we're now in HVMC mode
			if ( is_null($this->load->_ci_root) )
			{
				$this->load->_ci_root =& $CI;
			}
		}

		$this->load->library('driver');
		$this->load->library('Session/session');

		//load active lang if not exist then default language  if not exist then config->item('language')
		if ( !class_exists('Languages_model')) $this->load->model('languages_model');
		$this->active_lang = $this->languages_model->get_active_language();
				
		if ( !class_exists('Settings_model')) $this->load->model('settings_model');
		$options = $this->settings_model->getOptions('general');
		// change option show_sessions on/off
		($this->config->item('show_sessions')!=$options['show_sessions']['option_value']) ? $this->config->set_item('show_sessions',$options['show_sessions']['option_value']) : '';
		// if the lang manager has been disabled from the front office, do not allow the viewer to go any further
		if ($options['front_office_languages']['option_value'] != 'on' && $this->uri->segment(1) != 'backoffice' ) {
			$this->default_lang = $this->languages_model->get_default_language();
			if ( $this->default_lang->name <> $this->session->userdata('language')){ 
				$this->languages_model->setLanguage($this->default_lang->name);
			}
		} else {

			$this->active_lang = $this->languages_model->get_active_language();
			if( $this->active_lang ){
				$this->languages_model->setLanguage($this->active_lang->name);
			} else {
				$this->default_lang = $this->languages_model->get_default_language();
				if( $this->default_lang ){
					$this->languages_model->setLanguage($this->default_lang->name);
				} else {
					$this->languages_model->setLanguage($this->config->item('language'));
				}
			}
		}

		$this->active_template = $this->session->userdata('theme');
		// do not display the backoffice template on the start
		if ( !$this->active_template || $this->uri->segment(1) != 'backoffice'){
			// load model template
			if ( !class_exists('Templates_model')) $this->load->model('templates_model');
			
			$default_temp = $this->templates_model->get_default_template();
			$this->switch_my_theme($default_temp->name);

			$this->pos_sidebar = $default_temp->sidebar;
		}
		if( $this->uri->segment(1) == 'backoffice' ){
			$this->switch_my_theme('backoffice');
			$this->pos_sidebar = 'left';
		}

		//reload user access right move from sessions to property
		$this->useraccessright=$this->session->userdata('user_access_right');
		$this->is_superadmin = $this->session->userdata('is_superadmin');
		$this->is_admin = $this->session->userdata('is_admin');
		$this->is_subscriber = $this->session->userdata('is_subscriber');

		//load models
		if ( !class_exists('Settings_model')) $this->load->model('settings_model');
		$options = $this->settings_model->getOptions('general');
		// if the site has been disabled from the back end, do not allow the viewer to go any further
		if ($options['maintenance']['option_value'] == 'on' && $this->uri->segment(1) != 'backoffice' ) {
			$data = $this->lang->line('site_disabled');
			$this->load->view('maintenance', $data);
		}

	}

	function index(){

		$module=$this->active_template;

		$this->$module->lang($module, $this->session->userdata('language'));
	}
		
	/**
	 * Return an option value, for use outside of the model
	 * 
	 * @deprecated use config_item(); (CI globally available)
	 *
	 * @param string $option_name
	 * @return string
	 */
	public function getOption($option_name){
		
		//set config options
		$module = ($this->module == NULL) ? $this->uri->segment(2) : $this->module;
		
		$res = $this->db->query('SELECT * FROM `' . $this->db->dbprefix($this->table_opts) . '` WHERE category IN ("' . $module . '","general")');
		
		
		foreach($res->result_array() as $row){
			$result_arr[$row['option_name']] = $row['option_value'];
			//use CI's config class
			$this->config->set_item($row['option_name'], $row['option_value']);
		}
		
		$this->options = $result_arr;
		
		return $this->options[$option_name];
	}	

	/**
	 * Controller function for categories
	 *
	 * @param string $action
	 * @param int $id
	 */
	function categories($action=NULL, $id=NULL){

		//the current module. ie. 'posts'
		$data['module_plural'] = $this->uri->segment(2);
		//the singular word. ie. 'Post'
		$data['module'] = strtoupper(substr($data['module_plural'],0,1)) . 	substr($data['module_plural'], 1, -1);

		if($action == 'edit'){
			if(is_numeric($id)){
				$this->Categories_model->buildTree();
				$data['cat_dd'] = $this->Categories_model->getTreeDD();
				$data['categories2'] = $this->Categories_model->getTreeRows();
				$data['row'] = $this->Categories_model->getCategory($id)->first_row('array');
			}
			else
				//invalid category id
				$action = null;
		}
		if(isset($_POST['category']) && $_POST['category'] !=NULL && $action == 'save') {
			$res=$this->Categories_model->save($id);
			if( $res==NULL){
				$this->_setMessage('Cannot save this category exist =>'.$data['module_plural'].'  '.$_POST['category'], 'error');
			}
			redirect('backoffice/'.$data['module_plural'].'/categories');
		}
		if($action == 'delete') {
			$this->Categories_model->delete($id);
			redirect('backoffice/'.$data['module_plural'].'/categories');
		} 
		if($action == NULL) {
			
			$this->Categories_model->buildTree();
			
			$data['cat_dd'] = $this->Categories_model->getTreeDD();
			$data['categories2'] = $this->Categories_model->getTreeRows();
			$data['uncategorized'] = $this->Categories_model->getUncategorized();
		}

		if(empty($_POST['category']) && $action == 'save') 
			redirect('backoffice/'.$data['module_plural']);
		
		$data['sub_nav'] = $data['module_plural'];
		$data['view']	 = 'categories_' . (($action == 'edit') ? 'edit' : 'all');
	
		$this->display('categories', 'backoffice', 'none', $data);
	}

	
	/**
	 * Upload a file. If it's an image, a thumbnail will be created.
	 * 
	 * FORMAT - The $args parameter must be in the following format:
	 * 		1. As an array: 	array('key'=>'val', 'key2'=>'val2')
	 * 		
	 * OPTIONS - The following options are available for $args:
	 *
	 * allowed_types (string)(optional)
	 *   Specify what file types are allowed
	 *   Default: jpg
	 * large_size (array)(optional)
	 *   Specify the width and height of the large image. 
	 *   Default: array('w'=>500, 'h'=>500)
	 * thumb_size (array)(optional)
	 *   Specify the width and height of the thumbnail image. 
	 *   Default: array('w'=>200, 'h'=>200)
	 * 
	 * @param mixed $args
	 * @return array
	 */
	function _uploadFile( $args ){

		if(isset($args['upload_path'])){
			$upload_path = $args['upload_path'];			
		}
		else{
			$this->_setMessage('Upload failed. Missing file upload path.', 'error');
			return FALSE;
		}
		
		$count = 0;
		$this->load->library('image_lib');
		$this->load->library('upload');	
		
		//set default image sizes
		if(!isset($args['large_size']) || $args['large_size'] == NULL)
			$args['large_size'] = array('w'=>500, 'h'=>500);
		if(!isset($args['thumb_size']) || $args['thumb_size'] == NULL)
			$args['thumb_size'] = array('w'=>200, 'h'=>200);
			
		//set default for allowed_types
		if(!isset($args['allowed_types']) || $args['allowed_types'] == NULL)
			$args['allowed_types'] = 'jpg';

		//config options for upload class
		$config = array('upload_path' => $upload_path, 'allowed_types' => $args['allowed_types']);

		//loop through each FILE input
		foreach($_FILES as $field=>$data){
			//fixes a bug with the file names
			$this->upload->initialize($config);
		
			if($data['name'] == NULL || $data['error']>0){
				$message = "the file have not been uploaded, the name field may not be correct or the file size may not be authorized.";
				break;
			}

			if ( ! $this->upload->do_upload($field))
			{
				$message = implode(",", array('error' => $this->upload->display_errors()));
				break;
			}

			$upload_data = $this->upload->data();

			//filename to lower case
			rename($upload_path . $upload_data['file_name'], $upload_path . strtolower($upload_data['file_name']));
			
			if($upload_data['is_image']){
				$this->_createThumb($upload_path, $upload_data['file_name'], $args['thumb_size']['w'], $args['thumb_size']['h']);
				$this->_createThumb($upload_path, $upload_data['file_name'], $args['large_size']['w'], $args['large_size']['h'], '-midle');
			}

			//save upload data for return
			
			
			$upload_data_arr[] = $upload_data;
			
			$count++;
		}

		if($count > 0) {
			$this->_setMessage("$count file(s) uploaded successfully.", 'success');
		} 
		elseif(isset($message) && $message != NULL && !isset($upload_data)){
			$this->_setMessage($message, 'error');
			return false;
		}
		return $upload_data_arr;
	}
	
	/**
	 * Delete a file.
	 *
	 * @param string $upload_path
	 * @param string $filename
	 * @param string $fileext
	 */
	function _deleteFile($upload_path=NULL, $filename, $fileext='.jpg'){
		//add the 'dot' if it's not there
		if(substr($fileext,0,1) != '.')
			$fileext = '.' . $fileext;
		
		//check for upload path
		if(!isset($upload_path) || $upload_path == NULL)
			$upload_path = config_item('file_upload_path');
			
		//delete file
		if(file_exists($upload_path . $filename . $fileext)){
			unlink($upload_path . $filename . $fileext);
			
			$this->_setMessage("$filename$fileext has been deleted.", 'success');
			
			//delete large image size
			if(file_exists($upload_path . $filename . '-midle' . $fileext))
				unlink($upload_path . $filename . '-midle' . $fileext);
			//delete small image size
			if(file_exists($upload_path . $filename . '-mini' . $fileext))
				unlink($upload_path . $filename . '-mini' . $fileext);
		} else {
			$this->_setMessage("$filename$fileext does not exist.");
		}
	}
	
	/**
	 * Create a thumbnail
	 *
	 * @param string $upload_path
	 * @param string $file_name
	 * @param int $width
	 * @param int $height
	 * @param string $thumb_marker
	 */
	function _createThumb($upload_path, $file_name, $width=200, $height=200, $thumb_marker='-mini'){
		$config['image_library'] = 'gd2';
		$config['source_image'] = $upload_path . strtolower($file_name);
		$config['create_thumb'] = TRUE;
		$config['maintain_ratio'] = TRUE;
		$config['width'] = $width;
		$config['height'] = $height;
		$config['thumb_marker'] = $thumb_marker;
		
		$this->image_lib->initialize($config); 
		$this->image_lib->resize();
		$this->image_lib->clear();
	}
	

	public function switch_my_theme($my_theme = 'candlecms')
	{
		$this->active_template = $my_theme;
		$this->config->set_item('theme', $my_theme);
        $this->template->set_template($my_theme);
		$this->session->set_userdata('theme', $my_theme);
	}

	public function loadLangModule($module='candlecms', $class='warning'){
//var_dump(  $module, $this->session->userdata('language') );die;
		$this->$module->lang($module, $this->session->userdata('language'));
	}
	
	function getCurrentLang	(){	

		// checking out on the current language
		if ($this->session->userdata('language')) {

			$_language = $this->languages_model->getLang(array('language'=>$this->session->userdata('language')))->row();
			return $_language->code;
		}
		return FALSE;
	}
	
	function setCurrentLang	($mylang='english'){

		if (in_array($mylang, $this->_languages))
		{
			// checking out on the current language
			if ($mylang <> $this->session->userdata('language')) {
				$_language = $this->languages_model->setLanguage($mylang);
				$this->code_lang = $_language->code;
			}
			else{
				$this->code_lang = $this->session->userdata('code_lang');
			}
			return $this->code_lang;
		}		
	}		
	
	public function switch_my_lang($langfile='', $language='', $return = FALSE, $add_suffix=TRUE)
	{

		$langfile = str_replace(EXT, '', $langfile);

		if ($add_suffix == TRUE)
		{
			$langfile = str_replace('_lang.', '', $langfile).'_lang';
		}

		$langfile .= EXT;

		if (in_array($langfile, $this->lang->is_loaded, TRUE))
		{
			return;
		}

		if ($language == '')
		{
			$config_lang = $this->config->item('language');
			$deft_lang = (!isset($config_lang)) ? 'english' : $config_lang;
			$language = ($deft_lang == '') ? 'english' : $deft_lang;
		}

		// Determine where the language file is and load it
		if (file_exists(APPPATH.'language/'.$language.'/'.$langfile))
		{
			include(APPPATH.'language/'.$language.'/'.$langfile);
		} 
		else
		{
			show_error('Unable to load the requested language file: language/'.$language.'/'.$langfile);
			exir();
		}


		if ( ! isset($lang))
		{
			log_message('error', 'Language file contains no data: language/'.$language.'/'.$langfile);
			return;
		}

		if ($return == TRUE)
		{
			return $lang;
		}

		$this->lang->is_loaded[] = $langfile;
		$this->lang->language = array_merge($this->lang->language, $lang);
		unset($lang);

		log_message('debug', 'Language file loaded: language/'.$language.'/'.$langfile);
		return TRUE;		
		
	}

	public function _setMessage($message, $class='warning'){
		$this->session->set_userdata('msg', $message);
		$this->session->set_userdata('msg_class', $class);
	}
	
	
	public function pdf()
	{
		 $this->load->plugin('to_pdf');
		 // page info here, db calls, etc.     
		 $html = $this->load->view('controller/viewfile', $data, true);
		 pdf_create($html, 'filename');
	}  	
		
	public function check_securimage(){
		
		$this->load->library('securimage');
        $inputCode = $this->input->post('imagecode');
        
        if($this->securimage->check($inputCode) == true){
			$data['securimage'] = '<h1>=v= PASS!</h1>';
			$this->_setMessage('Your input has been saved and sent in your mailbox.' . CI_VERSION, 'success');
        } else {
			$data['securimage'] = '<h1>/_\ FAILURE</h1>';
			$this->_setMessage('Your input has not been saved and retry again.' . CI_VERSION, 'error');
        }
        
		redirect('posts');
	}	

	
		/* $this->display($view, $theme, $sidebar, $data);
		 * view  = show this page or switch in the container.php template
		 * theme = choice one theme or switch mytheme on admin
		 * sidebar = show at th right, left position or none
		 * data  the array content all showing data 
		 */

	public function display($modular='pages', $mytheme='candlecms', $sidebar='none', $data=NULL){

		$data['backoffice'] = FALSE;
		$data['show_sidebar'] = $sidebar;// change inside sidebar
		$data['user_level'] = $this->session->userdata('user_level');
		$data['display_name'] = $this->session->userdata('display_name');
		$data['modular'] = $modular;
		$data['app_version'] = $this->config->item('app_version');
		$data['db_version'] = $this->config->item('db_version');
		$data['app_date_version'] = $this->config->item('app_date_version');
		$data['author'] = $this->config->item('author');


		if ( $this->session->userdata('theme') <> $mytheme)
			$this->switch_my_theme($mytheme);
		        
        //test if backoffice is enabled
		if ( $this->session->userdata('theme') == 'backoffice'){
			$data['mysql_version'] = $this->get_mysql_version('server');
			$data['gd_version'] = $this->get_gd_version();		
			$data['backoffice'] = TRUE;
			$data['modul_lang'] = 'backoffice';  // current module is backoffice

			// loading the language file  at administrator class MY_Controller->LoadLangModule($this->active_template, $this->session->userdata('language'))     
			$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
			
			$data = array_merge ($data ,
			// Write to $footer
			array(
				'site_name'		=> $this->config->item('site_name'),
				'site_title'	=> $this->config->item('site_title'),
				'site_url'		=> $this->config->item('site_url'),
				'admin_email'	=> $this->config->item('admin_email'),
				'name' 			=> 'Byoos solutions...',
				'location'		=> 'GAP - France  / Yaoundé - Cameroun'
				)
			);
		} 
		elseif ( $this->session->userdata('theme') == 'candlecms')
		{
			$this->lang->load('candlecms', $this->session->userdata('language'));
			$this->load->helper('language');
			$data = array_merge ($data , $this->frontoffice_data());
		}else {
			$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
			$this->load->helper('language');			
		}

		// Write to $header
		$this->template->write_view('header', 'themes/'.$mytheme.'/header', $data, TRUE);
		// Write to $content
		$this->template->write_view('content', 'themes/'.$mytheme.'/container', $data, TRUE);
		// Write to $sidebar
		$this->template->write_view('sidebar', 'themes/'.$mytheme.'/sidebar', $data, TRUE);
		// Write to $footer
		$this->template->write_view('footer', 'themes/'.$mytheme.'/footer', $data, TRUE);
		// Render the template
		$this->template->render();
      
	}


	function save_visitor_info() {

		$this->load->library('user_agent');
		$this->load->model('Visitors_model');
		$this->Visitors_model->date = time();
		$this->Visitors_model->ip_address = $this->input->ip_address();
		$this->Visitors_model->browser = $this->agent->browser();
		$this->Visitors_model->referer = $this->agent->referrer();
		$this->Visitors_model->page_visited = $this->uri->uri_string();
		$this->Visitors_model->human_year = date('Y');
		$this->Visitors_model->human_month = date('m');
		$this->Visitors_model->human_day = date('d');
		$this->Visitors_model->save();

	}



	function set_session($user) {

		$session_data = array(
		'logged_in'		=>	TRUE,
		'user_id'		=>	$user->user_id,
		'display_name'	=>	$user->display_name,
		'email_address'	=>	$user->email_address,
		'passage_save'	=>	1,
		'user_level'	=>	$user->user_level
		);
		
		$this->session->set_userdata($session_data);

	}

	public function frontoffice_data()
	{
		//load models
		$this->load->model('Settings_model');
		
		$data = array();

		$data['options'] =  $this->Settings_model->getOptions('general');

		$data['site_title'] = $data['options']['site_title']['option_value'];
		$data['site_name'] = $data['options']['site_name']['option_value'];
		$data['site_slogan'] = $data['options']['site_slogan']['option_value'];
		$data['admin_email'] = $data['options']['admin_email']['option_value'];
		
		$data['detail'] = 'This developpment you are offer by BYOOS Cameroon, Good nuts !
		<br/> Include: 
		<br/> - The captcha libraries - securimage
		<br/> - The Template libraries
		<br/> - The Modular libraries - ci_modular
		<br/> - The CKeditor libraries javascript
		<br/> - The flvplayer libraries videos - sounds - pictures
		<br/> - The Counter and visitor libraries database  less
		<br/> - The Taggly libraries Tags Cloud
		<br/> - The Inktype libraries Auth-Subscribe with SHA1 encryption and SALT
		';

		$this->counter->update();
		$nb_connect = $this->counter->view();

		$data['user_online'] = $nb_connect . (isset($nb_connect) ? ' '.$this->lang->line('user_connected').($nb_connect>1?'\'s':'') : '');

		$matchTags = array ('PHP','CodeIgniter');

		$data['configArray'] = array (
			'min_font' => 12,
			'max_font' => 48,
			'html_start' => '<ul>',
			'html_end' => '</ul>',
			'shuffle' => TRUE,
			'class' => 'my_css_class',
			'find_Match' => $matchTags,
			'match_Class' => 'bold',
		);

		$data['myArray'] = array (
			array(10, 'PHP', 'http://php.com'),
			array(18, 'MySQL', 'http://mysql.com'),
			array(32, 'DjaForest', 'http://djaforest.com'),
			array(5, 'CodeIgniter', 'http://codeigniter.fr')
		);
					
		return $data;
	}
	/**
	 * @return string The PHP version
	 *
	 * Function to retrieve the PHP version
	 */
	function get_php_version()
	{
		// Set the PHP version
		$php_version = phpversion();
		
		// Validate the version
		return ($php_version >= 5) ? $php_version : FALSE;
	}
	
	/**
	 * @param 	string $type The MySQL type, client or server
	 * @return 	string The MySQL version of either the server or the client
	 * 
	 * Function to retrieve the MySQL version (client/server)
	 */
	function get_mysql_version($type = 'server')
	{

		// What do we want to return, the client or the server ? 
		if($type == 'server'){
			// Retrieve the database settings from the db functions
			$mysql = $this->db->call_function('get_server_info');

			return $mysql;
		}
		else{
			// Get the version
			$mysql = $this->db->call_function('get_client_info');

			// Compare it
			return $mysql ? preg_replace('/[^0-9\.]/','', $mysql) : FALSE;
		}	
	}
	
	/**
	 * @return string The GD library version. 
	 *
	 * Function to retrieve the GD library version
	 */
	function get_gd_version()
	{
		// Get if the gd_info() function exists
		if(function_exists('gd_info'))
		{
			$gd_info = gd_info();			
			return preg_replace('/[^0-9\.]/','',$gd_info['GD Version']);
		}
		else
		{
			return FALSE;
		}
	}
	
	/**
	 * @param 	string $data The data that contains server related information.
	 * @return 	bool
	 *
	 * Function to validate the server settings.
	 */
	function check_server($data)
	{
		// Check PHP is ok
		if( version_compare(PHP_VERSION, '5.0', '<') )
		{
			return FALSE;
		}

		// Check MySQL server is ok
		if( $data->mysql->server_version < '5.0.0' )
		{
			return FALSE;
		}

		// Check MySQL client is ok
		if( $data->mysql->client_version < '5.0.0' )
		{
			return FALSE;
		}
		
		if($data->http_server->supported === FALSE)
		{
			return FALSE;
		}

		// If PHP, MySQL, etc is good but server is unknown, say partial
		if( $data->http_server->supported === 'partial' || $data->gd_version === FALSE )
		{
			return 'partial';
		}

		// Must be fine
		return TRUE;
	}
	
	/**
	 * @param	string $server_name The name of the HTTP server such as Abyss, Cherokee, Apache, etc
	 * @return	array
	 *
	 * Function to validate whether the specified server is a supported server. The function returns an array with two keys: supported and non_apache. 
	 * The supported key will be set to TRUE whenever the server is supported. The non_apache server will be set to TRUE whenever the user is using a server other than Apache. 
	 * This enables the system to determine whether mod_rewrite should be used or not.
	 */
	function verify_http_server($server_name)
	{
		// Set all the required variables
		if($server_name == 'other')
		{
			return 'partial';
		}
		
		$supported_servers = $this->ci->config->item('supported_servers');

		return array_key_exists($server_name, $supported_servers);
	}
     
     /*
      * exmple utilisation
      * 
      * $mavariable = $this->session->userdata('user_access_right');
      *  if( ! $mavariable['pages']['canView'] ){
      *        redirection();
      * }else{
      *     execution();
      * }
      */	
   function UserAccessRight(){

		if ( !class_exists('Usergroups_model')) $this->load->model('Usergroups_model');

		$user_access_right = array();
 		$query = $this->Usergroups_model->get_module_access($this->session->userdata('user_level') );

		foreach( $query->result() as $row ){
			$user_access_right[ $row->name ] = array(  'canView'   => $row->grpma_view,
													   'canEdit'  =>$row->grpma_edit,
													   'canDelete'  =>$row->grpma_delete
				);
		}

		return $user_access_right;
   }

	/**
	 * @return TRUE / FALSE statut or redirect
	 *
	 * Function to user access right canView
	 */
	function canView($module='pages')
	{
		if( !$this->useraccessright[$module]['canView']){		
			$this->_setMessage($this->lang->line('access_right_canview', 'backoffice').$module);//no access view right
			redirect('backoffice/administrator');
		}
		return TRUE;   
	}   

	/**
	 * @return TRUE / FALSE statut or redirect
	 *
	 * Function to user access right canEdit
	 */
	function canEdit($module='pages')
	{
		if( !$this->useraccessright[$module]['canEdit']){		
			$this->_setMessage($this->lang->line('access_right_canedit', 'backoffice').$module);//no access edit right
			redirect('backoffice/administrator');
		}
		return TRUE;   
	}   

	/**
	 * @return TRUE / FALSE statut or redirect
	 *
	 * Function to user access right canDelete
	 */
	function canDelete($module='pages')
	{
		if( !$this->useraccessright[$module]['canDelete']){		
			$this->_setMessage($this->lang->line('access_right_candelet', 'backoffice').$module);//no access delete right
			redirect('backoffice/administrator/');
		}
		return TRUE;   
	}   	
}
/* End of file MY_Controller.php */
/* Location: ./application/core/MY_Controller.php */
