<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class MY_Calendar extends CI_Calendar {
	
	/**
	 * Current local time
	 *
	 * @var int
	 */
	 
	public $local_time;
	
	function __construct($config = array() ){
		parent::__construct($config);
	}
	
	// --------------------------------------------------------------------

	/**
	 * Generate the calendar
	 *
	 * @access	public
	 * @param	integer	the year
	 * @param	integer	the month
	 * @param	array	the data to be shown in the calendar cells
	 * @return	string
	 */
	function generate($year = '', $month = '', $data = array())
	{
		// Set and validate the supplied month/year
		if ($year == '')
			$year  = date("Y", $this->local_time);
			
		if ($month == '')
			$month = date("m", $this->local_time);
			
 		if (strlen($year) == 1)
			$year = '200'.$year;
		
 		if (strlen($year) == 2)
			$year = '20'.$year;

 		if (strlen($month) == 1)
			$month = '0'.$month;
		
		$adjusted_date = $this->adjust_date($month, $year);
		
		$month	= $adjusted_date['month'];
		$year	= $adjusted_date['year'];
		
		// Determine the total days in the month
		$total_days = $this->get_total_days($month, $year);
						
		// Set the starting day of the week
		$start_days	= array('sunday' => 0, 'monday' => 1, 'tuesday' => 2, 'wednesday' => 3, 'thursday' => 4, 'friday' => 5, 'saturday' => 6);
		$start_day = ( ! isset($start_days[$this->start_day])) ? 0 : $start_days[$this->start_day];
		
		// Set the starting day number
		$local_date = mktime(12, 0, 0, $month, 1, $year);
		$date = getdate($local_date);
		$day  = $start_day + 1 - $date["wday"];
		
		while ($day > 1)
		{
			$day -= 7;
		}
		
		// Set the current month/year/day
		// We use this to determine the "today" date
		$cur_year	= date("Y", $this->local_time);
		$cur_month	= date("m", $this->local_time);
		$cur_day	= date("j", $this->local_time);
		
		$is_current_month = ($cur_year == $year AND $cur_month == $month) ? TRUE : FALSE;
	
		// Generate the template data array
		$this->parse_template();
	
		// Begin building the calendar output						
		$out = $this->replacements['table_open'];
		$out .= "\n";	

		$out .= "\n";		
		$out .= $this->replacements['heading_row_start'];
		$out .= "\n";
		
		// "previous" month link
		if ($this->show_next_prev == TRUE)
		{
			// Add a trailing slash to the  URL if needed
			$this->next_prev_url = preg_replace("/(.+?)\/*$/", "\\1/",  $this->next_prev_url);
		
			$adjusted_date = $this->adjust_date($month - 1, $year);
			$out .= str_replace('{previous_url}', $this->next_prev_url.$adjusted_date['year'].'/'.$adjusted_date['month'], $this->replacements['heading_previous_cell']);
			$out .= "\n";
		}

		// Heading containing the month/year
		$colspan = ($this->show_next_prev == TRUE) ? 5 : 7;
		
		$this->replacements['heading_title_cell'] = str_replace('{colspan}', $colspan, $this->replacements['heading_title_cell']);
		$this->replacements['heading_title_cell'] = str_replace('{heading}', $this->get_month_name($month)."&nbsp;".$year, $this->replacements['heading_title_cell']);
		
		$out .= $this->replacements['heading_title_cell'];
		$out .= "\n";

		// "next" month link
		if ($this->show_next_prev == TRUE)
		{		
			$adjusted_date = $this->adjust_date($month + 1, $year);
			$out .= str_replace('{next_url}', $this->next_prev_url.$adjusted_date['year'].'/'.$adjusted_date['month'], $this->replacements['heading_next_cell']);
		}

		$out .= "\n";		
		$out .= $this->replacements['heading_row_end'];
		$out .= "\n";

		// Write the cells containing the days of the week
		$out .= "\n";	
		$out .= $this->replacements['week_row_start'];
		$out .= "\n";

		$day_names = $this->get_day_names();

		for ($i = 0; $i < 7; $i ++)
		{
			$out .= str_replace('{week_day}', $day_names[($start_day + $i) %7], $this->replacements['week_day_cell']);
		}

		$out .= "\n";
		$out .= $this->replacements['week_row_end'];
		$out .= "\n";

		// Build the main body of the calendar
		while ($day <= $total_days)
		{
			$out .= "\n";
			$out .= $this->replacements['cal_row_start'];
			$out .= "\n";

			for ($i = 0; $i < 7; $i++)
			{
				$out .= ($is_current_month == TRUE AND $day == $cur_day) ? $this->replacements['cal_cell_start_today'] : $this->replacements['cal_cell_start'];
			
				if ($day > 0 AND $day <= $total_days)
				{ 					
					$out .= "<div onMouseOver=\"$('new-$day').show(); return false;\" onMouseOut=\"$('new-$day').hide(); return false;\" style='height: 100%'>
							<span class='day'>$day</span>";
					if (isset($data[$day]))
					{	
						// Cells with content
						//$temp = ($is_current_month == TRUE AND $day == $cur_day) ? $this->replacements['cal_cell_content_today'] : $this->replacements['cal_cell_content'];
						//$out .= str_replace('{day}', $day, str_replace('{content}', $data[$day], $temp));
						
						foreach($data[$day] as $row) {
							$out .= "<div style='margin-left: 3px; padding: 2px; '>
								<span style='background: $row[color]; -moz-border-radius: 3px;'>&nbsp;&nbsp;&nbsp;</span> 
								<a href='".site_url("backoffice/events/edit/$row[id]")."' id='event-$row[id]'  rel='facebox' title='View and edit this event'>$row[title]</a></div>
								";
						}
						$out.= "<div id='new-$day' class='calendar-new-link' style='display: none;margin-left: 3px;'>
							<a href='".site_url("backoffice/events/add/$year/$month/$day")."' rel='facebox'>+ new</a></div>";
					}
					else
					{
						$out .= "<div id='new-$day' style='display: none; margin-left: 3px;' class='calendar-new-link'>
							<a href='".site_url("backoffice/events/add/$year/$month/$day")."' rel='facebox'>+ new</a></div>";
						// Cells with no content
						//$temp = ($is_current_month == TRUE AND $day == $cur_day) ? $this->replacements['cal_cell_no_content_today'] : $this->replacements['cal_cell_no_content'];
						//$out .= str_replace('{day}', "<span class='day'>$day</span>", $temp);
					}
					$out .= '</div>';
					
					
					
				}
				else
				{
					// Blank cells
					$out .= $this->replacements['cal_cell_blank'];
				}
				
				$out .= ($is_current_month == TRUE AND $day == $cur_day) ? $this->replacements['cal_cell_end_today'] : $this->replacements['cal_cell_end'];					  	
				$day++;
			}
			
			$out .= "\n";		
			$out .= $this->replacements['cal_row_end'];
			$out .= "\n";		
		}

		$out .= "\n";		
		$out .= $this->replacements['table_close'];

		return $out;
	}
}
/* End of file MY_Calendar.php */
/* Location: ./application/libraries/MY_Calendar.php */
