<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Categories_model extends MY_Model {
	
	public $module = 'posts';
	private $table_cat = 'categories';
	private $tree_rows = NULL;
	
	function __construct(){
        // Call the Model constructor
        parent::__construct();
    }
    
	function setModule($module_name){
		$this->module = $module_name;
	}
	
   	function getCategories(){
		return $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE cat_type='$this->module'");
   	}
   	
   	/**
   	 * Get a single category by id or slug.
   	 *
   	 * @param mixed $category
   	 * @return result
   	 */
	function getCategory($category){

		if(is_numeric($category))
   			$where = "id=$category";
   		elseif(is_string($category))
   			$where = "slug='$category'";
   		elseif(is_null($category))
   			$where = "slug='Uncategorized'";

		$res = $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $where");

		return $res;
   	}
   	
	/**
   	 * Get the count of uncategorized posts, events etc.
   	 *
   	 * @return int
   	 */
	function getUncategorized(){
		$query = "SELECT count(*) cnt FROM `" . $this->db->dbprefix($this->module) . "` WHERE category='Uncategorized' OR category='0'";
		return $this->db->query($query)->first_row()->cnt;
	}
   	
   	/**
   	 * Build the hierarchical category tree.
   	 *
   	 * @param mixed $root		The desired top level
   	 * @param int $num_levels	Number of levels deep
   	 */
	function buildTree($root=NULL, $num_levels=NULL) {  
		//reset array
		$this->tree_rows = array();
		
		//category id
		if(is_numeric($root)){
			$where = "id=$root";
			$factor = 0;
		}
		//category name
		elseif(is_string($root)){
			$where = "category='$root'";
			$factor = 0;
		}
		//default root category
		else {
			$where = "category='_".$this->module."-categories'";
			$factor = 1;
		}
		//get rgt and lft values. ie. root node.
		$row = $this->db->query("SELECT lft, rgt FROM `" . $this->db->dbprefix($this->table_cat) . "`  
			WHERE $where AND cat_type='$this->module'")->first_row('array');
		
		// start with an empty $right stack  
		$right = array();
	 	
		// now, retrieve all descendants of the $root node  
		$result = $this->db->query("SELECT c.id , c.cat_type, c.category, c.parent, c.lft, c.rgt, c.descrip, c.slug, (
				SELECT count(*) FROM  `" . $this->db->dbprefix($this->module) . "`  WHERE category=c.id
			) cnt FROM `" . $this->db->dbprefix($this->table_cat) . "` c
			WHERE c.lft BETWEEN $row[lft] AND $row[rgt] 
			AND c.cat_type='$this->module' ORDER BY c.lft ASC");  
	 
		// display each row  
		foreach($result->result_array() as $row){
	       // only check stack if there is one  
	       if (count($right)>0) {  
	           // check if we should remove a node from the stack  
	           while ($right[count($right)-1]<$row['rgt']) {  
	               array_pop($right);  
	           }  
	       }

	       if($num_levels == NULL || count($right)-$factor < $num_levels )
			//save data to array
			$this->tree_rows[] = array(
	 			'id'=>$row['id'],
	 			'cat_type' => $row['cat_type'],
	 			'category' => $row['category'],
	       		'parent' => $row['parent'],
	 			'level' => count($right)-$factor,
	 			'slug' => $row['slug'],
	 			'descrip' => $row['descrip'],
	       		'count' => $row['cnt']
	 		);
	       // add this node to the stack  
	       $right[] = $row['rgt'];  
   		}
   	}
   	
	/**
	 * Get the hierarchical tree as an HTML dropdown list
	 *
	 * @param id $current_id
	 * @return string
	 */
   	function getTreeDD($current_id=null){
   		if($this->tree_rows == NULL)
   			$this->buildTree();

		$ret='';
   		foreach($this->tree_rows as $cat){ 
			$ret .= "<option value='$cat[id]' ".
				(($cat['id'] == $current_id) ? 'selected' : '').'>';

			if ($cat['level']>0) 
				$ret .=str_repeat('&nbsp;&nbsp;', $cat['level']);
			else
				$ret .= '';
								
			if($cat['category'] == '_'.$this->module.'-categories')
				$ret .= 'None';
			else 
				$ret .= $cat['category'];
				
			$ret .= '</option>';
   		}

   		return $ret;
   	}
   	
   	/**
   	 * Get the hierarchical tree as an array
   	 *
   	 * @return array
   	 */
   	function getTreeRows(){
   		if($this->tree_rows == NULL)
   			$this->buildTree();

   		return $this->tree_rows;
   	}
   	
	/**
	 * Sort a multidimensional array by a specific field.
	 * Prototype array: array(0 => array('field1'=>'value1', ...), ...)
	 * Best used for a query result that needs to be sorted, but cannot
	 * be sorted by the database, ie. timestamp in a text field.
	 *
	 * @param array $original
	 * @param string $field
	 * @param bool $sort_type ['ASC'|'DESC']
	 * @return array
	 */
	function sortArrayByField($original, $field, $sort_type = 'ASC'){
		$sortArr = array();
		$resultArr = array();
		
		foreach((array)$original as $key => $value)
			$sortArr[$key] = $value[$field];
		
		if($sort_type == 'DESC')
			arsort($sortArr);
		else
			asort($sortArr);
          
		foreach($sortArr as $key => $value)
			$resultArr[$key] = $original[$key];
       
		return $resultArr;
	}
	
	/**
	 * Save changes to a category. If it doesn't exist, insert it.
	 *
	 * @param int $id
	 * @return unknown
	 */
	function save($cat_id=NULL){

		$data = array(
			'cat_type' => $this->module,
			'category' => $_POST['category'],
			'descrip' => (isset($_POST['descrip'])) ? $_POST['descrip']: 'quickly categorie',
			'slug' => url_title(strtolower($_POST['category'])),
			'color' => (isset($_POST['color'])) ?  $_POST['color'] : NULL
		);

		$query = $this->db->get_where($this->db->dbprefix($this->table_cat), array('category'=>$data['category'], 'cat_type'=>$data['cat_type']));
		// if category exist no save !!! doublon ???
		if( $query->num_rows() ===0){
			if($cat_id == NULL){
				echo $cat_id;
				//insert the new category
				$this->insert($_POST['parent']);
				$id = $this->db->insert_id();
				$cat_id = $id;
			}
			
			$this->db->update($this->db->dbprefix($this->table_cat), $data, array('id'=>$cat_id));
			
			return (isset($id)) ? $id : NULL;			
		}
		return	NULL;
	}
	
	/**
	 * Insert a new category
	 *
	 * @param int $parent_id
	 */
   	function insert($parent_id=0){

   		$row = $this->db->query("SELECT rgt, category FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE id=$parent_id AND cat_type='$this->module'")->first_row();
   		$right = $row->rgt;
		$category = $row->category;
			
   		if($right == null || $right == '')
   			$right = 1;
   		
   		$this->db->query("UPDATE `" . $this->db->dbprefix($this->table_cat) . "` SET rgt=rgt+2 WHERE rgt>=$right AND cat_type='$this->module'"); 
		$this->db->query("UPDATE `" . $this->db->dbprefix($this->table_cat) . "` SET lft=lft+2 WHERE lft>=$right AND cat_type='$this->module'");
		
		$this->db->query("INSERT INTO `" . $this->db->dbprefix($this->table_cat) . "` (category,cat_type,parent,lft,rgt) 
			values('$category','$this->module',$parent_id,$right,".($right+1).")");
   	}
   	
   	/**
   	 * Delete a category
   	 *
   	 * @param int $cat_id
   	 */
   	function delete($cat_id){
   		//get current category info
   		$row = $this->db->query("SELECT parent,lft, rgt, (rgt-lft+1) width FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE id=$cat_id AND cat_type='$this->module'")->first_row();
   		//delete current category
   		$this->db->query("DELETE FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE lft BETWEEN $row->lft AND $row->rgt AND cat_type='$this->module'");
		//adjust affected parent/child categories
		$this->db->query("UPDATE `" . $this->db->dbprefix($this->table_cat) . "` SET rgt=rgt - $row->width WHERE rgt > $row->rgt AND cat_type='$this->module'");
		$this->db->query("UPDATE `" . $this->db->dbprefix($this->table_cat) . "` SET lft=lft - $row->width WHERE lft > $row->rgt AND cat_type='$this->module'");
      $this->db->query("UPDATE `" . $this->db->dbprefix($this->module) . "` SET category=$row->parent WHERE category=$cat_id");
   	}
   	
   	/**
   	 * Get the path to a category node
   	 *
   	 * @param mixed $category
   	 * @return result
   	 */
   	function getPath($category){
   		//get the current category info
   		$row = $this->getCategory($category)->first_row();

		//now get the path (using the above info)		
		if($row)
			return $this->db->query("SELECT id, category, slug FROM `" . $this->db->dbprefix($this->table_cat) . "`  
				WHERE lft < $row->lft AND rgt > $row->rgt and cat_type='$this->module' ORDER BY lft ASC");
		else
			return $row;
   	}
   	
   	/**
   	 * Make an HTML breadcrumb trail.
   	 *
   	 * $category can be the slug, or id. Remember to use the id
   	 * if the category name exists more than once.
   	 * 
   	 * @param mixed $category
   	 * @return string
   	 */
   	function breadCrumbs($category){
		$crumbs='';
		if($this->getPath($category)){
			foreach($this->getPath($category)->result() as $path){
				if($path->category == '_'.$this->module.'-categories')
					$crumbs = "<li><a href='".site_url('backoffice/'.$this->module.'/category/ALL')."'>All</a></li>";
				else
					$crumbs .= "<li><a href='".site_url("backoffice/".$this->module."/category/$path->id")."'>$path->category</a></li>";

				
			}
			
			$row = $this->getCategory($category)->first_row();
			($crumbs=='') ?$crumbs = "<li><a href='".site_url('backoffice/'.$this->module.'/category/ALL')."'>All</a></li>": '';
			return "<ul id='crumbs'>" .$crumbs. "<li>$row->category</li></ul>";
		}
		else
			return "<ul id='crumbs'><li><a href='".site_url('backoffice/'.$this->module.'/category/ALL')."'>All</a></li></ul>";
   	}
}

/* End of file categories_model.php */
/* Location: ./application/models/categories_model.php */
