<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Contacts_model extends MY_Model{

    public $table_cts 	= 'contacts'; // exemple integrated into SQL  `' . $this->db->dbprefix($this->table_cts) . '`
    public $table_cat 	= 'categories';
	
	public function __construct(){
		parent::__construct();
	}
	
	
	/**
	 * Gets all posts based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return contact with the specified id(s)
	 *   Default: none
	 * name (string)(optional)
	 *   Return contact with the specified name
	 *   Default: none
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 100
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	public function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		
		//contact id
		if(isset($args['id']) && $args['id'] != NULL){
			$this->db->where_in($this->db->dbprefix($this->table_cts) . '.id', $args['id']);
		}
		//contact name (1 contact only)
		if(isset($args['name']) && $args['name'] != NULL){
			$this->db->where_in($this->db->dbprefix($this->table_cts) . '.name', $args['name']);
		}
		
		//categories in
		if(isset($args['category_in']) && $args['category_in'] != NULL){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = $posts_field . ' IN ( SELECT '.$cats_field.' FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE (';
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$cat.' 
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$cat.'" 
						)';
				}
			}
			else {
				//single category
				$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$args["category_in"].'" 
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$args["category_in"].'" 
						)';
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in']) && $args['category_not_in'] != NULL){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = $posts_field.' NOT IN ( SELECT '.$cats_field.' FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE (';
			if(is_array($args['category_not_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$cat.'" 
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$cat.'" 
						)';
				}
			}
			else {
				//single category
				$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$args["category_not_in"].'" 
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE '.$cats_field.'="'.$args["category_not_in"].'" 
						)';
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//omit following criteria if only counting rows
		if(isset($args['count']) && $args['count'] == NULL || isset($args['count']) && $args['count'] === FALSE){
			//order by
			$this->db->order_by( (!isset($args['order_by'])) ? 'name' : $args['order_by'] );
			//limit/offset
			if(isset($args['limit']) && $args['limit'] != NULL)
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}
		
		$this->db->from($this->db->dbprefix($this->table_cts));
		$this->db->join($this->db->dbprefix($this->table_cat), $this->db->dbprefix($this->table_cts) . '.category=categories.id', 'left outer');
		
		if(isset($args['count']) && $args['count'] == TRUE){
			return $this->db->count_all_results();
		} else {
			$this->db->select('contacts.id, contacts.name, contacts.email, contacts.timestamp,
				contacts.url, contacts.about,coalesce('.$this->db->dbprefix($this->table_cat).'.category, "Uncategorized") category, 
				coalesce('.$this->db->dbprefix($this->table_cat).'.id, 0) cat_id, 
				coalesce('.$this->db->dbprefix($this->table_cat).'.slug, "Uncategorized") cat_slug', FALSE);
			return $this->db->get();
		}
	}
	
	/**
	 * Save or insert a contact
	 *
	 * @param int $contact_id
	 * @return string
	 */
	public function save($contact_id){

		if($contact_id == NULL || $contact_id == 0){
			return $this->db->insert($this->db->dbprefix($this->table_cts), $_POST);
		}
		else {
			return $this->db->update($this->db->dbprefix($this->table_cts), $_POST, array('id'=>$contact_id));
		}
	}
	
	
	/**
	 * Delete a contact
	 *
	 * @param int $contact_id
	 * @return unknown
	 */
	public function delete($contact_id){
		//delete the contact
		if( $this->db->delete($this->db->dbprefix($this->table_cts), array('id'=>$contact_id)) )
			return "Contact deleted.";
		else
			return "There was an error deleting the contact.";
	}
	
	/**
	 * Get a contact
	 *
	 * @deprecated use get('id=4')
	 * 
	 * @param unknown_type $id
	 * @return unknown
	 */
	public function getContact($id){
		return $this->db->get_where($this->db->dbprefix($this->table_cts), array('id' => $id));
	}
	
	/**
	 * Get All Contacts
	 * 
	 * @deprecated use getContacts('order=name')
	 *
	 * @param unknown_type $order
	 * @return unknown
	 */
	public function getAllContacts($order='name'){
		$q = 'SELECT l.id, l.name, l.url, coalesce(c.category, "Uncategorized") category, l.timestamp, c.id cat_id FROM `' . $this->db->dbprefix($this->table_cts) . '` l
			LEFT OUTER JOIN `' . $this->db->dbprefix($this->table_cat) . '` c on l.category = c.id 
			ORDER BY ' .$order;
			$result = $this->db->query($q);
			return $result;
	}
	
	/**
	 * Get contacts by category
	 * 
	 * @deprecated use get('category_in=some-category')
	 *
	 * @param unknown_type $slug
	 * @param unknown_type $limit
	 * @param unknown_type $order
	 * @return unknown
	 */
	public function getContactsByCategory($slug, $limit=100, $order='name, timestamp DESC'){
		if($limit)
			$opts = ' LIMIT ' . $limit;
		
		$query = $this->db->query('SELECT l.id, l.name, l.url, coalesce(c.category, "Uncategorized") category, l.timestamp, c.id cat_id FROM `' . $this->db->dbprefix($this->table_cts) . '` l
			LEFT OUTER JOIN `' . $this->db->dbprefix($this->table_cat) . '` c on l.category = c.id 
			WHERE c.slug = '.$slug.' 
			ORDER BY '.$order.' '.$opts);
		return $query;
	}
	
	/**
	 * Get contacts
	 * 
	 * @deprecated use get($args)
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	public function getContacts( $args ){
		return $this->get($args);
	}
}
