<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Events_model extends MY_Model {
	 
            public $tb_evts='events';// exemple integrated into SQL  `" . $this->db->dbprefix($this->tb_cat) . "`
            public $tb_evtsw='events_view';
            public $tb_loc='locations';
            public $tb_opts='options';            
            public $tb_cat='categories';	
            
	function __construct(){
        parent::__construct();
    }
    
   /**
	 * Gets events based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return events with the specified id(s)
	 *   Default: none
	 * slug (string)(optional)
	 *   Return event with the specified slug
	 *   Default: none
	 * upcoming_only (bool)(optional)
	 * 	 Return only upcoming events, if true
	 *   Default: FALSE
	 * category_in (string|int|array)(optional)
	 *   Return events in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return events NOT in specified category slug or category id.
	 *   Default: none
	 * in_archive ( string(year) | array(year=>2009,month=>12) )(optional)
	 *   Return events in a year/month based archive
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return eve nts ordered by the specified order
	 *   Default: start_timestamp
	 * limit (string)(optional)
	 * 	 Limit the number of returned events. also includes offset.
	 *   Default: 0, 100
	 * count (bool)(optional)
	 * 	 If this is true, the number of rows will be returned instead of a db result
	 *   Default: false
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	function get( $args ){
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
	
		//event id
		if(isset($args['id'])){
			$this->db->where_in('id', $args['id']);
		}
		//event slug (1 event only)
		if(isset($args['slug'])){
			$this->db->where_in('slug', $args['slug']);
		}
		//categories in
		if(isset($args['category_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? 'cat_id' : 'cat_slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 4);
				
			$where = "$posts_field IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in']) && $args['category_not_in'] != NULL){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'cat_id' : 'cat_slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 4);
				
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//in_archive
		if(isset($args['in_archive'])){
			if(is_array($args['in_archive'])){
				$this->db->where('YEAR(start_timestamp)', $args['in_archive']['year']);
				if($args['in_archive']['month'])
					$this->db->where('MONTH(start_timestamp)', $args['in_archive']['month']);
			} else {
				$this->db->where('YEAR(start_timestamp)', $args['in_archive']);
			}
		}
		
		//omit following criteria if only counting rows
		if(!isset($args['count']) ||  $args['count'] === FALSE){
			//order by

			$this->db->order_by( (!isset($args['order_by'])) ? 'start_timestamp' : $args['order_by'], 'asc' );
			//limit/offset
			if(isset($args['limit']))
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}
		//upcoming events only
		if(isset($args['upcoming_only']) && $args['upcoming_only']){
			$this->db->where("end_timestamp >=NOW()");
		}
		
		if(isset($args['count']) && $args['count'] == TRUE){
			$this->db->from($this->db->dbprefix($this->tb_evtsw));
			return $this->db->count_all_results();
		} else {
			return $this->db->get($this->db->dbprefix($this->tb_evtsw));
		}
	}
    
    /**
     * Get the id of a location
     *
     * @param string $name
     * @return int
     */
	function getLocationID($name){
		$name = mysql_escape_string($name);
		
		if($name == NULL)
			return 0;
		
		$query = $this->db->query("SELECT id FROM `" . $this->db->dbprefix($this->tb_loc) . "` WHERE name LIKE '$name'");
				
		if($query->num_rows() == 0) {
			$this->db->insert($this->db->dbprefix($this->tb_loc), array('name'=>$name));
			return $this->db->insert_id();
		}
		else {
			$row = $query->first_row();
			return $row->id;
		}
	}
	
	
	function getLocations($name){
		$name = mysql_escape_string($name);
		//search by id
		if(is_numeric($name))
			return $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->tb_loc) . "` WHERE id=$name ORDER BY name");
		//search by name
		else
			return $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->tb_loc) . "` WHERE name LIKE '%$name%' ORDER BY name");
	}
	
	
	
	function saveLocation($loc_id){
		$this->db->update($this->db->dbprefix($this->tb_loc), $_POST, array('id'=>$loc_id));
	}
	
	function deleteLocation($loc_id){
		//remove location
		$this->db->delete($this->db->dbprefix($this->tb_loc), array('id'=>$loc_id));
		//update events
		$this->db->update($this->db->dbprefix($this->tb_evts), array('location'=>0), array('location'=>$loc_id));
	}
	
	function getTimes($time){
		return $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->tb_opts) . "` WHERE category='time' AND option_value LIKE '$time%'");
	}
	
	function saveEvent($id=NULL){
		//get location id
		$location_id = $this->getLocationID($_POST['location']);
		
		$data = array(
			'title'=>$_POST['title'],
			'start_timestamp'=>date('Y-m-d H:i:s', strtotime($_POST['start_date'] .' ' .$_POST['start_time'])),
			'end_timestamp'=>date('Y-m-d H:i:s', strtotime($_POST['end_date'] .' ' .$_POST['end_time'])),
			'descrip'=>$_POST['descrip'],
			'category'=>$_POST['category'],
			'location'=>$location_id,
			'modified_by'=> $this->session->userdata('display_name'),
			'modified_timestamp' => date('Y-m-d H:i:s')
		);

		//new event, insert
		if($id == 0 || $id == NULL) {
			$data['added_by'] = $this->session->userdata('display_name');
			$data['added_timestamp'] = date('Y-m-d H:i:s');
			$this->db->insert($this->db->dbprefix($this->tb_evts), $data);
			$id = $this->db->insert_id();
			$message = 'Your event was created.';
		}
		//existing event, update
		else {
			$this->db->update($this->db->dbprefix($this->tb_evts), $data, array('id'=>$id));
			$message = 'Your event was updated.';
		}
		
		//check for image, do upload
		if($_FILES['userfile']['name'] != null){
			$this->load->library('upload', array('upload_path'=>$this->getOption('file_upload_path'),'allowed_types'=>'jpg'));	
			
			if (!$this->upload->do_upload())
				$message .= '<br/>' . $this->upload->display_errors();
			else {
				$upload_data = $this->upload->data();
				//save img name to db
				$this->db->update('events', array('image'=>$upload_data['raw_name']), array('id'=>$id));
				//create thumbnail
				$config['image_library'] = 'gd2';
				$config['source_image'] = $this->options['file_upload_path'] . $upload_data['file_name'];
				$config['create_thumb'] = TRUE;
				$config['maintain_ratio'] = TRUE;
				$config['width'] = 150;
				$config['height'] = 150;
				
				$this->load->library('image_lib', $config);
				
				$this->image_lib->resize();
			}
		}
		
		return array(
			'month' => date('m', strtotime($_POST['start_date'])),
			'year' => date('Y', strtotime($_POST['start_date'])),
			'message' => $message
		);
	}
	
	
	function deleteEvent($id){
		//get event info
		$result = $this->db->get_where($this->db->dbprefix($this->tb_evts), array('id'=>$id));
		$row = $result->first_row('array');
		//delete event info
		$this->db->delete($this->db->dbprefix($this->tb_evts), array('id'=>$id));
		$deleted_rows = $this->db->affected_rows();
		//delete image(s)
		if(file_exists($this->options['file_upload_path'] . $row['image']. '.jpg'))
			unlink($this->options['file_upload_path'] . $row['image']. '.jpg');
		if(file_exists($this->options['file_upload_path'] . $row['image']. '_thumb.jpg'))
			unlink($this->options['file_upload_path'] . $row['image']. '_thumb.jpg');
		
		return array('message'=>$deleted_rows . ' event deleted.');
	}
	
	function getEventsInMonth($month, $year){
		
		$this->links = $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->tb_evtsw) . "` WHERE 
			(MONTH(start_timestamp) = $month AND YEAR(start_timestamp) = $year) OR 
			(MONTH(end_timestamp) = $month AND YEAR(end_timestamp) = $year)");
			
		return $this->links;
	}
	
	/**
	 * Get events
	 * 
	 * @deprecated use get( $args )
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	function getEvents( $args ){
		return $this->get( $args );
	}
}
