<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

 class Links_model extends MY_Model{

 
    public $table_lnk 	= 'links'; // example integrated into SQL  `' . $this->db->dbprefix($this->table) . '`
    public $table_cat 	= 'categories';

	
	function __construct(){
		parent::__construct();
	}
	
	
	/**
	 * Gets all posts based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return link with the specified id(s)
	 *   Default: none
	 * name (string)(optional)
	 *   Return link with the specified name
	 *   Default: none
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 100
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		 
		//link id
		if(isset($args['id'])){
			$this->db->where_in('links.id', $args['id']);
		}
		//link name (1 link only)
		if(isset($args['name'])){
			$this->db->where_in('links.name', $args['name']);
		}
		
		//categories in
		if(isset($args['category_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = "$posts_field IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in']) && ($args['category_not_in'] != NULL)){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE (";
			if(is_array($args['category_not_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//omit following criteria if only counting rows
		if(!isset($args['count']) ||  $args['count'] === FALSE){
			//order by
			$this->db->order_by( (!isset($args['order_by'])) ? 'name' : $args['order_by'] );
			//limit/offset
			if(isset($args['limit']))
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}
		
		$this->db->from($this->db->dbprefix($this->table_lnk));
		$this->db->join($this->db->dbprefix($this->table_cat), 'links.category=categories.id', 'left outer');
		
		if(isset($args['count']) && $args['count'] == TRUE){
			return $this->db->count_all_results();
		} else {
			$this->db->select("links.id, links.name, links.url, links.email_address, links.timestamp, 
				links.descrip, links.image, links.filename,links.filetype, links.image_url, links.rss_url, links.private,
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.category, 'Uncategorized') category, 
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.id, 0) cat_id, 
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.slug, 'Uncategorized') cat_slug", FALSE);
			return $this->db->get();
		}
	}

	
	function searchLinks($search_str='', $limit=100, $order='name, timestamp DESC'){
		
		if($limit)
			$this->db->limit($limit);
				
		$where = "links.descrip LIKE '%".$search_str."%'";			
		//$where = "MATCH (p.detail) AGAINST ('$search_str')";
		$this->db->where($where, NULL, FALSE);	
		//order by
		$this->db->order_by($order);
		
		$this->db->from($this->db->dbprefix($this->table_lnk));
		$this->db->join($this->db->dbprefix($this->table_cat), 'links.category=categories.id', 'left outer');
				
			$this->db->select("links.id, links.name, links.url, links.email_address, links.timestamp, 
				links.descrip, links.image, links.filename,links.filetype, links.image_url, links.rss_url, links.private,
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.category, 'Uncategorized') category, 
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.id, 0) cat_id, 
				coalesce(`" . $this->db->dbprefix($this->table_cat) . "`.slug, 'Uncategorized') cat_slug", FALSE);
			return $this->db->get();

	}
	
	/**
	 * Save or insert a link
	 *
	 * @param int $link_id
	 * @return string
	 */
	function save($link_id){

		if($link_id == NULL || $link_id == 0)
			return $this->db->insert($this->db->dbprefix($this->table_lnk), $_POST);
		else 
			return $this->db->update($this->db->dbprefix($this->table_lnk), $_POST, array('id'=>$link_id));
	}
	
	/**
	 * Delete a link
	 *
	 * @param int $link_id
	 * @return unknown
	 */
	function delete($link_id){
		//delete the link
		if( $this->db->delete($this->db->dbprefix($this->table_lnk), array('id'=>$link_id)) )
			return "Link deleted.";
		else
			return "There was an error deleting the link.";
	}
	
	/**
	 * Get a link
	 *
	 * @deprecated use get('id=4')
	 * 
	 * @param unknown_type $id
	 * @return unknown
	 */
	function getLink($id){
		return $this->db->get_where($this->db->dbprefix($this->table_lnk), array('id' => $id));
	}
	
	/**
	 * Get All Links
	 * 
	 * @deprecated use getLinks('order=name')
	 *
	 * @param unknown_type $order
	 * @return unknown
	 */
	function getAllLinks($order='name'){
		$q = "SELECT l.id, l.name, l.url, l.email_address, coalesce(c.category, 'Uncategorized') category, l.timestamp, c.id cat_id FROM `" . $this->db->dbprefix($this->table_lnk) . "` l 
			LEFT OUTER JOIN `" . $this->db->dbprefix($this->table_cat) . "` c on l.category = c.id 
			ORDER BY " . $order;
			$result = $this->db->query($q);
			return $result;
	}
	
	/**
	 * Get links by category
	 * 
	 * @deprecated use get('category_in=some-category')
	 *
	 * @param unknown_type $slug
	 * @param unknown_type $limit
	 * @param unknown_type $order
	 * @return unknown
	 */
	function getLinksByCategory($slug, $limit=100, $order='name, timestamp DESC'){
		if($limit)
			$opts = " LIMIT $limit";
		
		return $this->db->query("SELECT l.id, l.name, l.url, coalesce(c.category, 'Uncategorized') category, l.timestamp, c.id cat_id FROM `" . $this->db->dbprefix($this->table_lnk) . "` l 
			LEFT OUTER JOIN `" . $this->db->dbprefix($this->table_cat) . "` c on l.category = c.id 
			WHERE c.slug = '$slug'
			ORDER BY $order $opts");
	}
	
	/**
	 * Get links
	 * 
	 * @deprecated use get($args)
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	function getLinks( $args ){
		return $this->get($args);
	}
}
