<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Medias_model extends MY_Model{
	
	public function __construct(){
		parent::__Construct();
	}
	
	/**
	 * Gets all media based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return link with the specified id(s)
	 *   Default: none
	 * name (string)(optional)
	 *   Return link with the specified name
	 *   Default: none
	 * type (string)(optional)
	 *   Return media of the specified file type
	 *   Default: none
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 100
	 * 
	 * @param mixed $args 
	 * @return object
	 */

    public $table_medias='medias';
	public $table_cat='categories';
	public $table_user='users';
	

        //$this->db->dbprefix($this->table_user)
        
	public function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		
		//media id
		if(isset($args['id'])){
			$this->db->where_in('medias.id', $args['id']);
		}
		
		//link name (1 link only)
		if(isset($args['name'])){
			$this->db->where_in('medias.filename', $args['name']);
		}
		
		//categories in
		if(isset($args['category_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? $this->db->dbprefix($this->table_cat) . '.id' : $this->db->dbprefix($this->table_cat) . '.slug';
			//id or slug in categories table
			$options = explode('.', $posts_field);
			$cats_field = $options[1];
				
			$where = "$posts_field IN ( SELECT $cats_field FROM ".$this->db->dbprefix($this->table_cat)." WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM ".$this->db->dbprefix($this->table_cat)." WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		if(isset($args['type'])){
			$this->db->where_in('medias.filetype', $args['type']);
		}
		//omit following criteria if only counting rows
		if(!isset($args['count']) || $args['count'] === FALSE){
			//order by
			$this->db->order_by(!isset($args['order_by']) ? 'date_uploaded DESC' : $args['order_by'] );
			//limit/offset
			if(isset($args['category_in']) || isset($args['limit']))
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}		
	
		
		$result=$this->db->from($this->db->dbprefix($this->table_medias));
		$this->db->join($this->db->dbprefix($this->table_cat), 'medias.category=categories.id', 'left outer');
		$this->db->join($this->db->dbprefix($this->table_user), 'medias.username=users.display_name', 'left outer');
		
		if(isset($args['count']) && $args['count'] == TRUE){
			return $this->db->count_all_results();
		} else {
			$this->db->select("medias.id, medias.filename, medias.filetype, medias.filesize, medias.date_uploaded, 
				medias.title, medias.descrip, medias.downloaded, medias.allowdownload, 
				coalesce( ".$this->db->dbprefix($this->table_cat).".category, 'Uncategorized') category, 
				coalesce( ".$this->db->dbprefix($this->table_cat).".id, 0) cat_id, 
				coalesce( ".$this->db->dbprefix($this->table_cat).".slug, 'Uncategorized') cat_slug,
				users.display_name", FALSE);
				
			
			return $this->db->get();
		}
	}
	
	/**
	 * Get the different filetypes
	 *
	 * @return result
	 */
	public function getMediaTypes(){
		return $this->db->query("SELECT filetype, count(*) cnt FROM ". $this->db->dbprefix($this->table_medias)." GROUP BY filetype");
	}
	
	/**
	 * Save changes, or new media
	 * 
	 * $args can either be an id, or an array
	 *
	 * @param mixed $args
	 */
	public function save( $args ){
		if(is_array($args)){
			//new file(s) uploaded, insert data
			foreach($args as $file=>$data){
				$db_data = array(
					'username'		=> $this->session->userdata('display_name'),
					'filename'		=> strtolower($data['raw_name']),
					'filesize'		=> $data['file_size'],
					'filetype'		=> strtolower(substr($data['file_ext'], 1)),
					'imagesize'		=> $data['image_width'] . 'x' . $data['image_height'],
					'category'		=> $_POST['category'],
					'downloaded'	=> 0,
					'allowdownload' => 0
				);
				$this->db->insert($this->db->dbprefix($this->table_medias), $db_data);
			}
		}
		else {
			$this->db->update($this->db->dbprefix($this->table_medias), $_POST, array('id'=>$args));
		}
	}
	
	/**
	 * Deletes a media file from the db.
	 * 
	 * Use controller function _deleteFile() to 
	 * remove the actual file.
	 *
	 * @param int $id
	 */
	public function delete($id){
		$this->db->delete($this->db->dbprefix($this->table_medias), array('id'=>$id));
	}
	
	/**
	 * Get media
	 * 
	 * @deprecated use get($args)
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	public function getMedia($args){
		
		return $this->get($args);
	}
}
/* End of file medias_model.php */
/* Location: ./application/models/medias_model.php */
