<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Newsletter_model extends MY_Model{

            public $tb_news='newsletter';// exemple integrated into SQL  `' . $this->db->dbprefix($this->table) . '`
            public $tb_cat='categories';

	function __construct(){
		parent::__construct();
	}
	
	/**
	 * Gets all posts based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return link with the specified id(s)
	 *   Default: none
	 * name (string)(optional)
	 *   Return link with the specified name
	 *   Default: none
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 100
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		//newsletter id
      if(isset($args['id']) && $args['id'] != NULL){
			$this->db->where_in($this->db->dbprefix($this->tb_news) . '.id', $args['id']);
		}
		
		//categories in
		if(isset($args['category_in']) && $args['category_in'] != NULL){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
				
			$where = "$posts_field IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in']) && $args['category_not_in'] != NULL){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'categories.id' : 'categories.slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 11);
		
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE (";
			if(is_array($args['category_not_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT rgt FROM `" . $this->db->dbprefix($this->tb_cat) . "` WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
                       
			$this->db->where($where, NULL, FALSE);
		}
		
		//omit following criteria if only counting rows
		if(!isset($args['count']) ||  $args['count'] === FALSE){
			//order by
			$this->db->order_by( (!isset($args['order_by'])) ? 'registered' : $args['order_by'] );
			//limit/offset
			if(isset($args['limit']))
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}
		
		$this->db->from($this->db->dbprefix($this->tb_news));
		//$this->db->join($this->db->dbprefix($this->tb_cat), $this->db->dbprefix($this->tb_news) .'category' = $this->db->dbprefix($this->tb_cat) .'id', 'left outer');
		$this->db->join( $this->db->dbprefix($this->tb_cat), 'newsletter.category=categories.id', 'left outer');

		if(isset($args['count']) && $args['count'] == TRUE){
			return $this->db->count_all_results();
		} else {
			$this->db->select("newsletter.id,newsletter.address, newsletter.registered,
                                newsletter.last_email_sent,newsletter.last_email_status, newsletter.active,
                                newsletter.fail_cnt, newsletter.success_cnt,
				coalesce(`" . $this->db->dbprefix($this->tb_cat) . "`.category, 'Uncategorized') category,
				coalesce(`" . $this->db->dbprefix($this->tb_cat) . "`.id, 0) cat_id,
				coalesce(`" . $this->db->dbprefix($this->tb_cat) . "`.slug, 'uncategorized') cat_slug", FALSE);
			return $this->db->get();
		}
	}
	
	function getSubscribers($limit, $offset){
		return $this->db->query("SELECT * FROM `" . $this->db->dbprefix($this->tb_news) . "` ORDER BY registered LIMIT $offset, $limit");
	}
	
	function getSubscriberCount(){
		return $this->db->count_all( $this->db->dbprefix($this->tb_news));
	}
	
	function delete($id){
		$this->db->delete($this->db->dbprefix($this->tb_news), array('id'=>$id));
	}
	
	function isValidEmail($email){
            return preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$/", $email);
	}
/*	
	function insert($address, $category){
		$address = mysql_escape_string($address);
		
		//validate address
		if(!$this->isValidEmail($address))
			return FALSE;
			
		//see if address already exists
		$row = $this->db->query("SELECT count(*) cnt FROM `" . $this->db->dbprefix($this->tb_news) . "` WHERE address = '$address'")->first_row();
		if($row->cnt > 0)
			return FALSE;
		
		$this->db->insert($this->db->dbprefix($this->tb_news), array('address'=>$address, 'category'=>$category,'active'=>'true'));
		
		return TRUE;
	}
*/	
	function queueMass($data){
		if($_POST['cat_used'])
			$result = $this->get('category_in='.$_POST['msg_category']);
		else 
			$result = $this->get($this->db->dbprefix($this->tb_news));
			
		foreach($result->result_array() as $row){

			if ( $data['function_email'] == TRUE){
				
				if(mail('contact@candlecms.com', $subject, $message, $headers)){
					$data['to_address'] = $row['address'];
					//add addresses to pending table
					$this->db->insert($this->db->dbprefix('email_pending') , $data);
					return TRUE;
				}
				else	return FALSE;
			}
			else{
				$this->load->library('email');
				$this->email->from($this->config->item('newsletter_email'));
				$this->email->to($row['address']);
				$this->email->subject($data['subject']);		
				$this->email->message($data['headers'].$data['message']);

				if ( ! $this->email->send())
				{
					// Generate error
					echo $this->email->print_debugger();
					return FALSE;
				}							
			return TRUE;
			}			
		}
	}
	
	function send($data){

		$config['protocol'] = 'smtp';
	   // $config['protocol'] = 'sendmail';
		$config['smtp_host'] = 'localhost';
	   // $config['smtp_port'] = '25';
		$config['mailpath'] = '/usr/sbin/sendmail';
		$config['charset'] = 'iso-8859-1';
		$config['wordwrap'] = TRUE;

		$modul_lang = 'backoffice';
			
		$subscriber_list = $this->db->get_where($this->db->dbprefix($this->tb_news), array('active'=>'true'))->result_array();

		foreach($subscriber_list as $row){
			//$data['to_address']= $row['address'];
			//$this->db->insert($this->db->dbprefix('email_pending'), $data);

			if ( $data['function_email'] == TRUE){

				if(mail(trim($row['address']), $data['subject'], $data['message'], $data['headers'])){
					return TRUE;
				}
				else	return FALSE;
			}
			else{
				$this->load->library('email');
				$this->email->from($this->config->item('newsletter_email'));
				$this->email->to($row['address']);
				$this->email->subject($data['subject']);		
				$this->email->message($data['headers'].$data['message']);

				if ( ! $this->email->send())
				{
					// Generate error
					echo $this->email->print_debugger();
					return FALSE;
				}			
			return TRUE;
			}
		}
	}
	
	function sendTest($data){


		if ( $data['function_email'] == TRUE){

			if(mail($data['address'], $data['subject'], $data['message'], $data['headers'])){
				return TRUE;
			}
			else return FALSE;
		}
		else{
			$config['protocol'] = 'smtp';
		   // $config['protocol'] = 'sendmail';
			$config['smtp_host'] = 'localhost';
		   // $config['smtp_port'] = '25';
			$config['mailpath'] = '/usr/sbin/sendmail';
			$config['charset'] = 'iso-8859-1';
			$config['wordwrap'] = TRUE;

			$this->load->library('email');
			$this->email->from($this->config->item('app_name_short'));
			$this->email->to($data['address']);
			$this->email->subject($data['subject']);		
			$this->email->message($data['headers'].$data['message']);

			if ( ! $this->email->send())
			{
				// Generate error
				echo $this->email->print_debugger();
				return FALSE;
			}			
		return TRUE;
		}
	}
	

	/**
	 *
	 * get subscribers id
	 *
	 */

	function getSubscriberId($address)
	{
	   $subscriber= $this->db->get_where($this->db->dbprefix($this->tb_news), array('address'=>$address));
	   
	   if($subscriber->num_rows > 0){
			$subscriber=$subscriber->result_array();
			return $subscriber[0]['id'];
	   }
	   else return FALSE;

	}
	
	function updateStatut($id,$statut)
	{
		$this->db->where('id',$id);
		$this->db->update($this->db->dbprefix($this->tb_news),array('active'=>$statut));
	}

	
	function insert($address, $category){
		
	
		/*
		 * or email send 
		 */
		 $subject = "Candlecms - Newsletter Registration";
		 $message= "<html><head></head><body><h1 >Candlecms Newsletter</h1><br /><br />";
		 $headers  = 'MIME-Version: 1.0' . "r\n";
		 $headers .= 'Content-type: text/html; charset=iso-8859-1' . "\r\n";
		 $headers .= "\r\n";

	
		$address = mysql_escape_string($address);

		//validate address
		if(!$this->isValidEmail($address))
			return FALSE;
			
		//see if address already exists
		$row = $this->db->query("SELECT count(*) cnt FROM `" . $this->db->dbprefix($this->tb_news) . "` WHERE address = '$address'")->first_row();
               
		if($row->cnt > 0){
			//reactivate the account
		
			$id=$this->getSubscriberId($address);
			$this->updateStatut ($id, 'true');
			 
			$message .= "Your account have been reactivated ";
			$message.= "</body></hmtl>";

			 mail($address, $subject, $message,$headers);

			return FALSE;

		}
		else{
			$this->db->insert($this->db->dbprefix($this->tb_news), array('address'=>$address, 'category'=>$category,'active'=>'true'));
			
		// send a mail to signale the subscriber about its registration to the newsletter

			$message .= "We are happy to inform you that you have been registered to Candlecms Newsletter";
			$message .= "</body></hmtl>";

			mail($address, $subject, $message,$headers);
		
			return TRUE;

		}
	}
   public function updateSubscribers($id,$data){
     
         $this->db->where('id',$id);
         return $this->db->update($this->db->dbprefix($this->tb_news),$data);
     
   }
	
}
/* End of file newsletter_model.php */
/* Location: ./application/models/newsletter_model.php */
