<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Pages_model extends MY_Model{

    public $table_pg 	= 'pages';
    public $table_cat 	= 'categories';
    public $table_users = 'users';


    	
	function __construct(){
		parent::__construct();
		
				$this->module = 'pages';
				
	}
	
	
	/**
	 * Gets all pages based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return posts with the specified id(s)
	 *   Default: none
	 * slug (string)(optional)
	 *   Return post with the specified slug
	 *   Default: none
	 * published (bool)(optional)
	 * 	 Return all posts or only published posts
	 *   Default: TRUE
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 0, 100
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		
		//page id
		if(isset($args['id'])){
			$this->db->where_in('pages.id', $args['id']);
		}
		//page slug (1 page only)
		if(isset($args['slug'])){
			$this->db->where_in('pages.slug', $args['slug']);
		}
		//lang
		if(isset($args['lang'])){
			$this->db->where_in('pages.lang', $args['lang']);
		}
		//published
		if($args['published'] == TRUE || !isset($args['published'])){
			$this->db->where("timestamp < NOW() and status='Published'");
		}
		//limit/offset
		if(isset($args['limit'])){
			$this->db->limit($args['limit'],$args['offset']);
		} else {
			$this->db->limit(100, 0);
		}
		//categories in
		if(isset($args['category_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? $this->db->dbprefix($this->table_cat) . '.id' :  $this->db->dbprefix($this->table_cat) . '.slug';
			//id or slug in categories table
			$options = explode('.', $posts_field);
			$cats_field = $options[1];

			$where = "$posts_field IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT  DISTINCT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT  DISTINCT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT DISTINCT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT DISTINCT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		//categories in
		if(isset($args['category_not_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? $this->db->dbprefix($this->table_cat) . '.id' :  $this->db->dbprefix($this->table_cat) . '.slug';
			//id or slug in categories table
			$options = explode('.', $posts_field);
			$cats_field = $options[1];
				
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT DISTINCT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						) AND (
							SELECT DISTINCT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT DISTINCT lft FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT DISTINCT rgt FROM `" . $this->db->dbprefix($this->table_cat) . "` WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}

		//order by
		$this->db->order_by( (!isset($args['order_by'])) ? 'timestamp' : $args['order_by'] );
	
		$this->db->select("pages.id, pages.timestamp, pages.lang, pages.status, pages.slug, coalesce( `" . $this->db->dbprefix($this->table_pg) . "`.title, 'Untitled' ) title, 
			pages.detail, coalesce( u.display_name, u.user_id ) display_name, pages.user_id, 
			coalesce( " . $this->db->dbprefix($this->table_cat) . ".category, 'Uncategorized' ) category, " . $this->db->dbprefix($this->table_cat) . ".id cat_id, " . $this->db->dbprefix($this->table_cat) . ".cat_type cat_type,
			coalesce( " . $this->db->dbprefix($this->table_cat) . ".slug, 'Uncategorized' ) cat_slug", FALSE);
		$this->db->from($this->db->dbprefix($this->table_pg));
		$this->db->join($this->db->dbprefix($this->table_users) . ' u', 'u.user_id = pages.user_id', 'left outer');
		$this->db->join($this->db->dbprefix($this->table_cat), $this->db->dbprefix($this->table_cat) . '.id = pages.category', 'left outer');
		
		if(isset($args['count']) && $args['count'] == TRUE){

			
			return $this->db->count_all_results();
		} else {
			return $this->db->get();
		}
	}
	
	function searchPages($search_str){

		$where = "detail LIKE '%".$search_str."%'";			
		//$where = "MATCH (p.detail) AGAINST ('$search_str')";
		$this->db->where($where, NULL, FALSE);	
		//order by
		$this->db->order_by('timestamp', 'DESC');
		
		$this->db->select("p.id, p.timestamp, p.status, p.slug, coalesce( p.title, 'Untitled' ) title, 
			p.detail, coalesce( u.display_name, u.user_id ) display_name, p.user_id, 
			coalesce( c.category, 'Uncategorized' ) category, c.id cat_id, c.cat_type cat_type,
			coalesce( c.slug, 'Uncategorized' ) cat_slug", FALSE);
		$this->db->from('pages p');
		$this->db->join('users u', 'u.user_id = p.user_id', 'left outer');
		$this->db->join('categories c', 'c.id = p.category', 'left outer');
		return $this->db->get();
	}
	
	/**
	 * Save a page.
	 *
	 * @param int $id
	 * @return mixed
	 */
	function save($id){
		//make slug
		$_POST['slug'] = url_title($_POST['title']);
		
		//remove from _POST array
		unset($_POST['new_cat_name']);
		unset($_POST['new_cat_parent']);
		
		if($id == NULL || $id == 0){
			//insert the new post
			$save_result = $this->db->insert($this->db->dbprefix($this->table_pg), $_POST);
		} else {
			$save_result = $this->db->update($this->db->dbprefix($this->table_pg), $_POST, array('id'=>$id));
		}
	}
	
	/**
	 * Delete a page.
	 *
	 * @param int $id
	 * @return string
	 */
	function delete($id){
		//delete post
		$res = $this->db->delete($this->db->dbprefix($this->table_pg), array('id'=>$id));
		
		if($res) 
			return "Page deleted successfully.";
		else
			return "There was an error deleting your page.";
	}

	/**
	 * Get a count of pages
	 * 
	 * @deprecated use get('count=1');
	 *
	 * @param bool $published
	 * @return int
	 */
	function countPages($published=TRUE){
		if($published)
			return $this->db->count_all($this->db->dbprefix($this->table_pg));
		else
			return $this->db->query("
				SELECT count(*) cnt 
				FROM `" . $this->db->dbprefix($this->table_pg) . "`  
				WHERE timestamp < NOW() 
				AND status='Published'
			")->first_row()->cnt;
	}
	
	/**
	 * Get pages
	 * 
	 * @deprecated use get($args);
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	function getPages($args){
		return $this->get($args );
	}
}
