<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Photos_model extends MY_Model{

	public $table_p='photos';
	public $table_cat='categories';
	public $table_users='users';
	public $table_tags='tags';
	public $options=NULL;	

	/**
	 * Class constructor.
	 *
	 */
	public function __construct(){
		parent::__construct();
		
		$this->photo_upload_path = $this->options['image_upload_path'];
	}
	
	/**
	 * Get photos and meta
	 *
	 * @param int $offset
	 * @param int $per_page
	 * @return resource
	 */
	public function getPhotos( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
		
		//page id
		if(isset($args['id'])){
			$this->db->where_in('photos.id', $args['id']);
		}
		//page slug (1 page only)
		if(isset($args['slug'])){
			$this->db->where_in('photos.slug', $args['slug']);
		}
		//limit/offset
		if(isset($args['limit'])){
			$this->db->limit($args['limit'],$args['offset']);
		} else {
			$this->db->limit(100, 0);
		}
		//categories in
		if(isset($args['category_in'])){

			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? $this->db->dbprefix($this->table_cat) . '.id' : $this->db->dbprefix($this->table_cat) . '.slug';
			//id or slug in categories table
			$options = explode('.', $posts_field);
			$cats_field = $options[1];

			$where = "$posts_field IN ( SELECT $cats_field FROM ".$this->db->dbprefix($this->table_cat)." WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_in]'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? $this->db->dbprefix($this->table_cat) . '.id' : $this->db->dbprefix($this->table_cat) . '.slug';
			//id or slug in categories table
			$options = explode('.', $posts_field);
			$cats_field = $options[1];
				
			$where = "$posts_field NOT IN ( SELECT $cats_field FROM ".$this->db->dbprefix($this->table_cat)." WHERE (";
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= "lft BETWEEN (
							SELECT lft FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						) AND (
							SELECT rgt FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$cat'
						)";
				}
			}
			else {
				//single category
				$where .= "lft BETWEEN (
							SELECT lft FROM ". $this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_not_in]'
						) AND (
							SELECT rgt FROM ".$this->db->dbprefix($this->table_cat)." WHERE $cats_field='$args[category_not_in]'
						)";
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
            
		//order by
		$this->db->order_by( (!isset($args['order_by'])) ? 'date_uploaded' : $args['order_by'] );
	
		$this->db->select("photos.id, photos.username, users.display_name, photos.filename, photos.filetype, photos.filesize, COALESCE(".$this->db->dbprefix($this->table_p).".picturetitle, 'Untitled') picturetitle, photos.date_uploaded, photos.imagesize, photos.comments,
			coalesce( " . $this->db->dbprefix($this->table_cat) . ".category, 'Uncategorized' ) category, " . $this->db->dbprefix($this->table_cat) . ".id cat_id, " . $this->db->dbprefix($this->table_cat) . ".cat_type cat_type,
			coalesce( " . $this->db->dbprefix($this->table_cat) . ".slug, 'Uncategorized' ) cat_slug", FALSE);
		$this->db->from($this->db->dbprefix($this->table_p));
		$this->db->join($this->db->dbprefix($this->table_users) , 'users.display_name = photos.username', 'left outer');
		$this->db->join($this->db->dbprefix($this->table_cat), $this->db->dbprefix($this->table_cat) . '.id = photos.category', 'left outer');
		
		if(isset($args['count']) && $args['count'] == TRUE){
			return $this->db->count_all_results();
		} else {
			return $this->db->get();
		}
	}
	
	/**
	 * Get a single photo by photo_id
	 *
	 * @param int $id
	 * @return resource
	 */
	public function getPhoto($id){

            $query = "SELECT p.id, p.username, u.display_name, p.filename, p.filetype, p.filesize, COALESCE(c.category, 'Uncategorized') category, p.category cat_id,
			COALESCE(c.slug, 'uncategorized') cat_slug, COALESCE(p.picturetitle, 'Untitled') picturetitle, p.date_uploaded, p.imagesize, p.comments,
			( SELECT group_concat( tag ORDER BY tag ) FROM ".$this->db->dbprefix($this->table_tags)." WHERE src_id = p.id AND tag_type = 'photos') tags FROM ".$this->db->dbprefix($this->table_p)
                     ." p LEFT OUTER JOIN ".$this->db->dbprefix($this->table_users)." u ON p.username = u.display_name LEFT OUTER JOIN  ".$this->db->dbprefix($this->table_cat)." c ON p.category = c.id";

	    return $this->db->query($query." WHERE p.id = $id");
	}
	
	/**
	 * Get a count of all photos in the db
	 *
	 * @return int
	 */
	public function getCount(){
		return $this->db->count_all($this->db->dbprefix($this->table_p));
	}	
	
	/**
	 * Save title, descrip etc. 
	 *
	 * @param string $field
	 * @param int $id
	 */
	public function save($field, $id){
		$this->db->update($this->db->dbprefix($this->table_p), array($field => $_POST['value']), array('id'=>$id));
	}
	
	public function saveUpload($args){

		if(is_array($args)){
			//new file(s) uploaded, insert data
			foreach($args as $file=>$data){
				$db_data = array(
					'username' => $this->session->userdata('display_name'),
					'filename' => strtolower($data['raw_name']),
					'filesize' => $data['file_size'],
					'filetype'		=> strtolower(substr($data['file_ext'], 1)),
					'imagesize' => $data['image_width'] . 'x' . $data['image_height'],
					'category' => $_POST['category']
				);
				$this->db->insert($this->db->dbprefix($this->table_p), $db_data);
			}
		}
	}
	
	/**
	 * Delete a photo by id. Deletes all photo sizes and tags.
	 *
	 * @param int $id
	 */
	public function delete($id){
		$this->db->delete($this->db->dbprefix($this->table_p), array('id'=>$id));
		$this->db->delete($this->db->dbprefix($this->table_tags), array('src_id'=>$id, 'tag_type'=>'photos'));
	}
	
	
	public function changeCategory($photo_id, $new_category){
		$this->db->update($this->db->dbprefix($this->table_p), array('category'=>$new_category), array('id'=>$photo_id));
	}
	
	
	
	/**
	 * Add 1 or more tags to a photo
	 *
	 * @param int $photo_id
	 * @param string $tags
	 */
	public function addTagsToPhoto($photo_id, $tags){
		if($tags == null)
			return FALSE;
		
		$tag_arr = explode(',', $tags);
		
		if(is_array($tag_arr)){
			foreach($tag_arr as $tag){
				$this->db->insert('tags', array(
					'src_id'=>$photo_id, 
					'tag_type'=>'photos',
					'tag'=>trim($tag),
					'slug' => url_title(strtolower($tag))
				));
			}
		}
	}
	
	/**
	 * Get the tags for a photo
	 *
	 * @param int $photo_id
	 * @return resource
	 */
	public function getTagsOnPhoto($photo_id=0){
		return $this->db->get_where($this->db->dbprefix($this->table_tags), array('src_id' => $photo_id, 'tag_type'=>'photos'));
	}
	
	/**
	 * Delete a tag
	 *
	 * @param int $tag_id
	 */
	public function deleteTag($tag_id){
		$this->db->delete($this->db->dbprefix($this->table_tags), array('id'=>$tag_id));
	}
}
