<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Posts_model extends MY_Model{

    public $table_p 	= 'posts';
    public $table_pw	= 'posts_view'; 
    public $table_cat 	= 'categories';
    public $table_tags 	= 'tags';
    public $table_users	= 'users';    
    public $table_pc	= 'post_comments';
	
	public function __construct()
	{
		parent::__construct();

		$this->module = 'posts';

	}
	
	/**
	 * Gets all posts based on the $args parameter.
	 * 
	 * FORMAT - The $args parameter can be in the following formats:
	 * 
	 * 		1. As an array: 		array('key'=>'val', 'key2'=>'val2')
	 * 		2. As a query string: 	key=val&key2=val2
	 * 		
	 * 		Note: 	Some options that allow for multiple selections, ie category_in,
	 * 				are not supported via the query string method.
	 * 
	 * OPTIONS - The following options are available:
	 * 
	 * id (string|array)(optional)
	 *   Return posts with the specified id(s)
	 *   Default: none
	 * slug (string)(optional)
	 *   Return post with the specified slug
	 *   Default: none
	 * published (bool)(optional)
	 * 	 Return all posts or only published posts
	 *   Default: TRUE
	 * category_in (string|int|array)(optional)
	 *   Return posts in specified category slug or category id. 
	 *   Default: none
	 * category_not_in (string|int|array)(optional)
	 *   Return posts NOT in specified category slug or category id.
	 *   Default: none
	 * tagged (string)(optional)
	 *   Return posts tagged with the specified tag
	 *   Default: none
	 * not_tagged (string)(optional)
	 *   Return posts NOT tagged with the specified tag
	 *   Default: none
	 * in_archive ( string(year) | array(year=>2009,month=>12) )(optional)
	 *   Return posts in a year/month based archive
	 *   Default: none
	 * order_by (string)(optional)
	 *   Return posts ordered by the specified order
	 *   Default: timestamp DESC
	 * limit (string)(optional)
	 * 	 Limit the number of return posts. also includes offset.
	 *   Default: 0, 100
	 * count (bool)(optional)
	 * 	 If this is true, the number of rows will be returned instead of a db result
	 *   Default: false
	 * 
	 * @param mixed $args 
	 * @return object
	 */
	public function get( $args ){
		
		if(!is_array($args)){
			//extract to 0=>'key=val', 1=>'key=val' etc.
			$options = explode('&', $args);
			foreach($options as $index=>$str){
				//extract to key=>val
				$temp = explode('=', $str);
				$new_args[trim($temp[0])] = trim($temp[1]);
			}
			//copy new array over old string
			$args = $new_args;
		}
	
		//post id
		if(isset($args['id'])){
			$this->db->where_in('id', $args['id']);
		}
		//post slug (1 post only)
		if(isset($args['slug'])){
			$this->db->where_in('slug', $args['slug']);
		}
		//lang
		if(isset($args['lang'])){
			$this->db->where_in('lang', $args['lang']);
		}
		//published
		if(!isset($args['published']) || $args['published'] == TRUE){
			$this->db->where('timestamp < NOW() and status="Published"');
		}

		//categories in
		if(isset($args['category_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_in']) || is_numeric($args['category_in'][0])) 
				? 'cat_id' : 'cat_slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 4);
				
			$where = $posts_field. ' IN ( SELECT ' . $cats_field . ' FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE (';
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field . '="' . $cat . '"
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field . '="' . $cat . '"
						)';
				}
			}
			else {

				//single category
				$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field . '="' . $args['category_in'] . '" 
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field . '="' . $args['category_in'] . '" 
						)';
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//categories not in
		if(isset($args['category_not_in'])){
			//check for category_id or category_slug
			$posts_field = (is_numeric($args['category_not_in']) || is_numeric($args['category_not_in'][0])) 
				? 'cat_id' : 'cat_slug';
			//id or slug in categories table
			$cats_field = substr($posts_field, 4);
				
			$where = $posts_field . ' NOT IN ( SELECT ' . $cats_field . ' FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE (';
			if(is_array($args['category_in'])){
				//loop for multiple categories
				$where_count = 0;
				foreach($args['category_not_in'] as $cat){
					$where .= ($where_count++ > 0) ? ' OR ' : '';
					$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' .$cats_field . '=' . $cat . '
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' .$cats_field . '=' . $cat .'
						)';
				}
			}
			else {
				//single category
				$where .= 'lft BETWEEN (
							SELECT lft FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field . '=' . $args['category_not_in'] . '
						) AND (
							SELECT rgt FROM `' . $this->db->dbprefix($this->table_cat) . '` WHERE ' . $cats_field. '=' . $args['category_not_in'] . '
						)';
			}
			$where .= '))';
			$this->db->where($where, NULL, FALSE);
		}
		
		//tagged
		if(isset($args['tagged'])){
			$this->db->like('tags', $args['tagged']);
		}
		//not tagged
		if(isset($args['not_tagged'])){
			$this->db->not_like('tags', $args['not_tagged']);
		}
		//in_archive
		if(isset($args['in_archive'])){
			if(is_array($args['in_archive'])){
				$this->db->where('YEAR(timestamp)', $args['in_archive']['year']);
				if($args['in_archive']['month'])
					$this->db->where('MONTH(timestamp)', $args['in_archive']['month']);
			} else {
				$this->db->where('YEAR(timestamp)', $args['in_archive']);
			}
		}
		//omit following criteria if only counting rows
		if(!isset($args['count']) ||  $args['count'] === FALSE){
			//order by
			$this->db->order_by( (!isset($args['order_by'])) ? 'timestamp desc' : $args['order_by'] );
			//limit/offset
			if(isset($args['limit']))
				$this->db->limit($args['limit'],$args['offset']);
			else 
				$this->db->limit(100, 0);
		}
		
		if(isset($args['count']) && $args['count'] == TRUE){
			$this->db->from($this->db->dbprefix($this->table_pw));
			return $this->db->count_all_results();
		} else {
			return $this->db->get($this->db->dbprefix($this->table_pw));
		}
	}
	
	
	/**
	 * Gets a list of archives by year and (optionally) month
	 *
	 * @param string $detail
	 * @param mixed $category
	 * @param string $type
	 * @return resource
	 */
	public function getArchives($detail='month', $category=null, $type='IN'){
		if($detail == 'month')
			$grp = ", MONTH(timestamp)";
		
		if($category != null){
			if(is_array($category)){
				$i=0;
				foreach($category as $slug){
					$in .= ($i++ > 0) ? ',' : '';
					$in .= "'$slug'";
				}
				$opts = "AND cat_slug $type ($in)";
			} else {
				$opts = "AND cat_slug $type ('$category')";
			}
		}
			
		return $this->db->query('SELECT timestamp, count(*) cnt, MONTH(timestamp) month, YEAR(timestamp) year 
			FROM `' . $this->db->dbprefix($this->table_pw) . '` WHERE status="Published" '. $opts . '
			GROUP BY YEAR(timestamp) ' . $grp . ' ORDER BY timestamp DESC');
	}
	
	
	public function searchPosts($search_str){
		
		$where = " p.detail LIKE '%".$search_str."%'";			
		
		$q = 'SELECT p.id, p.timestamp, DATE_FORMAT( p.timestamp, "%b %e, %Y" ) f_date, DATE_FORMAT( p.timestamp, "%l:%i%p" ) f_time, p.user_id, u.display_name, p.status, coalesce( p.title, "Untitled" ) title, p.summary, p.detail, (
			SELECT count( * )
			FROM `' . $this->db->dbprefix($this->table_pc) . '`
			WHERE post_id = p.id AND approved = "TRUE"
			)comment_count, p.allow_comments, p.comment_email_notify, p.tags, coalesce( c.category, "Uncategorized" ) category, c.id cat_id, c.slug, p.service, p.service_id
			FROM `' . $this->db->dbprefix($this->table_p) . '` p
			LEFT OUTER JOIN `' . $this->db->dbprefix($this->table_users) . '` u ON u.user_id = p.user_id
			LEFT OUTER JOIN `' . $this->db->dbprefix($this->table_cat) . '` c ON c.id = p.category
			WHERE '.$where.' 
			ORDER BY timestamp DESC';
		return $this->db->query($q);
	}
	
	/**
	 * Save a post.
	 *
	 * @param int $id
	 * @return mixed
	 */
	public function save($id=0){
		//make slug
		$_POST['slug'] = url_title($_POST['title']);
		//post to twitter?
		$send_to_twitter = (empty ($_POST['send_to_twitter'])) ? NULL : $_POST['send_to_twitter'];
		//with bitly url?
		$add_bitly_url = (empty ($_POST['add_bitly_url'])) ? NULL : $_POST['add_bitly_url'];
		//remove from _POST array
		unset($_POST['send_to_twitter']);
		unset($_POST['add_bitly_url']);
		unset($_POST['new_cat_name']);
		unset($_POST['new_cat_parent']);
		
		if($id == NULL || $id == 0){
			//insert the new post
			$save_result = $this->db->insert($this->db->dbprefix($this->table_p), $_POST);
			$id = $this->db->insert_id();
			
			//update any pending tags
			$this->db->update('tags', array('src_id'=>$id), array('src_id'=>0));
			
			//send to twitter
			if($send_to_twitter == 'on'){
				if($add_bitly_url == 'on'){
					//determine post id type
					$post_id = (config_item('bitly_posts_url_type') == 'id') ? $id : $_POST['slug'];
					//make the bit.ly url
					$url = $this->makeBitlyUrl(base_url().config_item('bitly_url_to_posts') . '/' . $post_id);
					$status = substr($_POST['title'],0,116) . ' - ' . $url;
				} else {
					$status = substr($_POST['title'],0,140);
				}
				$this->tweet($status);
			}

		} else {
			$save_result = $this->db->update($this->db->dbprefix($this->table_p), $_POST, array('id'=>$id));
		}
		
		return $save_result;
	}
	
	/**
	 * Delete a post
	 *
	 * @param int $id
	 * @return string
	 */
	public function delete($id){
		//delete post
		$res = $this->db->delete($this->db->dbprefix($this->table_p), array('id'=>$id));
		//delete comments
		$this->db->delete($this->db->dbprefix($this->table_pc), array('post_id'=>$id));
		//delete tags
		$this->db->delete($this->db->dbprefix($this->table_tags), array('src_id'=>$id, 'tag_type'=>'posts'));
		
		return $res;
		/*
		if($res) 
			return "Post deleted successfully.";
		else
			return "There was an error deleting your post.";
		*/
	}
	
	/**
	 * Builds a 'tag cloud', returns an array of the details. 
	 * 
	 *
	 * @return array
	 */
	public function getTagCloud(){
		$max = $this->db->query('SELECT tag, count(*) cnt FROM `' . $this->db->dbprefix($this->table_tags) . '` 
			WHERE tag_type = "posts" GROUP BY tag ORDER BY cnt DESC')->first_row()->cnt;
		//determin size ranges
		$small = $max / 4;
		$medium = $small * 2;
		$large = $small * 3;
		$xlarge = $max;
		
		foreach($this->db->query('SELECT tag, slug, count(*) cnt FROM `' . $this->db->dbprefix($this->table_tags) . '` 
			WHERE tag_type="posts" GROUP BY tag ORDER BY tag')->result_array() as $row){
			if($row['cnt'] <= $small)
				$font_size = 10;
			elseif($row['cnt'] <= $medium)
				$font_size = 14;
			elseif($row['cnt'] <= $large)
				$font_size = 18;
			elseif($row['cnt'] <= $xlarge)
				$font_size = 22;
			else
				$font_size = 26;
		
			//put in array
			$arr[$row['tag']] = array('slug'=>$row['slug'],'size'=>$font_size,'count'=>$row['cnt']);
		}
		
		return $arr;
	}
	
	public function getAllTags( $limit,$offset){
      $this->db->select('tag, COUNT(*) AS cnt',FALSE);
      $this->db->from($this->db->dbprefix($this->table_tags));
      $this->db->where('tag_type','posts');
      $this->db->group_by('tag');
    $this->db->limit($limit,$offset);
	/*	return $this->db->query('SELECT tag, count(*) cnt from `' . $this->db->dbprefix($this->table_tags) . '`
         WHERE tag_type = "posts"
         GROUP BY tag

         ');*/
      return $this->db->get();
	}
   public function countAllTags(){
     // return $this->db->count_all($this->db->dbprefix($this->table_tags));
      $nbre=$this->db->query("SELECT * from `" . $this->db->dbprefix($this->table_tags) . "` WHERE tag_type = 'posts'");

      return $nbre->num_rows();
   }
	
	public function getTagsOnPost($post_id=0){
		return $this->db->get_where($this->db->dbprefix($this->table_tags), array('src_id' => $post_id, 'tag_type'=>'posts'));
	}
	
	public function addTags($post_id){
		$tag_arr = explode(',', $_POST['tags']);
		
		foreach($tag_arr as $the_tag){
			$this->db->insert($this->db->dbprefix($this->table_tags), array(
				'src_id'=>$post_id, 
				'tag_type'=>'posts', 
				'tag'=>trim($the_tag),
				'slug'=>strtolower(url_title($the_tag))
			));
		}
	}
	
	public function deleteTag($tag_id){
		$this->db->delete($this->db->dbprefix($this->table_tags), array('id'=>$tag_id));
	}
	
	public function getComments($id=null, $approved=false, $limit=50){
		if($id == null){
			return $this->db->query('SELECT c.id, c.post_id, c.timestamp, c.name, c.url, c.email, 
				c.comment, c.ip, c.approved, p.title FROM `' . $this->db->dbprefix($this->table_pc) . '` c
				LEFT OUTER JOIN `' . $this->db->dbprefix($this->table_p) . '` p ON p.id = c.post_id
				ORDER BY c.timestamp DESC LIMIT ' . $limit);
		} else {
			if($approved) 
				return $this->db->get_where($this->db->dbprefix($this->table_pc), array('post_id' => $id, 'approved' => 'true'));
			else 
				return $this->db->get_where($this->db->dbprefix($this->table_pc), array('post_id' => $id));
		}
			
	}
	
	public function getComment($id){
		return $this->db->get_where($this->db->dbprefix($this->table_pc), array('id' => $id));
	}
	
	public function insertComment($data){
		$row = $this->getPosts("id=$data[post_id]")->first_row();
		//$approve_cmt = $this->options['approve_comment'];

		//make sure comments are allowed
		if($row->allow_comments == 'on'){
			//auto approve?
			$note = '';
			if(config_item('approve_comment') == 'on'){
				$data['approved'] = 'false';
				$note = 'Your comment is awaiting moderation.';
			}
			//too many url's?
			if(substr_count($data['comment'], 'http://') > 4)
				return '<img src="'.base_url().'assets/theme/backoffice/images/error.png" /> Sorry, there are too many URL"s in your comment.';
			
			$this->db->insert($this->db->dbprefix($this->table_pc), $data);
			
			return '<img src="'.base_url().'assets/theme/backoffice/images/tick.png" /> Thanks for commenting! ' . $note;
		}
		else 
			return '<img src="'.base_url().'assets/theme/backoffice/images/error.png" /> Sorry, comments are disabled for this post.';
	}
	
	public function saveComment($id){
		return $this->db->update($this->db->dbprefix($this->table_pc), $_POST, array('id'=>$id));
	}
	
	public function deleteComment($id){
		return $this->db->delete($this->db->dbprefix($this->table_pc), array('id'=>$id));
	}
	
	public function approveComment($id, $approved){
		$this->db->update($this->db->dbprefix($this->table_pc), array('approved'=>$approved), array('id'=>$id));
	}
	
	public function unapprovedCommentCount(){
		$query = $this->db->query('SELECT count(*) cnt FROM `' . $this->db->dbprefix($this->table_pc) . '`  
			WHERE approved != "true"')->first_row()->cnt;

		return $query;
	}
	
	public function getTweets(){
		return $this->db->query('SELECT * FROM `' . $this->db->dbprefix($this->table_p) . '` WHERE service="twitter" ORDER BY timestamp DESC');
	}
	
	public function tweet($status=NULL){
		if(config_item('twitter_integration') != 'on')
			return 'Twitter integration is not enabled.';
		
		$this->load->library('twitter', 
			array('user'=>config_item('twitter_username'), 'pass'=>config_item('twitter_password'))
		);
		
		$status = ($status == NULL) ? $_POST['twitter_stat'] : $status;
		
		$result = $this->twitter->setStatus($status);
		if($result !== FALSE){
			if($_POST['add_as_post'] == 'on')
				$this->db->insert($this->db->dbprefix($this->table_p), array('user'=>USER, 'title'=>$_POST['twitter_stat'], 'service'=>'twitter', 'service_id'=>$result));
			
			return 'Update posted to twitter.';
		}
		else 
			return 'Error: Unable to update twitter.';
	}
	
	public function getRecentTweets(){
		if(config_item('twitter_integration') != 'on')
			return 'Twitter integration is not enabled.';
		
		$this->load->library('twitter', 
			array('user'=>config_item('twitter_username'), 'pass'=>config_item('twitter_password'))
		);
		$result = $this->twitter->getStatus();
		if($result !== FALSE){
			return $result;
		}
		else 
			return 'Error: Unable to connect to twitter.';
	}
	
	public function makeBitlyUrl($url, $login=null, $apiKey=null, $format='json', $version='2.0.1'){
		if($this->options['bitly_integration'] != 'on')
			return 'Bit.ly integration is not enabled.';
		
		if($login == null)
			$login = $this->getOption('bitly_login');
		if($apiKey == null)
			$apiKey = $this->getOption('bitly_api_key');
		
		$bitly = 'http://api.bit.ly/shorten?version=2.0.1&login=' . $login .
			'&apiKey=' . $apiKey . '&longUrl=' . $url . '&format=' . $format;
		
		$json = json_decode(file_get_contents($bitly), true);
		
		return $json['results'][$url]['shortUrl'];
	}
	
	/**
	 * Get a single post by id or slug
	 * 
	 * @deprecated use get('id=3')
	 * 
	 * @param int $id
	 * @return array
	 */
	public function getPost($id){
		if(is_numeric($id))
			return $this->db->get_where($this->db->dbprefix($this->table_pw), array('id' => $id));
		else
			return $this->db->get_where($this->db->dbprefix($this->table_pw), array('slug'=>$id))->first_row('array');
	}
	
	/**
	 * Get posts
	 * 
	 * @deprecated use get($args)
	 *
	 * @param unknown_type $args
	 * @return unknown
	 */
	public function getPosts( $args ){
		return $this->get($args);
	}
	
	/**
	 * Get a count of posts
	 *
	 * @deprecated use getPosts('count=1') 
	 * 
	 * @param bool $published
	 * @return int
	 */
	public function countPosts($published=TRUE){
		if($published)
			return $this->db->count_all($this->db->dbprefix($this->table_pw));
		else
			return $this->db->query('
				SELECT count(*) cnt 
				FROM `' . $this->db->dbprefix($this->table_pw) . '`
				WHERE timestamp < NOW() 
				AND status="published"
			')->first_row()->cnt;
	}
   

}

/* End of file posts_model.php */
/* Location: ./application/models/posts_model.php */
