<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

//include 'groups_model.php';
class Usergroups_model extends MY_Model {

    public $table_groups  = 'groups';
    public $table_users = 'users';
    public $modules='modules';
    public  $grpaccess= 'groups_modules_access';
    public $usergroups = array();    

	function __construct(){
        parent::__construct();
		$this->usergroups = $this->get_groups();


    }

	public function get_group( $args ) {

		$this->_prep_query($args);

		$query = $this->db->get($this->db->dbprefix($this->table_groups));

		if ($query->num_rows()) {

				return $query;

		}
		
		return FALSE;
	}

	private function _prep_query( $args=NULL ) {

		// query group

		if (isset($args['group_id'])) {
			$this->db->where('group_id', $args['group_id']);
		}

		if (isset($args['user_level'])) {
			$this->db->where('user_level', $args['user_level']);
		}


		if (isset($args['group_name']) && $args['group_name']) {
			$this->db->where('group_name', $args['group_name']);
		}
		
		$this->db->order_by('group_id');

	}
	/**
	 * Returns the group details
	 *
	 * @param int $id
	 * @return obj
	 */

	public function _get_group ( $group_id )
	{
		$query = $this->db->query 
		(
			'SELECT 
				* 
			FROM 
				`' . $this->db->dbprefix($this->table_groups) . '`
			WHERE 
				group_id = ' . qstr ( $group_id ) 
		);
		return ( $query->num_rows () == 1 ) ? $query->row () : FALSE;
	}
    
	/**
	 * Returns the group details
	 *
	 * @param int $id
	 * @return obj
	 */

	public function get_group_by_name ( $name = NULL)
	{
		$query = $this->db->query 
		(
			'SELECT 
				* 
			FROM 
				`' . $this->db->dbprefix($this->table_groups) . '`
			WHERE 
				group_name = ' . qstr ( $name ) 
		);
		return ( $query->num_rows () == 1 ) ? $query->row ('user_level') : FALSE;
	}

	/**
	 * Returns the available groups
	 *
	 * @param int $id
	 * @return obj
	 */

	public function get_groups ()
	{
		$query = $this->db->query 
		(
			'SELECT 
				* 
			FROM 
				`' . $this->db->dbprefix($this->table_groups) . '`
			ORDER BY group_id DESC'
		);
		return ( $query->num_rows () > 0 ) ? $query : FALSE;
	}


	/**
	 * Returns the count groups
	 *
	 * @param int $id
	 * @return obj
	 */

	public function get_groups_count ()
	{
		$query = $this->db->query 
		(
			'SELECT 
				* 
			FROM 
				`' . $this->db->dbprefix($this->table_groups) . '`
			ORDER BY group_id DESC'
		);
		return ( $query->num_rows () > 0 ) ? $query->num_rows () : FALSE;
	}

	// ------------------------------------------------------------------------

	/**
	 * get_user_group
	 *
	 * Returns the title of the group that a user belongs to
	 *
	 * @param	user id
	 * @access	private
	 * @return 	string
	 */

	public function get_group_members ( $id )
	{
		$query = $this->db->query ( 'SELECT COUNT(id) AS nr FROM `' . $this->db->dbprefix($this->table_users) . '` WHERE user_level = ' . qstr ( $id ) );
			
		if ( $query->num_rows () == 1 )
		{
			$row = $query->row ();
			return $row->nr;
		}
		return 0;
	}

	// ------------------------------------------------------------------------
	
	/**
	 * insert_group
	 *
	 * Adds a new group to the database
	 *
	 * @param	$title - group title
	 * @param	$description - group description
	 * @param	$login_redirect - default group redirect on login
	 * @param	$logout_redirect - default group redirect on logout
	 * @access	private
	 * @return 	bol
	 */

	public function insert_group ( $user_level, $title, $description, $login_redirect, $logout_redirect, $active  )
	{
		$data = array
		(
			'`user_level`'					=> $_POST['user_level'],
			'`group_name`'			=> $_POST['group_name'],
			'`description`'				=> $_POST['group_description'],
			'`login_redirect`'			=> $_POST['login_redirect'],
			'`logout_redirect`'		=> $_POST['logout_redirect'],
			'`active`'							=>  ($_POST['active']=='on' ) ? 1:0,
		);
      /*
       *modifier afin d'ajouter la creation des liens sur les modules
       */
		if( $this->db->insert ( $this->db->dbprefix($this->table_groups), escape_arr ( $data ) ) == FALSE )
              return FALSE;
      //on recuperer le dernier id de la table et on creer son module access
      $key = self::GRP_ID;
      $id_group = $this->db->query('SELECT group_id FROM '.$this->db->dbprefix($this->table_groups) .' ORDER BY '.self::GRP_ID.' DESC ')
                          ->row()->$key;

      if( $this->createModuleAccess($id_group) == FALSE)
              return FALSE;

      return TRUE;

	}

	// ------------------------------------------------------------------------

	/**
	 * edit_group
	 *
	 * Adds a new group to the database
	 *
	 * @param	$title - group title
	 * @param	$description - group description
	 * @param	$login_redirect - default group redirect on login
	 * @param	$logout_redirect - default group redirect on logout
	 * @access	private
	 * @return 	bol
	 */

	public function edit_group ($group_id  )
	{
		$data = array
		(
		
			'`group_name`'			=> $_POST['group_name'],
			'`description`'				=> $_POST['group_description'],
			'`login_redirect`'			=> $_POST['login_redirect'],
			'`logout_redirect`'		=> $_POST['logout_redirect'],
			'`active`'							=>  ($_POST['active']=='on' ) ? 1:0,
		);
		$this->db->where ( 'group_id', $group_id );
		return ( $this->db->update ( $this->db->dbprefix($this->table_groups), escape_arr ( $data ) ) ) ? TRUE : FALSE;
	}

	/**
	 * Deletes a group
	 *
	 * @param int $ID
	 * @return bol
	 */

	public function delete_group ( $id )
	{  
      /**
       * @author tchekjunior
       * ajout de la suppression des lignes 
       */
      if( $this->deleteModuleAccess($id) == FALSE)
               return FALSE;

		return ( $this->db->query 
		( 
			'DELETE FROM 
				`' . $this->db->dbprefix($this->table_groups) . '` 
			WHERE 
				`group_id` = ' . qstr ( $id ) 
		) ) ? TRUE : FALSE;


	}

	/**
	 * Deletes the members that belong to a given group
	 *
	 * @param int $gr_id - group id
	 * @return bol
	 */

	public function delete_members_from_group ( $gr_id )
	{
		return ( $this->db->query 
		( 
			'DELETE FROM 
				`' . $this->db->dbprefix($this->table_users) . '` 
			WHERE 
				`user_level` = ' . qstr ( $gr_id ) 
		) ) ? TRUE : FALSE;
	}

	/**
	 * Returns the login page that belongs to the group in which a member
	 * is part, if any
	 *
	 * @return string/bol
	 */

	public function get_login_group_redirect ()
	{
		$query = $this->db->query 
		(
			'SELECT 
				`login_redirect` 
			FROM 
				`' . $this->db->dbprefix($this->table_groups) . '` 
			WHERE 
				`id` = ' . qstr ( get_mem_info ( 'user_level' ) )
		);
		if ( $query->num_rows () == 1 ) {
			$row = $query->row ();
			return $row->login_redirect;
		}
		return FALSE;	
	}

	/**
	 * Returns the logout page that belongs to the group in which a member
	 * is part, if any
	 *
	 * @return string/bol
	 */

	public function get_logout_group_redirect ()
	{
		$query = $this->db->query 
		(
			'SELECT 
				`logout_redirect` 
			FROM 
				  `' . $this->db->dbprefix($this->table_groups) . '` 
			WHERE 
				`id` = ' . qstr ( get_mem_info ( 'user_level' ) )
		);
		if ( $query->num_rows () == 1 ) {
			$row = $query->row ();
			return $row->logout_redirect;
		}
		return FALSE;	
	}

       /**
     * est appeler lors de la creation d'un module, afin de defnire les droit
     * acces un groupe aux modules
     * @param <int> $id_group
     * @return <bool>
     */
    protected  function  createModuleAccess($id_group){
      $data = array();

      if( !is_numeric($id_group))
         return false;

      //on recupere tout les id la table module
      $query = $this->db->select('mid')
                        ->from( $this->db->dbprefix($this->modules))
                        ->get();

      if( $query->num_rows() > 0){
         //on construis chaque ligne de modules, obtient un $data[][]

         $key ='mid';
         foreach ($query->result() as $row){

            $data[] = array(  'grp_id'   =>    $id_group,
                              'mid'     =>    $row->$key,
                              'grpma_edit'    =>    0,//desactive pas defaut
                              'grpma_view'     =>    1,//activer pas defaut
                              'grpma_delete'   =>    0 //desactiver
                           );
         }

      }else{
         return FALSE;
      }

      //insertion des données
      $this->db->insert_batch($this->db->dbprefix($this->grpaccess), $data);
      return TRUE;

   }

   /**
    * apeller lors de la suppression d'un groupe
    * @param <type> $id_group
    */
   protected function  deleteModuleAccess($id_group){
      if( is_numeric($id_group))
         return false;

      $this->db->where( 'grp_id', $id_group)
               ->delete($this->db->dbprefix($this->grpaccess) );

       $this->deleteModuleAccess($id_group);
   }


   /**
    * author: tchekjunior
    * date: Mardi, 25 sept 2012
    * comment: permet de specifiers les acces sur un modules,
    * sile module n'existe pas dans la table il sera creer, en sachant que si l'on applique les constrainte integrite
    * la bd sera garante de l'exitance du module, sinon on devra effectuer une requette pour verifier le module.
    * @param <int> $id_group
    * @param <int> $id_module
    * @param <bool> $edit
    * @param <bool> $view
    * @param <bool> $delete
    * @return <bool>
    */
   public function set_module_access( $id_group, $id_module , $edit, $view, $delete ){

      if( !(is_numeric($id_group)&& is_numeric($id_module)))
         return false;

      $edit = ($edit) ? 1 : 0;
      $view = ($view) ? 1 : 0;
      $delete = ($delete) ? 1 : 0;

      //on recupère les lignes(theorie une seule) ayant l'id du group et du module
      $query = $this->db->get_where($this->db->dbprefix($this->grpaccess),
                                    array(   'grp_id'  =>    $id_group,
                                             'mid'   =>   $id_module
                                        )
                                 );

      if( $query->num_rows() > 0 ){
         //mise a jours
         $key = 'grpma_id';
         $this->db->where('grpma_id' ,$query->row()->$key);

         $this->db->update($this->db->dbprefix($this->grpaccess),
                           array(   'grp_id'   => $id_group,
                                    'mid'     => $id_module,
                                    'grpma_edit'    => $edit,
                                    'grpma_view'     => $view,
                                    'grpma_delete'   => $delete
                               )
                           );
      }else{
         /*
          * normalement je devrais effectuer verifier l'id du groupe et l'id du module
          * afin de assurer de l'integrite,on  verra plus tard
          */

         $this->db->insert( $this->db->dbprefix($this->grpaccess),
                           array(   'grp_id'   =>    $id_group,
                                    'mid'     =>    $id_module,
                                    'grpma_edit'    =>    $edit,
                                    'grpma_view'     =>    $view,
                                    'grpma_delete'   =>    $delete
                               )
                           );
                           
      }
		return TRUE;
   }


   /**
    * @author: tchekjunior
    *verifier autorisation pour acceder et visualiser le module
    * @param <int> $id_group
    * @param <int> $id_module
    * @return <bool>
    */
   public function have_view_access($id_group, $id_module){

      $row = $this->db->select('grpma_view')
                      ->from($this->db->dbprefix($this->grpaccess))
                      ->where(array(   'grp_id'   => $id_group,
                                       'mid'     => $id_module
                                    )
                              )
                      ->get()->row();
      
      if( !isset ($row->grpma_view ))
         return FALSE;

      return ($row->grpma_view)?TRUE:FALSE;
   }

   /**
    *verifier l'acces en ecriture dans un module
    * @param <int> $id_group
    * @param <int> $id_module
    * @return <bool>
    */
   public function  have_edit_access($id_group, $id_module){

      $row = $this->db->select( 'grpma_edit')
               ->from($this->db->dbprefix($this->grpaccess))
               ->where(array( 'grp_id' =>$id_group, 'mid'=>$id_module))
               ->get()->row();

      if( !isset ($row->grpma_edit))
         return FALSE;

      return ($row->grpma_edit)?TRUE:FALSE;
   }

   /**
    *verifier l'acces pour une suppression dans un module
    * @param <type> $id_group
    * @param <type> $id_module
    * @return <type>
    */
   public function have_delete_access($id_group, $id_module){


      $row = $this->db->select('grpma_delete' )
               ->from($this->db->dbprefix($this->grpaccess))
               ->where(array( 'grp_id'=>$id_group, 'mid'=>$id_module))
               ->get()->row();


      if( !isset ($row->grpma_delete))
         return FALSE;

      return ($row->grpma_delete)?TRUE:FALSE;
    }

	/**
   * retourne ensemble de access sur les modules d'un groupe
   * @param <int> $id_group
   * @return <result/false>
   */
  public function get_module_access( $id_group=NULL,$mid=NULL){
     if( !(is_numeric($id_group)))
        return false;

		$this->db->select('*');
		$this->db->from($this->db->dbprefix($this->grpaccess)." as g");
		$this->db->join($this->db->dbprefix($this->modules)." as m", 'm.mid  = g.mid','left');
		(!isset($mid)|| $mid==NULL)?$this->db->where( array('grp_id'  =>  $id_group)):$this->db->where( array(   'grp_id'  =>    $id_group,'m.mid'=>$mid)) ;
     $query = $this->db->get();
     
     return $query;
  }
}

/* End of file usergroups_model.php */
/* Location: ./application/models/usergroups_model.php */
