<?php if (!defined('BASEPATH')) exit('No direct script access allowed');

class Visitors_model extends MY_Model {

	public $visitor_id;
	public $date;
	public $ip_address;
	public $browser;
	public $referer;
	public $page_visited;
	public $human_year;
	public $human_month;
	public $human_day;

	public $by_day;
	public $by_referer;

	public $grouped;

	public $page;
	public $limit;
	public $numpages;
	public $paginate;
	
	public $table_visitors = 'visitors';
	
	public function __construct()
	{
		parent::__construct();
		$this->limit = 20;
	}

	public function get() {

		// before we set a limit / offset, we should grab all results within defined range of records to form number of pages, etc
		$this->_prep_query();
		$query = $this->db->get($this->db->dbprefix($this->table_visitors));
		$this->numpages = ceil($query->num_rows / $this->limit);

		// set the offset and limit for the query
		if ($this->paginate == TRUE) {
			$offset = ($this->page * $this->limit) - $this->limit;
			$this->db->limit($this->limit, $offset);
		}

		$this->_prep_query();

		if ($this->grouped) {

			$this->db->select('
			COUNT(visitor_id) AS num_visits,
			human_year AS year,
			human_month AS month,
			human_day AS day,
			(SELECT COUNT(DISTINCT ip_address) FROM `' . $this->db->dbprefix($this->table_visitors) . '` WHERE human_year = year AND human_month = month AND human_day = day) AS num_unique_visits', FALSE);
			
		}

		elseif ($this->by_day) {

			$this->db->select("
			ip_address,
			browser,
			referer,
			page_visited,
			FROM_UNIXTIME(date, '%m/%d/%Y %h:%i %p') AS human_date");

		}

		elseif ($this->by_referer) {

			$this->db->select('
			COUNT(referer) AS referer_count,
			referer');

			$this->db->groupby('referer');
			$this->db->orderby('referer_count DESC');

		}

		$query = $this->db->get($this->db->dbprefix($this->table_visitors));

		return $query->result_array();

	}

	public function save() {

		$db_array = array(
		'date'			=>	$this->date,
		'ip_address'	=>	$this->ip_address,
		'browser'		=>	$this->browser,
		'referer'		=>	$this->referer,
		'page_visited'	=>	$this->page_visited,
		'human_year'	=>	$this->human_year,
		'human_month'	=>	$this->human_month,
		'human_day'		=>	$this->human_day);

		if ($this->visitor_id) {
			$this->db->where('visitor_id', $this->visitor_id);
			$this->db->update($this->db->dbprefix($this->table_visitors), $db_array);
		}
		else {
			$this->db->insert($this->db->dbprefix($this->table_visitors), $db_array);
		}

	}

	public function delete() {

		$this->db->where('visitor_id', $this->visitor_id);
		$this->db->delete($this->db->dbprefix($this->table_visitors));

	}

	private function _prep_query() {
		
		// this function should only contain anything needed by the query that collects all results for pagination numbers

		if ($this->grouped) {
			$this->db->groupby('human_year, human_month, human_day');
			$this->db->orderby('date DESC');
		}

		if ($this->by_day) {
			$this->db->where('human_year', $this->human_year);
			$this->db->where('human_month', $this->human_month);
			$this->db->where('human_day', $this->human_day);
			$this->db->orderby('date DESC');
		}

		if ($this->by_referer) {

			$this->db->select('
			COUNT(referer) AS referer_count,
			referer');
			
			$this->db->where('human_year', $this->human_year);
			$this->db->where('human_month', $this->human_month);
			$this->db->where('human_day', $this->human_day);

			$this->db->select('
			COUNT(referer) AS referer_count,
			referer');

			$this->db->groupby('referer');
			$this->db->orderby('referer_count DESC');
		}

	}

}

/* End of file visitors_model.php */
/* Location: ./application/models/visitors_model.php */
