<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 * @subpackage	Backoffice
 * @category	Application
 * @since 		v0.3.1.build5  update  ci-custom2  2.1.1rev16
 * @license     GNU General Public License version 3.0 (GPLv3)
 * @classifieds controller.
 * @update 2011/06/21  17:10   gbobard@gmail.com Gabriel
 */

class Classifieds extends MY_Controller {

	function __construct(){
		parent::__construct();
		
		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Classifieds_model','Categories_model'));
		//set module
		$this->Categories_model->setModule('classifieds');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView($this->Categories_model->module);
	}
	
	/**
	 * Shows a list of Classifieds
	 *
	 * @param int $offset
	 */
	function index($offset=0){

		if($this->session->userdata('classifieds_category'))
			redirect('backoffice/classifieds/category/' . $this->session->userdata('classifieds_category'));
		
		//setup pagination
		$this->load->library('pagination');
		$config['base_url'] = site_url('backoffice/classifieds/page');
		$config['total_rows'] = $this->Classifieds_model->getClassifieds(array('published'=>FALSE,'count'=>TRUE));
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
		
		$data = array(
			'classifieds'=> $this->Classifieds_model->getClassifieds(array('limit'=>$config['per_page'], 'offset'=>$offset, 'published'=>0)),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'all_users'	=> $this->Classifieds_model->getUsers(array('user_id'=>0)),
			'mysearch'	=> TRUE,
			'sub_nav'	=> 'classifieds',
			'view' 		=> 'classifieds_home'
		);
		
		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	
	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	function page($offset=0){
		$this->index($offset);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('classifieds_category');
			redirect('backoffice/classifieds');
		}
		else {
			$this->session->set_userdata('classifieds_category', $cat_id);
			
			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('backoffice/classifieds/category/'.$cat_id);
			$config['total_rows'] = $this->Classifieds_model->getClassifieds(array('category_in'=>$cat_id,'published'=>FALSE,'count'=>TRUE));
			$config['per_page'] = 20;
			$config['uri_segment'] = 5;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'classifieds' => $this->Classifieds_model->getClassifieds(array('category_in'=>$cat_id,'published'=>FALSE,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'sub_nav' => 'classifieds',
				'view' => 'classifieds_home'
			);
			
		$this->display('classifieds', 'backoffice', 'none', $data);
		}
	}
	
	/**
	 * Edit a classified
	 *
	 * @param int $id
	 */
	function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		if($id>0){		
			$data['row'] = $this->Classifieds_model->getClassifieds(array('id'=>$id, 'published'=>0))->first_row('array');
		}
		$data['categories'] = $this->Categories_model->getTreeDD((isset($data['row']['cat_id'])) ? $data['row']['cat_id'] :NULL );
		$data['tags'] = $this->Classifieds_model->getTagsOnClassified($id);
		$data['twitter_integration'] = $this->Classifieds_model->getOption('twitter_integration');
		$data['users'] = $this->Classifieds_model->getUsers(array('user_id'=>0));
		$data['current_user'] = $this->session->userdata('display_name');
		$data['current_user_id'] = $this->session->userdata('user_id');
		$data['current_code_lang'] = $this->session->userdata('code_language');
		$data['sub_nav'] = 'classifieds';
		$data['view'] = (($id == 0) ? 'classifieds_add' : 'classifieds_edit');

		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	
	/**
	 * Add a new classified. Calls the edit() method.
	 *
	 */
	function add(){
		$this->edit();
	}
	
	/**
	 * Save existing classified, or insert new classified.
	 * Also handles image uploads for the classified.
	 *
	 * @param int $id
	 */
	function save($id=NULL){

		$user = $this->Classifieds_model->getUsers(array('display_name'=>$_POST['display_name']));

		if ($user){
			$user = $user->row();
			$_POST['user_id'] = $user->user_id;
			$_POST['display_name'] = $user->display_name;
			$_POST['email_address'] = $user->email_address;
		}	
		
		if(isset($_FILES ['classified_image'] ['name']) && $_FILES ['classified_image'] ['name'] !=NULL){

			//load photos model
			$this->load->model('Photos_model'); 

			//get default image sizes
			$opts['large_size'] = array ('w' => 100,'h' => 75);
			$opts['upload_path'] = $this->Users_model->getOption('file_upload_path').'/classifieds/';
			$opts['allowed_types'] = $this->Photos_model->getOption('image_allowed_types');
						
			//upload the image
			$image_data = $this->_uploadFile( $opts );

			//if successuflly uploaded, add image field to _POST array
			if($image_data[0]['raw_name'] != NULL){
				$_POST['image'] = $image_data[0]['orig_name'];
				$_POST['filename'] = $image_data[0]['raw_name'];
				$_POST['filetype'] = strtolower(substr($image_data[0]['file_ext'], 1));
			}
		}
		
		if($this->Classifieds_model->save($id))
			$this->_setMessage('Your classifieds has been saved.', 'success');
		else
			$this->_setMessage('Oops, there was a problem saving your classified.', 'error');
			
		redirect('backoffice/classifieds');
	}
	
	/**
	 * Delete a classified and image.
	 *
	 * @param unknown_type $id
	 */
	function delete($id){

		$this->canDelete($this->Categories_model->module);

		//get classified row before delete
		$row = $this->Classifieds_model->get(array('id'=>$id))->first_row();
		
		if($row->image != NULL){
			$this->_deleteFile(NULL, $row->image);
		}
		
		if($this->Classifieds_model->delete($id))
			$this->_setMessage('Your classified has been deleted.', 'success');
		else 
			$this->_setMessage('Unable to delete your classified.', 'error');
		
		redirect('backoffice/classifieds');
	}
	
	function tag($tag=NULL){
		$data = array(
			'classifieds' => $this->Classifieds_model->getClassifieds(array('tagged'=>$tag)),
			'tag' => $tag,
			'sub_nav' => 'classifieds',
			'view' => 'classifieds_home'
		);
		
		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	
	/*function tags($id=NULL){
		$data = array(
			'tags' => $this->Classifieds_model->getAllTags(),
			'sub_nav' => 'classifieds',
			'view' => 'classifieds_tags_' . (($id == NULL) ? 'all' : 'edit')
		);
		
		$this->display('classifieds', 'backoffice', 'none', $data);
	}*/

   public function tags($offset=0){

      $this->load->library('pagination');

		$config['total_rows'] = $this->Classifieds_model->countAllTags();
      $config['base_url'] = site_url('backoffice/classifieds/tagspage/');
		$config['per_page'] = 5;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;

		$this->pagination->initialize($config);

    //  $offset=$offset;
		$data = array(
			'tags'		 => $this->Classifieds_model->getAllTags($config['per_page'],$offset),

          'pages_links'		=> $this->pagination->create_links(),
			'sub_nav'	 => 'classifieds',
			'view'		 => 'classifieds_tags_all' 

		);

		//$view = 'tags_' . (($id == NULL) ? 'all' : 'edit');
		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	public function tagspage($offset=0){
      $this->tags($offset);



	}
	
	function addTags($classified_id=0){
		$this->Classifieds_model->addTags($classified_id);
		$this->showTags($classified_id);
	}
	
	function deleteTag($classified_id=0, $tag_id){
		$this->Classifieds_model->deleteTag($tag_id);
		$this->showTags($classified_id);
	}
	
	function showTags($classified_id){
		foreach($this->Classifieds_model->getTagsOnClassified($classified_id)->result_array() as $row){
			echo "<a href='#' onClick=\"new Ajax.Updater('tag_box', '".site_url("backoffice/classifieds/deleteTag/$classified_id/$row[id]")."', {evalScripts: true}); return false;\">
				<img src='".base_url()."assets/theme/backoffice/images/fileclose.png' style='vertical-align: middle'></a>".trim($row['tag'])." &nbsp;&nbsp;";
		}
	}
	
	function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'classifieds' => $this->Classifieds_model->searchClassifieds($search_str),
			'categories' => $this->Categories_model->getCategories(),
			'search_str' => $search_str,
			'mysearch' => TRUE,
			'sub_nav' => 'search',
			'view' => 'classifieds_home'
		);
		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	
	
	
	function ajaxAddCategory(){
		$cat_id = $this->Categories_model->save();

		$this->Categories_model->buildTree();
		$cat_dd = $this->Categories_model->getTreeDD($cat_id);
		
		echo "<SELECT name='category' style='font-size: 14px;'>$cat_dd</SELECT>";
		//foreach($this->Categories_model->getCategories()->result_array() as $cat)
		//	echo "<option value='$cat[id]' ".(($_POST['category'] == $cat['category']) ? 'selected' : '').">$cat[category]</option>";
		
		//echo '</SELECT>';
	}
	
	function answers($action=NULL, $id=NULL){
		if($action == 'save'){
			$this->Classifieds_model->saveAnswer($id);
			redirect('backoffice/classifieds/answers');
		}
		elseif($action == 'edit') {
			$data = array(
				'row' => $this->Classifieds_model->getAnswer($id)->first_row('array'),
				'view' => 'classifieds_answers_edit'
			);
			$this->display('classifieds', 'backoffice', 'none', $data);
		}
		elseif($action == 'delete') {
			$this->Classifieds_model->deleteAnswer($id);
			redirect('backoffice/classifieds/answers');
		}
		elseif($action == 'approve') {
			$this->Classifieds_model->approveAnswer($id, 'true');
		}
		elseif($action == 'unapprove') {
			$this->Classifieds_model->approveAnswer($id, 'false');
		}
		else {
			$data = array(
				'comments'=>$this->Classifieds_model->getAnswers(),
				'view' => 'classifieds_answers_all'
			);
			$data['sub_nav'] = 'classifieds';
			$this->display('classifieds', 'backoffice', 'none', $data);
		}
	}
	
	function twitter(){
		$data = array(
			'recent_tweets' => $this->Classifieds_model->getRecentTweets(),
			'page_name' => $this->Classifieds_model->getOption('twitter_username'),
			'sub_nav' => 'classifieds',
			'view' => 'classifieds_twitter'
		);
		
		$this->display('classifieds', 'backoffice', 'none', $data);
	}
	
	function tweet(){
		$message = $this->Classifieds_model->tweet();
		$nav_data = array(
			'twitter' => $this->Classifieds_model->getOption('twitter_integration'),
			'comments' => $this->Classifieds_model->unapprovedCommentCount()
		);		
		redirect('backoffice/classifieds/twitter');
	}

}
/* End of file classifieds.php */
/* Location: ./application/modules/backoffice/classifieds.php */
