<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 * @subpackage	Contacts_model
 * @category	Application
 * @since 		v0.3.0.64  update  ci-custom2  2.1.1rev16
 *
 * Candlecms controller.
 * update 2011/05/04  17:10   RENAUD AXEL M. Eba raxethebest@gmail.com
 */
class Contacts extends MY_Controller {

	public function __construct(){
		parent::__Construct();

		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Contacts_model','Categories_model'));
		//set module
		$this->Categories_model->setModule('contacts');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView($this->Categories_model->module);		
	}

	/**
	 * Shows a list of contacts
	 *
	 * @param int $offset
	 */
	public function index($offset=0){

		if($this->session->userdata('contacts_category'))
				redirect('backoffice/contacts/category/' . $this->session->userdata('contacts_category'));

		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/contacts/page');
        $arg = array('count'=>'1');
		$config['total_rows'] = $this->Contacts_model->getContacts($arg);

		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_contacts'] = 4;

		$this->pagination->initialize($config);

		$data = array(
			'contacts'	 => $this->Contacts_model->getContacts(array('limit'=>$config['per_page'], 'offset'=>$offset,'count'=>FALSE)),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'mysearch' => TRUE,
			'sub_nav'	 => 'contacts',
            'view'		 => 'contacts_home'
		);
                
        $this->display('contacts','backoffice','none', $data);
	}

	/**
	 * Used for pagination
	 *
	 * @param int$offset
	 */
	public function page($offset=0){
		$this->index($offset);
	}

	/**
	 * Edit a contact
	 *
	 * @param int $id
	 */
	public function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		if($id>0){
				$data['row'] = $this->Contacts_model->getContacts(array('id'=>$id))->first_row('array');
			}

		$cat_id = (isset($data['row']['cat_id'])) ? $data['row']['cat_id'] : NULL;
		$data['categories']   = $this->Categories_model->getTreeDD($cat_id);
		$data['sub_nav'] 	  = 'contacts';
		$data['view']		  =  ($id==0) ? 'contacts_add' : 'contacts_edit';
				
		$this->display('contacts','backoffice','none', $data);
	}

	/**
	 * Add a new contact
	 *
	 */
	public function add(){
		$this->edit();
	}

	/**
	 * Save contact, upload photo if necessary
	 *
	 * @param int $id
	 */
	public function save($id=null){


		$message = $this->Contacts_model->save($id);

		redirect('backoffice/contacts');
	}

	/**
	 * Delete contact
	 *
	 * @param int $id
	 */
	public function delete($id){

		$this->canDelete($this->Categories_model->module);

		$row = $this->Contacts_model->getContacts("id=$id")->first_row();

		$message = $this->Contacts_model->delete($id);
		$this->index($message);
	}


	public function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'posts' 	 => $this->posts_model->searchPosts($search_str),
			'categories' => $this->Categories_model->getCategories(),
			'search_str' => $search_str,
			'mysearch' => TRUE,
            'sub_nav'=>'contacts',
			'view' => 'contacts_home'
		);

		$this->display('contacts','backoffice','none', $data);
	}

	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	public function category($cat_id=null, $offset=0){
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;

		if($cat_id == 'ALL'){
			$this->session->unset_userdata('contacts_category');
			redirect('backoffice/contacts');
		}
		else {
			$this->session->set_userdata('contacts_category', $cat_id);

			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('backoffice/contacts/category/'.$cat_id);
			$config['total_rows'] = $this->Contacts_model->getContacts(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page'] = 20;
			$config['uri_segment'] = 5;
			$config['num_contacts'] = 4;
			$this->pagination->initialize($config);

			$data = array(
				'contacts' => $this->Contacts_model->getContacts(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'sub_nav'=>'contacts',
				'view' => 'contacts_home'
			);

		$this->display('contacts','backoffice','none', $data);
		}
	}

}
/* End of file contacts.php */
/* Location: ./application/modules/backoffice/contacts.php */
?>
