<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 * @subpackage	Backoffice
 * @category	Application
 * @since 		v0.3.1.build5  update  ci-custom2  2.1.1rev16
 * @license     GNU General Public License version 3.0 (GPLv3)
 *
 * Items controller.
 * update 2011/06/22  09:10   gbobard@gmail.com Gabriel
 */

class Items extends MY_Controller {
	
	//path to the site mgr installation
	//usually blank or 'admin/'
	var $site_mgr_path = 'backoffice/';
	
	function __construct(){
		parent::__construct();

		$this->load->model('Items_model');
		$this->load->model('Categories_model');
		$this->Categories_model->setModule('items');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView($this->Categories_model->module);
	}
	
	function index(){
		$this->page();
	}
	
	function page($offset=0){
		if($this->session->userdata('items_category'))
			redirect('backoffice/items/category/' . $this->session->userdata('items_category'));
		
		
		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/items/page');
		$config['total_rows'] = $this->Items_model->countMerch();
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);
		
		$data = array(
			'merch' => $this->Items_model->getMerch(NULL, $offset, $config['per_page']),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'mysearch' => TRUE,
			'sub_nav' => 'items',
			'view' => 'items_home'
		);

		$this->display('items', 'backoffice', 'none', $data);
	}
	
	function add(){
		$this->edit();
	}
	
	function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		//add a new item
		if($id == 0)
			$data = array('add_mode'=>TRUE, 'categories' => $this->Categories_model->getTreeDD());
		//edit existing item
		else {
			$data['row'] = $this->Items_model->getMerch($id)->first_row('array');
			$data['sizes'] = $this->Items_model->getSizes($id);
			$data['images'] = $this->Items_model->getImages($id);
			$data['categories'] = $this->Categories_model->getTreeDD($data['row']['cat_id']);
		}
		$data['sub_nav'] = 'items';
		$data['view'] = ($id==0) ? 'items_add' : 'items_edit';
		
		$this->display('items', 'backoffice', 'none', $data);
	}
	
	function save(){
		//save the header info
		$merch_id = $this->Items_model->saveHeader($_POST['header']);
		//save each detail line
		if(isset($_POST['size'])){
			foreach($_POST['size'] as $row){
				$this->Items_model->saveSize($merch_id, $row);
				//print_r($row);
			}
		}
		
		redirect('backoffice/items');
	}
	
	/**
	 * Delete an item, it's images and sizes.
	 *
	 * @param int $merch_id
	 */
	function delete($merch_id){

		$this->canDelete($this->Categories_model->module);
		
		$this->Items_model->delete($merch_id);
		
		echo redirect('backoffice/items');
	}
	
	function search($offset=0){

		
		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/items/search');
		$config['total_rows'] = $this->Items_model->countMerch();
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);

		$data = array(
			'merch' => $this->Items_model->search($this->input->post('search_str')),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'search_str' => $this->input->post('search_str'),
			'mysearch' => TRUE,
			'sub_nav' => 'items',
			'view' => 'items_home'
		);
		
		$this->display('items', 'backoffice', 'none', $data);
	}
	
	function addSize(){
		$tmp_id = substr(md5(microtime(true)),0,6);
		echo "<div id='size$tmp_id' style='border-bottom: 1px solid silver; margin-left: 10px; padding: 10px; width: 600px;'
				 onMouseOver=\"$('{$tmp_id}del').show();\" onMouseOut=\"$('{$tmp_id}del').hide();\">
  			<input type='text' name='size[$tmp_id][size]' size=10 >
  			<input type='hidden' name='size[$tmp_id][id]' value='0' />
  			<input type='text' name='size[$tmp_id][description]' size=20 />
  			<input type='text' name='size[$tmp_id][available]' value='0' size=10 />
  			<span style='font-family: arial; font-size: 14px; vertical-align: top'>$</span>
  			<input type='text' name='size[$tmp_id][price]' value='0' size=10 />
  			<input type='text' name='size[$tmp_id][shipping]' value='0' size=10 />
  			<a id='{$tmp_id}del' href='#' onClick=\"new Ajax.Updater('size$tmp_id', '".site_url("backoffice/items/deleteSize")."'); return false;\" style='padding-left: 20px; display: none'>
				<img src='".base_url()."img/admin/cross.png'></a>
  			</div>";
	}
	
	function deleteSize($id=0){
		if($id)
			$this->Items_model->deleteSize($id);
		
		echo "Size Deleted!";
	}
	
	
	
	/**
	 * Show all items in a category
	 *
	 * @param string $slug
	 */
	function category($slug=null, $offset=0){
		$slug = ($slug == null) ? $_POST['slug'] : $slug;
		
		if($slug == 'ALL'){
			$this->session->unset_userdata('items_category');
			redirect('backoffice/items');
		} else {
			$this->session->set_userdata('items_category', $slug);

		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/items/category');
		$config['total_rows'] = $this->Items_model->countMerch();
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);
			
			$data = array(
				'merch' => $this->Items_model->getMerchByCategory($slug),
				'categories' => $this->Categories_model->getTreeRows(),
				'pages_links' => $this->pagination->create_links(),
				'slug' => $slug,
				'sub_nav' => 'items',
				'view' => 'items_home'
			);
			
		$this->display('items', 'backoffice', 'none', $data);
		}
	}
	
	function inventory($category_slug='%'){

		$data['inventory'] = $this->Items_model->getAllSizes($category_slug);
		//exit();
		$data['sub_nav'] = 'items';
		$data['view'] = 'items_inventory';

		$this->display('items', 'backoffice', 'none', $data);
	}
	
	function deleteImage($image_id){
		$this->Items_model->deleteImage($image_id);
		echo "<br/><Br/>Image deleted!</br><br/></br><br/>";
	}
	
	function uploadImage($merch_id=0){
		$this->Items_model->uploadImage($merch_id);
		?>
		<script type="text/javascript">
			window.top.window.uploadFinished();
		</script>
		<?php 
	}
	
	function reloadImages($merch_id=0){
		$images = $this->Items_model->getImages($merch_id);
		
		//TODO: move this to a view
		foreach($images->result_array() as $row){
				$img_src = base_url() . "assets/uploads/items/$row[imageid]-mini.$row[filetype]";
				echo "<div id='image$row[id]' style='width: 250px; border: 1px solid silver; text-align: center; margin: 3px; padding: 5px; float: left'>";
				echo "<img src='$img_src'><br/>";
				if($row['main'] != 'true') 
					echo "<span id='sub'><a href='#' 
						onClick=\"new Ajax.Updater('allimages', 
							'".site_url("backoffice/items/setDefaultImage/$merch_id/$row[id]")."'
						); return false;\">Set Default</a></span>";
				else 
					echo "<span id='sub'>Default</span> "; ?>
				&nbsp;&nbsp;&nbsp;&nbsp;<span id='del_reg'>
					<a href='#' 
						onClick="if(confirm('OK to delete this image?')){
							new Ajax.Updater('image<?php echo $row['id']?>', 
							'<?php echo site_url("backoffice/items/deleteImage/$row[id]")?>'
						)}; return false;">Delete</a></span></div>
				<?php 
		}
	}
	
	function setDefaultImage($merch_id, $image_id){
		$this->Items_model->setDefaultImage($merch_id, $image_id);
		$this->reloadImages($merch_id);
	}
}
/* End of file classifieds.php */
/* Location: ./application/modules/backoffice/items.php */
