<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 * @subpackage	Backoffice
 * @category	Application
 * @since 		v0.3.1.build5  update  ci-custom2  2.1.1rev16
 * @license     GNU General Public License version 3.0 (GPLv3)
 *
 * Links controller.
 * update 2011/05/25  17:10   Guy Martial guykenne@gmail.com  and Gabriel
 */

class Links extends MY_Controller {

	function __construct(){
		parent::__construct();
		
		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Links_model','Categories_model'));
		//set module
		$this->Categories_model->setModule('links');
		// test if access right Can View
		$this->canView($this->Categories_model->module);
	}
	
	/**
	 * Shows a list of links
	 *
	 * @param int $offset
	 */
	function index($offset=0){
		if($this->session->userdata('links_category'))
			redirect('backoffice/links/category/' . $this->session->userdata('links_category'));
		
		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/links/page');
		$config['total_rows'] = $this->Links_model->getLinks('count=1');
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);
		
		$data = array(
			'links' => $this->Links_model->getLinks(array('limit'=>$config['per_page'], 'offset'=>$offset)),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'mysearch' => TRUE,
			'sub_nav' => 'links',
			'view' => 'links_home'
		);
		//$this->load->view('template', $data);
		$this->display('links','backoffice','none',$data);
		
	}
	
	/**
	 * Used for pagination
	 *
	 * @param int$offset
	 */
	function page($offset=0){
		$this->index($offset);
	}
	
	/**
	 * Edit a link
	 *
	 * @param int $id
	 */
	function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
				
		$temp1 = $this->Links_model->getLinks("id=$id")->first_row('array');
		if (isset($temp1['cat_id']))
			$temp2 = $this->Categories_model->getTreeDD($temp1['cat_id']);
		else 
			$temp2 = $this->Categories_model->getTreeDD(NULL);
		
		$data = array(
			'row' => $temp1,
			'categories' => $temp2,
			'sub_nav' => 'links',
			'view' => ($id==0) ? 'links_add' : 'links_edit'
		);
		
		$this->display('links','backoffice','none',$data);
	}
	
	/**
	 * Add a new link
	 *
	 */
	function add(){
		$this->edit();
	}
	
	/**
	 * Save link, upload photo if necessary
	 *
	 * @param int $id
	 */
	function save($id=null){

		if(isset($_POST['name']) && empty($_POST['name'])){
			$this->_setMessage('Your field [ name ] is NULL or empty !!!', 'error');			
			redirect('backoffice/links/edit/'.$id);
		}
		
		if(!empty($_POST['email_address']) && !valid_email($_POST['email_address'])){
			$this->_setMessage('Your email as bad syntax.', 'error');			
			redirect('backoffice/links/edit/'.$id);
		}

		if(isset($_FILES ['link_image'] ['name']) && $_FILES ['link_image'] ['name'] !=NULL){

			//load photos model
			$this->load->model('Photos_model'); 

			//get default image sizes
			$opts['large_size'] = array ('w' => 100,'h' => 75);
			$opts['upload_path'] = $this->Users_model->getOption('file_upload_path').'links/';
			$opts['allowed_types'] = $this->Photos_model->getOption('image_allowed_types');

			//upload the image
			$image_data = $this->_uploadFile( $opts );

			//if successuflly uploaded, add image field to _POST array
			if($image_data[0]['raw_name'] != NULL){
				$_POST['image'] = $image_data[0]['orig_name'];
				$_POST['filename'] = $image_data[0]['raw_name'];
				$_POST['filetype'] = strtolower(substr($image_data[0]['file_ext'], 1));
			}
		}
		
		if($this->Links_model->save($id))
			$this->_setMessage('Your link has been saved.', 'success');
		else
			$this->_setMessage('Oops, there was a problem saving your link.', 'error');

		redirect('backoffice/links');
	}
	
	/**
	 * Delete link
	 *
	 * @param int $id
	 */
	function delete($id){

		$this->canDelete($this->Categories_model->module);

		$row = $this->Links_model->getLinks("id=$id")->first_row();

		$upload_path = $this->Links_model->getOption('file_upload_path');
		$this->_deleteFile($upload_path, $row->filename, $row->filetype);
		
		$message = $this->Links_model->delete($id);
		$this->index($message);
	}
	
	function __search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'links' => $this->Links_model->searchLinks($search_str),
			'categories' => $this->Categories_model->getTreeRows(),
			'search_str' => $search_str,
			'view' => 'links_home'
		);
		
		$this->display('links', 'backoffice', 'right',  $data);
	}
		
	
	function search($offset=0){

		
		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/links/search');
		$config['total_rows'] = $this->Links_model->getLinks('count=1');
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);

		$data = array(
			'links' => $this->Links_model->searchLinks(array('name'=>$this->input->post('search_str'), 'limit'=>$config['per_page'], 'offset'=>$offset)),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'search_str' => $this->input->post('search_str'),
			'mysearch' => TRUE,
			'sub_nav' => 'links',
			'view' => 'links_home'
		);

		$this->display('links', 'backoffice', 'none', $data);
	}
	
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=null, $offset=0){
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('links_category');
			redirect('backoffice/links');
		}
		else {
			$this->session->set_userdata('links_category', $cat_id);
			
			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('backoffice/links/category/'.$cat_id);
			$config['total_rows'] = $this->Links_model->getLinks(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page'] = 20;
			$config['uri_segment'] = 5;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'links' => $this->Links_model->getLinks(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'mysearch' => TRUE,
				'sub_nav' => 'links',
				'view' => 'links_home'

			);

			$this->display('links','backoffice','none',$data);
		}
	}
}
/* End of file links.php */
/* Location: ./application/backoffice/controllers/links.php */
