<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Medias extends MY_Controller {
	
	public function __construct(){
		parent::__construct();
			
		$this->load->model('Medias_model');
		
		$this->load->model('Categories_model');
		
		$this->Categories_model->setModule('medias');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView($this->Categories_model->module);		
	}
	
	/**
	 * Show a list of media
	 *
	 * @param int $page_num
	 */
	public function index($offset=0){
		
		if($this->session->userdata('medias_category'))
			redirect('backoffice/medias/category/' . $this->session->userdata('medias_category'));
		
						
		$this->load->library('pagination');
		$config['base_url'] = site_url('backoffice/medias/page');
               
                
		$config['total_rows'] = $this->Medias_model->getMedia('count=1');
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
				    
		$data = array(
			'medias' => $this->Medias_model->getMedia(array('offset'=>$offset, 'limit'=>$config['per_page'])),
			'medias_types' => $this->Medias_model->getMediaTypes(),
			'categories' => $this->Categories_model->getTreeRows(),
			'page_links' => $this->pagination->create_links(),
			'mysearch' => TRUE,
            'sub_nav' => 'medias',
			'view' => 'medias_home'
		);
        
		$this->display('medias','backoffice','none', $data);
	}
	
	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	public function page($offset=0){
		$this->index($offset);
	}
		
		
	public function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'row' => $this->Media_model->getMedia(array('filename'=>$search_str))->first_row('array'),
			'categories' => $this->Categories_model->getCategories(),
			'search_str' => $search_str,
			'sub_nav'	 => 'medias',
			'view' => 'medias_edit'
		);
		$this->display('medias', 'backoffice',  'none', $data);
	}
	
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=NULL, $offset=0){
		
		$_POST['cat_id'] = (!isset($_POST['cat_id'])) ? 'Uncategorized' : $_POST['cat_id'];
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		 		 
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('medias_category');
			redirect('backoffice/medias');
		}
		else {
			$this->session->set_userdata('medias_category', $cat_id);

			//setup pagination
			$this->load->library('pagination');
			$config['base_url']		 = site_url('backoffice/medias/category/'.$cat_id);
			$config['total_rows'] = $this->Medias_model->getMedia(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page']		 = 20;
			$config['uri_segment']	 = 5;
			$config['num_links']	 = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'medias' => $this->Medias_model->getMedia(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'medias_links'=> $this->pagination->create_links(),
				'module'    => $this->Categories_model->module,
				'crumbs'	=> $this->Categories_model->breadCrumbs($cat_id),
				'mysearch' 		=> TRUE,
				'sub_nav'	=> 'medias',
				'view'		=> 'medias_home'
			);
			
		$this->display('medias', 'backoffice', 'none', $data);
		}
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	public function category_old($cat_id=null, $offset=0){
		
		$_POST['cat_id'] = (!isset($_POST['cat_id'])) ? 'Uncategorized' : $_POST['cat_id'];
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		
		
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('medias_category');
			redirect('backoffice/medias');
		}
		else {
			$this->session->set_userdata('medias_category', $cat_id);
			
			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('backoffice/medias/category/'.$cat_id);
			$config['total_rows'] = $this->Medias_model->getMedia(array('category_in'=>$cat_id,'count'=>TRUE));
			$config['per_page'] = 5;
			$config['uri_segment'] = 4;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'medias' => $this->Medias_model->getMedia(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'page_links' => $this->pagination->create_links(),
				'crumbs' => $this->Categories_model->breadCrumbs($cat_id),
				'cat_id'=>$cat_id,
				'sub_nav' => 'medias',
				'view' => 'medias_home'
			);
			$this->display('medias','backoffice','none', $data);
		}
	}
	
	/**
	 * Edit a media file
	 *
	 * @param int $media_id
	 */
	public function edit($media_id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		$data=array();		
		$data['row'] =  $this->Medias_model->getMedia(array('id'=>$media_id))->first_row('array');
		$cat_id = (isset($data['row']['cat_id'])) ? $data['row']['cat_id'] : NULL;

		$data['categories']	 = $this->Categories_model->getTreeDD($data['row']['cat_id']);
		$data['sub_nav']	 = 'medias';
		$data['view']		 = 'medias_edit';

		
		$this->display('medias','backoffice','none', $data);
	}
	
	/**
	 * Save a media file
	 *
	 * @param int $media_id
	 */
	public function save($media_id=0){
		$this->Medias_model->save($media_id);
		redirect('backoffice/medias');
	}
	
	/**
	 * Delete a media file
	 *
	 * @param int $id
	 */
	public function delete($id=0){

		$this->canDelete($this->Categories_model->module);
		
		$upload_path = $this->Medias_model->getOption('file_upload_path').'/medias/';
		$row = $this->Medias_model->getMedia("id=$id")->first_row();		

		$this->_deleteFile($upload_path, $row->filename, $row->filetype);
		
		//delete from db
		$this->Medias_model->delete($id);
		
		redirect('backoffice/medias');
	}
	
	/**
	 * Show the upload view
	 *
	 */
	public function upload(){
		
		$this->canEdit($this->Categories_model->module);
		
		$data = array(
			'categories' => $this->Categories_model->getTreeDD(),
			'sub_nav'=>'medias',
			'view'=>'medias_upload'
		);

		$this->display('medias','backoffice','none', $data);
	}
	
	/**
	 * Upload a media file
	 *
	 */
	public function doUpload(){

		if(isset($_FILES ['medias_file'] ['name'])  && !empty($_FILES ['medias_file'] ['name'])){
			$opts['upload_path'] = $this->Medias_model->getOption('file_upload_path').'/medias/';
			$opts['allowed_types'] = $this->Medias_model->getOption('file_upload_types');

			//upload the image
			$file_data = $this->_uploadFile($opts);
			
			if($file_data !== FALSE)
				$this->Medias_model->save($file_data); 
			else
				redirect('backoffice/medias/upload');
				
		}
		else{
			$this->_setMessage('Oops, there was a problem saving your Media is empty.', 'error');			
			redirect('backoffice/medias/upload');
		}
		redirect('backoffice/medias');
	}
	
	/**
	 * Show all media files by type (file ext)
	 *
	 * @param int $type
	 */
	public function type($type=NULL){
		$data = array(
			'medias' => $this->Medias_model->getMedia(array('type'=>$type)),
			'type' => $type,
			'sud_nav' => 'medias',
			'view' => 'medias_home'
		);
		$this->display('medias','backoffice','none', $data);
	}
	
	
	function ajaxAddCategory(){
		$cat_id = $this->Categories_model->save();

		$this->Categories_model->buildTree();
		$cat_dd = $this->Categories_model->getTreeDD($cat_id);
		
		echo "<SELECT name='category' style='font-size: 14px;'>$cat_dd</SELECT>";
		//foreach($this->Categories_model->getCategories()->result_array() as $cat)
		//	echo "<option value='$cat[id]' ".(($_POST['category'] == $cat['category']) ? 'selected' : '').">$cat[category]</option>";
		
		//echo '</SELECT>';
	}
}
/* End of file medias.php */
/* Location: ./application/modules/backoffice/controllers/medias.php */
