<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Description of modules
 *
 * @author Melanie LONTSI mel.lontsi@gmail.com
 */

class Modules extends MY_Controller{
    //put your code here
	private $upload_errors;

   public function __construct(){
 		parent::__construct();

		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView('modules');

		//load models lang
		$this->load->model('Modules_model');

    }

    //get all modules from assets/modules and from DB and present it to admin
    public function index(){

         $data=array(
           'view'=> "modules",
           'sub_nav'=>"modules",
           'modules' => $this->Modules_model->getModules(array("installed"=>1)),
           'count_install'=>$this->Modules_model->countModules('installed'),

       );

       $this->display("modules", "backoffice","none", $data);
    }

    public function install($id){

       $this->Modules_model->install($id);
       $this->_setMessage("A module have been reinstalled","success");
       redirect('backoffice/modules');
    }

    public function uninstall($id=null){

		 $data['sub_nav']="modules";
		if(isset($id)){
			if($this->Modules_model->uninstall($id))
            $this->_setMessage("Module deleted with success","success");

         else
            $this->_setMessage("Problem occured when deleting files","error");
         redirect("backoffice/modules/uninstall");
		}

      $data['modules']=$this->Modules_model->getModules(array('installed'=>0));
      $data['count']=$this->Modules_model->countModules('uninstalled');
		$data['view'] = 'uninstall_modules';

		$this->display('modules', 'backoffice', 'none', $data);
    }

	/**
	 * Upload a media file
	 *
	 */
    public function upload(){

       $data['sub_nav']="modules";

       if ($_POST) {

			$opts['upload_path'] = $this->Modules_model->getOption('file_upload_path').'/modules/';
			$opts['allowed_types'] = $this->Modules_model->getOption('file_upload_types');

			//upload the image
			$file_data = $this->_uploadFile($opts);

			if ( $this->upload_errors) {

				$data['upload_status'] = $this->upload_errors;
				$this->_setMessage($data['upload_status'], "error");
            redirect("backoffice/modules/upload");
			}
			else { // upload done without errors

				$target_dir = getcwd().'/application/modules/';

				$file_name=strtolower($file_data[0]['raw_name']);
				$file_name=explode('_',$file_name);
				$nbfields=		count($file_name);
				if($nbfields==1  && !strpos($file_data[0]['raw_name'],'_')){
					$this->_setMessage("The module,you upload,dont have the name format <strong>\"modulename_version.zip\"</strong>", "error");
					unlink($file_data[0]['full_path']);
							redirect("backoffice/modules/");
				}
				if($nbfields>1  && !strpos($file_name[1],'-')){
					$this->_setMessage("The module,you upload,dont have the version format </strong>; \"version\" must be <strong>\"X-Y-Z-W\"</strong>", "error");
							redirect("backoffice/modules/");
					unlink($file_data[0]['full_path']);
				}
				$realname=$file_name[0];
				$version=		str_replace('-','.',$file_name[1]);
				$row=$this->Modules_model->get(array('name'=>$realname));
				$row=$row->row_array();
				if(is_dir($target_dir.$realname) && count($row)>0 && $row['version'] > $version ){  // existing module

					//look if already exist the module in the database, may be one in an older version
					$this->_setMessage("The module,you upload, version is ".$version." there is already an existing one in a most recent version <strong>".$row['version']."</strong>", "error");
					unlink($file_data[0]['full_path']);
					redirect("backoffice/modules/");

				}
				else { //module do not exist in upload directory, or exists but the upload file is a recent version

                  $this->load->library('unzip');
                  $this->unzip->allow('zip');

				  $install = $this->unzip->extract($file_data[0]['full_path'], $target_dir, TRUE);
                  if($install)
                     $this->_setMessage("The module has been uploaded and installed with success", "success");
                  else
                     $this->_setMessage("The module has NOT been uploaded ", "error");
				}

            redirect("backoffice/modules/");
			}

		}
		else {

			$data['view'] = 'upload_modules';
			$this->display('modules', 'backoffice', 'none', $data);
		}

    }

    public function set($id,$action){

		if( $this->Modules_model->set($id,$action))
			   $this->_setMessage("Success!!!", "success");
		else
		$this->_setMessage("The operation have failed!!!", "error");

		redirect('backoffice/modules');
    }

    public function delete($id){
     if(	$this->Modules_model->delete($id))
		  $this->_setMessage("A module has been deleted", "success");
     else
			  $this->_setMessage("Deletion has not been done successfully", "error");

      redirect('backoffice/modules');
    }

    public function update($id=NULL){
		if(	$this->Modules_model->update($id))
			$this->_setMessage("A module has been updated", "success");
		else
			$this->_setMessage("Update has not been done successfully", "error");

	redirect('backoffice/modules');
	}

	public function move($id=NULL,$direction=NULL){

		$this->Modules_model->move($id,$direction);
		redirect('backoffice/modules');
	}

    public function modules_rights($id_module=NULL){

		$this->load->model('Usergroups_model');	
		$id_group = $this->session->userdata('user_level');
		$group=$this->Usergroups_model->get_groups()->result();	

		foreach( $group as $grp ){
			$edit=1;$view=1;$delete=0;
			if( $grp->group_name=='Anonymous' ){
				$edit=0;$view=0;$delete=0;
			}elseif($grp->group_name=='Superadmin' ){
				$edit=1;$view=1;$delete=1;
			}

			$ok=$this->Usergroups_model->set_module_access( $grp->user_level, $id_module ,$edit,$view,$delete );		
		}

		if( $ok	){
			$this->UserAccessRight();// Update session access right
			$this->_setMessage("A module rights has been updated", "success");
		}
		else{
			$this->_setMessage("Update module rights has not been done successfully", "error");
		}

		redirect('backoffice/modules');
	}
	
}
/* End of file modules.php */
/* Location: ./application/modules/backoffice/controllers/modules.php */
