<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Pages extends MY_Controller {

	function __construct(){
		parent::__construct();

				
		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Pages_model', 'Categories_model'));
		//set module
		$this->Categories_model->setModule('pages');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		
		$this->canView($this->Categories_model->module);

	}
	
	function index($message=NULL){

		$this->page($message);
		
	}
	
	function page($offset=0,$message=NULL){

		if($this->session->userdata('pages_category'))
			redirect('backoffice/pages/category/' . $this->session->userdata('pages_category'));
			
		$this->load->library('pagination');

		$config['base_url']   = site_url('backoffice/pages/page');
		$config['total_rows'] = $this->Pages_model->countPages(FALSE);
		$config['per_page']   = 20;
		$config['uri_segment']= 4;
		$config['num_links']  = 4;
		
		$this->pagination->initialize($config);
		$data = array(
			'pages'		 => $this->Pages_model->getPages(array('limit'=>$config['per_page'], 'offset'=>$offset, 'published'=>0)),
			'categories' => $this->Categories_model->getTreeRows(),
			'message' 	 => $message,
			'pages_links' => $this->pagination->create_links(),
			'mysearch' 		=> TRUE,
			'sub_nav'	 => 'pages',
			'view' 		 => 'pages_home'
		);

		$this->display('pages', 'backoffice', 'none', $data);
	}
	
	function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		if($id>0){
				$data['row'] = $this->Pages_model->getPages(array('id'=>$id, 'published'=>0))->first_row('array');				
			}

		$cat_id = (isset($data['row']['cat_id'])) ? $data['row']['cat_id'] : NULL;
		$data['categories']   = $this->Categories_model->getTreeDD($cat_id);
		$data['all_users'] 	  = $this->Pages_model->getUsers(array('user_id'=>0));
		$data['current_user'] = $this->session->userdata('display_name');
		$data['current_user_id'] = $this->session->userdata('user_id');
		$data['current_code_lang'] = $this->session->userdata('code_language');
		$data['sub_nav'] 	  = 'pages';
		$data['view']		  =  ($id==0) ? 'pages_add' : 'pages_edit';

		$this->display('pages', 'backoffice', 'none', $data);
	}
	
	/**
	 * Add a new page. Calls the edit() method.
	 *
	 */
	function add(){
		$this->edit();
	}
	
	
	function save($id=null){

		$user = $this->Pages_model->getUsers(array('display_name'=>$_POST['display_name']));

		if ($user){
			$user = $user->row();
			$_POST['user_id']=$user->user_id;
			$_POST['display_name']=$user->display_name;
		}	
		$this->Pages_model->save($id);
		redirect('backoffice/pages');
	}
	
	function delete($id){

		$this->canDelete($this->Categories_model->module);
		
		$message = $this->Pages_model->delete($id);
		redirect('backoffice/pages');
	}
	
	
	
	function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'pages' => $this->Pages_model->searchPages($search_str),
			'categories' => $this->Categories_model->getCategories(),
			'search_str' => $search_str,
			'mysearch' 		=> TRUE,
			'sub_nav'	 => 'pages',
			'view' => 'pages_home'
		);
		
		$this->display('pages', 'backoffice', 'none', $data);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=NULL, $offset=0){

		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		 		 
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('pages_category');
			redirect('backoffice/pages');
		}
		else {
			$this->session->set_userdata('pages_category', $cat_id);

			//setup pagination
			$this->load->library('pagination');
			$config['base_url']		 = site_url('backoffice/pages/category/'.$cat_id);
			$config['total_rows']	 = $this->Pages_model->getPages(array('category_in'=>$cat_id,'published'=>FALSE,'count'=>TRUE));
			$config['per_page']		 = 10;
			$config['uri_segment']	 = 5;
			$config['num_links']	 = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'pages'		=> $this->Pages_model->getPages(array('category_in'=>$cat_id,'published'=>FALSE,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links'=> $this->pagination->create_links(),
				'module'    => $this->Categories_model->module,
				'crumbs'	=> $this->Categories_model->breadCrumbs($cat_id),
				'mysearch' 		=> TRUE,
				'sub_nav'	=> 'pages',
				'view'		=> 'pages_home'
			);
			
		$this->display('pages', 'backoffice', 'none', $data);
		}
	}
	
	
	function ajaxAddCategory(){
		$this->Categories_model->save();
		echo "<select name='category' style='font-size: 14px;'><option value=''>Select...</option>";
		foreach($this->Categories_model->getCategories()->result_array() as $cat)
			echo "<option value='$cat[id]' ".(($_POST['category'] == $cat['category']) ? 'selected' : '').">$cat[category]</option>";
		
		echo '</select>';
	}

}
/* End of file pages.php */
/* Location: ./application/modules/backoffice/pages.php */
