<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 
 * @category	Application
 * @since 		v0.3.1.2  update  ci-custom2  2.1.1rev16
 *
 * Candlecms controller.
 * portage 2011/08/16 14:16   Renaud Axel  raxethebest@gmail.com  update gabriel gbobard@gmail.com
 * modify 2011/05/31
 */

class Photos extends MY_Controller {
	
 public function __construct(){
		parent::__Construct();
		
		$this->load->model('Photos_model');  
		$this->load->model('Categories_model');  
		
		$this->Categories_model->setModule('photos');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));
		// test if access right Can View
		$this->canView($this->Categories_model->module);		

	}
	
	public function index($offset=0){

		if($this->session->userdata('photos_category'))
			redirect('backoffice/photos/category/' . $this->session->userdata('photos_category'));
			
		$this->load->library('pagination');

		$config['base_url'] = site_url('backoffice/photos/page');
		$config['total_rows'] = $this->Photos_model->getCount();
		$config['per_page'] = 10;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
			
		$this->pagination->initialize($config);
		
		$data = array(
			'photos' => $this->Photos_model->getPhotos(array('limit'=>$config['per_page'], 'offset'=>$offset)),
			'categories' => $this->Categories_model->getTreeRows(),
			'pages_links' => $this->pagination->create_links(),
			'sub_nav'=>'photos',
			'view' => 'photos_home'
			
		);
		$this->display('photos','backoffice','none', $data);
	}
	
	public function page($offset=0){
		$this->index($offset);
	}
	
	public function upload(){
		
		$this->canEdit($this->Categories_model->module);
		
		$data = array(
			'categories' => $this->Categories_model->getTreeDD(),
			'sub_nav'=>'photos',
			'view' => 'photos_upload'
		);
		
		$this->display('photos','backoffice','none', $data);
	}
	
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	function category($cat_id=NULL, $offset=0){

		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		 		 
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('photos_category');
			redirect('backoffice/photos');
		}
		else {
			$this->session->set_userdata('photos_category', $cat_id);

			//setup pagination
			$this->load->library('pagination');
			$config['base_url']		 = site_url('backoffice/photos/category/'.$cat_id);
			$config['total_rows']	 = $this->Photos_model->getCount();
			$config['per_page']		 = 10;
			$config['uri_segment']	 = 5;
			$config['num_links']	 = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'photos'		=> $this->Photos_model->getPhotos(array('category_in'=>$cat_id,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links'=> $this->pagination->create_links(),
				'module'    => $this->Categories_model->module,
				'crumbs'	=> $this->Categories_model->breadCrumbs($cat_id),
				'mysearch' 		=> TRUE,
				'sub_nav'	=> 'photos',
				'view'		=> 'photos_home'
			);

		$this->display('photos', 'backoffice', 'none', $data);
		}
	}
	
	
	public function view($id){
		
		$data = array(
			'row' => $this->Photos_model->getPhoto($id)->first_row('array'),
			'tags' => $this->Photos_model->getTagsOnPhoto($id),
			'categories' => $this->Categories_model->getTreeDD(),
			'sub_nav'=>'photos',
			'view' => 'photos_view'
		);
		
		$this->display('photos','backoffice','none', $data);
	}
	
	public function sizes($photo_id, $size){
		$data = array(
			'size'=> ($size == 'O') ? '' : $size,
			'row' => $this->Photos_model->getPhoto($photo_id)->first_row('array'),
			'sub_nav'=>'photos',
			'view' => 'photos_size'
		);
		
		$this->display('photos','backoffice','none', $data);
	}
	
	/**
	 * Save title, desc, etc. AJAX calls this, no views needed!
	 *
	 * @param string $field
	 * @param int $id
	 */
	public function save($field, $id){
		$this->Photos_model->save($field, $id);
		//display the save field
		echo $_POST['value'];
	}
	
	public function delete($id){

		$this->canDelete($this->Categories_model->module);

		$upload_path = $this->Photos_model->getOption('file_upload_path').'/photos/';

		$row = $this->Photos_model->getPhoto($id)->first_row();

		$this->_deleteFile($upload_path, $row->filename);
		
		$this->Photos_model->delete($id);
		redirect('backoffice/photos');
	}
	
	public function doUpload(){

		$opts['upload_path'] = $this->Photos_model->getOption('file_upload_path').'/photos/';
		$opts['allowed_types'] = $this->Photos_model->getOption('image_allowed_types');
				
		//upload the image
		$file_data = $this->_uploadFile($opts);

		if($file_data !== FALSE)
			$this->Photos_model->saveUpload($file_data); 
		
		redirect('backoffice/photos');
	}
	
	public function changeCategory($photo_id){
		$cat=$this->Photos_model->changeCategory($photo_id, $this->input->post('category'));
		
		//$cat = $this->Photos_model->getCategory($this->input->post('category'))->first_row('array');
		
		echo "$cat[category]&nbsp;&nbsp;
			<a href='#' onClick=\"$('curr_cat').hide(); $('edit_cat').show(); return false;\">Edit</a>.";

	}
	
	public function deleteTag($photo_id, $tag_id){
		$this->Photos_model->deleteTag($tag_id);
		$this->showTags($photo_id);
	}
	
	public function addTags($photo_id){
		$this->Photos_model->addTagsToPhoto($photo_id, $this->input->post('tags'));
		$this->showTags($photo_id);
	}
	
	/**
	 * Display tags on a photo. AJAX calls this!
	 *
	 * @param int $photo_id
	 */
	public function showTags($photo_id){
		foreach($this->Photos_model->getTagsOnPhoto($photo_id)->result_array() as $tag)
			echo "<a href='".site_url("backoffice/photos/tag/$tag[tag]")."'>$tag[tag]</a>&nbsp;
			<span class='del' style='font-size: 10px;'><a href='#' onClick=\"new Ajax.Updater('tag_box', '".site_url("backoffice/photos/deleteTag/$photo_id/$tag[id]")."', {evalScripts: true}); return false;\" title='Delete this tag?'>
				x</a></span><br/>";
	}

}

