<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * @author 		BYOOS France - Cameroun - CandleCMS development team
 * @package		CandleCMS
 * @subpackage	Backoffice
 * @category	Application
 * @since 		v0.3.0.50  update  ci-custom2  2.1.1rev16
 *
 * Candlecms controller.
 * update 2011/04/03  17:10   gabriel gbobard@gmail.com
 */

class Posts extends MY_Controller {

	public function __construct(){
		parent::__construct();
				
		//load helpers
		$this->load->helper(array('html', 'text'));
		//load models
		$this->load->model(array('Posts_model', 'Categories_model', 'Settings_model', 'Analytics_model'));
		//set module
		$this->Categories_model->setModule('posts');
		// load the lang module for all controller's backoffice...
		$this->LoadLangModule($this->active_template, $this->session->userdata('language'));

		$this->canView($this->Categories_model->module);

	}
	
	/**
	 * Shows a list of posts
	 *
	 * @param int $offset
	 */
	public function index($offset=0){

		if($this->session->userdata('posts_category'))
			redirect('backoffice/posts/category/' . $this->session->userdata('posts_category'));

		//setup pagination
		$this->load->library('pagination');
		
		$config['base_url'] = site_url('backoffice/posts/page');
		$config['total_rows'] = $this->Posts_model->getPosts(array('published'=>FALSE,'count'=>TRUE));
		$config['per_page'] = 20;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);
		
		$data = array(
			'posts' 	 	=> $this->Posts_model->getPosts(array('limit'=>$config['per_page'], 'offset'=>$offset, 'published'=>0)),
			'categories' 	=> $this->Categories_model->getTreeRows(),
			'pages_links'	=> $this->pagination->create_links(),
			'all_users'		=> $this->Posts_model->getUsers(array('user_id'=>0)),
			'mysearch' 		=> TRUE,
			'twitter_integration'=> $this->Posts_model->getOption('twitter_integration'),
			'comments' 		=> $this->Posts_model->unapprovedCommentCount(),
			'sub_nav'		=> 'posts',
			'view'		 	=> 'posts_home'
		);
		
		$this->Analytics_model->saveUserInfo();// save visitors info's
		$this->display('posts', 'backoffice', 'none', $data);
	}
	
	/**
	 * Used for pagination. Calls the index() method.
	 *
	 * @param int $offset
	 */
	public function page($offset=0){
		$this->index($offset);
	}
	
	/**
	 * Show all items in a category
	 *
	 * @param string $cat_id
	 * @param int $offset
	 */
	public function category($cat_id=NULL, $offset=0){

		$_POST['cat_id'] = (!isset($_POST['cat_id'])) ? 'Uncategorized' : $_POST['cat_id'];
		$cat_id = ($cat_id == null) ? $_POST['cat_id'] : $cat_id;
		 		 
		if($cat_id == 'ALL'){
			$this->session->unset_userdata('posts_category');
			redirect('backoffice/posts');
		}
		else {
			$this->session->set_userdata('posts_category', $cat_id);
			
			//setup pagination
			$this->load->library('pagination');
			$config['base_url'] = site_url('backoffice/posts/category/'.$cat_id);
			$config['total_rows'] = $this->Posts_model->getPosts(array('category_in'=>$cat_id,'published'=>FALSE,'count'=>TRUE));
			$config['per_page'] = 10;
			$config['uri_segment'] = 5;
			$config['num_links'] = 4;
			$this->pagination->initialize($config);
			
			$data = array(
				'posts'		=> $this->Posts_model->getPosts(array('category_in'=>$cat_id,'published'=>FALSE,'limit'=>$config['per_page'],'offset'=>$offset)),
				'pages_links'=> $this->pagination->create_links(),
				'crumbs'	=> $this->Categories_model->breadCrumbs($cat_id),
				'cat_id' 	=> $cat_id,
				'module'    => $this->Categories_model->module,
				'sub_nav'	=> 'posts',
				'view'		=> 'posts_home'
			);

			$this->display('posts', 'backoffice', 'none', $data);
		}
	}
	
	/**
	 * Edit a post
	 *
	 * @param int $id
	 */
	public function edit($id=0){
		
		$this->canEdit($this->Categories_model->module);
		
		$data['smenu'] = 'manage';

		$data['row'] = $this->Posts_model->getPosts(array('id'=>$id, 'published'=>0))->first_row('array');
		$cat_id = (isset($data['row']['cat_id'])) ? $data['row']['cat_id'] : null;
		$data['categories'] = $this->Categories_model->getTreeDD($cat_id);
		$data['tags'] 		= $this->Posts_model->getTagsOnPost($id);
		$data['twitter_integration'] = $this->Posts_model->getOption('twitter_integration');
		$data['all_users'] 	= $this->Posts_model->getUsers(array('user_id'=>0));
		$data['current_user'] = $this->session->userdata('display_name');
		$data['current_user_id'] = $this->session->userdata('user_id');
		$data['current_code_lang'] = $this->session->userdata('code_language');
		$data['sub_nav'] 	= 'posts';
		$data['view'] 		= ($id==0) ? 'posts_add' : 'posts_edit';

		$this->display('posts', 'backoffice', 'none', $data);
	}
	
	/**
	 * Add a new post. Calls the edit() method.
	 *
	 */
	function add(){
		$this->edit();
	}
	
	/**
	 * Save existing post, or insert new post.
	 * Also handles image uploads for the post.
	 *
	 * @param int $id
	 */
	public function save($id=0){

		$user = $this->Posts_model->getUsers(array('display_name'=>$_POST['display_name']));

		if ($user){
			$user = $user->row();
			$_POST['user_id']=$user->user_id;
			$_POST['display_name']=$user->display_name;
		}	

		if(isset($_FILES ['post_image'] ['name']) && $_FILES ['post_image'] ['name'] !=NULL){

			//load photos model
			$this->load->model('Photos_model'); 

			//get default image sizes
			$opts['large_size'] = array (
				'w' => config_item('image_width'),
				'h' => config_item('image_height')
			);
			$opts['upload_path'] = $this->Users_model->getOption('file_upload_path').'posts/';
			$opts['allowed_types'] = $this->Photos_model->getOption('image_allowed_types');
			//upload the image
			$image_data = $this->_uploadFile( $opts );
			//if successuflly uploaded, add image field to _POST array
			if($image_data[0]['raw_name'] != NULL){
				$_POST['image'] = $image_data[0]['orig_name'];
				$_POST['filename'] = $image_data[0]['raw_name'];
				$_POST['filetype'] = strtolower(substr($image_data[0]['file_ext'], 1));
			}
		}
		
		if($this->Posts_model->save($id))
			$this->_setMessage('Your post has been saved.', 'success');
		else
			$this->_setMessage('Oops, there was a problem saving your post.', 'error');
			
		redirect('backoffice/posts');
	}
	
	/**
	 * Delete a post and image.
	 *
	 * @param unknown_type $id
	 */
	public function delete($id){

		$this->canDelete($this->Categories_model->module);
		//get post row before delete
		$row = $this->Posts_model->get(array('id'=>$id))->first_row();
		
		if($row->image != NULL){
			$this->_deleteFile(NULL, $row->image);
		}
		
		if($this->Posts_model->delete($id))
			$this->_setMessage('Your post has been deleted.', 'success');
		else 
			$this->_setMessage('Unable to delete your post.', 'error');
		
		redirect('backoffice/posts');
	}
	
	public function tag($tag){
	
		$this->load->library('pagination');
		
		$config['total_rows'] = $this->Posts_model->getPosts(array('tagged'=>$tag, 'count'=>TRUE));

		$config['per_page'] = 10;
		$config['uri_segment'] = 5;
		$config['num_links'] = 4;
		
		$this->pagination->initialize($config);
			
		$data = array(
			'posts'				 => $this->Posts_model->getPosts(array('tagged'=>$tag)),
			'twitter_integration'=> $this->Posts_model->getOption('twitter_integration'),
			'pages_links'		=> $this->pagination->create_links(),
			'tag'				 => $tag,
			'sub_nav'			 => 'posts',
			'view'				 => 'posts_home'
		);

		$this->display('posts', 'backoffice', 'none', $data);
	}
	
	public function tags($offset=0){

      $this->load->library('pagination');

		$config['total_rows'] = $this->Posts_model->countAllTags();
      $config['base_url'] = site_url('backoffice/posts/tagspage/');
		$config['per_page'] = 5;
		$config['uri_segment'] = 4;
		$config['num_links'] = 4;
		$this->pagination->initialize($config);

		$data = array(
			'tags'		 => $this->Posts_model->getAllTags($config['per_page'],$offset),
			
          'pages_links'		=> $this->pagination->create_links(),
			'sub_nav'	 => 'posts',
			'view'		 => 'posts_tags_all'
          
		);

		$this->display('posts', 'backoffice', 'none', $data);
	}
	
	public function tagspage($offset=0){
		$this->tags($offset);
	}
	
	public function addTags($post_id=0){
		$this->Posts_model->addTags($post_id);
		$this->showTags($post_id);
	}
	
	public function deleteTag($post_id=0, $tag_id){
		$this->Posts_model->deleteTag($tag_id);
		$this->showTags($post_id);
	}
	
	public function showTags($post_id){
		foreach($this->Posts_model->getTagsOnPost($post_id)->result_array() as $row){
			echo "<a href='#' onClick=\"new Ajax.Updater('tag_box', '".site_url("backoffice/posts/deleteTag/$post_id/$row[id]")."', {evalScripts: true}); return false;\">
				<img src='".base_url()."assets/themes/backoffice/images/fileclose.png' style='vertical-align: middle'></a>".trim($row['tag'])." &nbsp;&nbsp;";
		}
	}
	
	public function search(){
		$search_str = $_POST['search_str'];
		$data = array(
			'posts' => $this->Posts_model->searchPosts($search_str),
			'categories' 	=> $this->Categories_model->getTreeRows(),
			'mysearch' 		=> TRUE,
			'search_str' => $search_str,
			'sub_nav'	 => 'posts',
			'view' => 'posts_home'
		);
		$this->display('posts', 'backoffice',  'none', $data);
	}
	
	
	
	public function ajaxAddCategory(){
		$cat_id = $this->Categories_model->save();
		$this->Categories_model->buildTree();
		$cat_dd = $this->Categories_model->getTreeDD($cat_id);
		
		echo "<SELECT name='category' style='font-size: 14px;'>$cat_dd</SELECT>";
		//foreach($this->Categories_model->getCategories()->result_array() as $cat)
		//	echo "<option value='$cat[id]' ".(($_POST['category'] == $cat['category']) ? 'selected' : '').">$cat[category]</option>";
		
		//echo '</SELECT>';
	}
	
	public function comments($action=NULL, $id=NULL){
		if($action == 'save'){
			$this->Posts_model->saveComment($id);
			redirect('backoffice/posts/comments');
		}
		elseif($action == 'edit') {
			$data = array(
				'row' => $this->Posts_model->getComment($id)->first_row('array'),
				'sub_nav'	 => 'posts',
				'view' => 'posts_comments_edit'
			);
			$this->display('posts', 'backoffice', 'none', $data);
		}
		elseif($action == 'delete') {
			$this->Posts_model->deleteComment($id);
			redirect('backoffice/posts/comments');
		}
		elseif($action == 'approve') {
			$this->Posts_model->approveComment($id, 'true');
		}
		elseif($action == 'unapprove') {
			$this->Posts_model->approveComment($id, 'false');
		}
		else {
			$data = array(
				'comments'=>$this->Posts_model->getComments(),
				'sub_nav'	 => 'posts',
				'view' => 'posts_comments_all'
			);
			$data['twitter_integration'] = $this->Posts_model->getOption('twitter_integration');

			$this->display('posts', 'backoffice', 'none', $data);
		}
	}
	
	function twitter(){
		$data = array(
			'recent_tweets' => $this->Posts_model->getRecentTweets(),
			'page_name' => $this->Posts_model->getOption('twitter_username'),
			'sub_nav' => 'posts',
			'view' => 'posts_twitter'
		);
		
		$this->display('posts', 'backoffice', 'none', $data);
	}
	
	function tweet(){
		$message = $this->Posts_model->tweet();
		
		redirect('backoffice/posts/twitter');
	}

}
/* End of file posts.php */
/* Location: ./application/modules/backoffice/posts.php */
